import numpy as np
from scipy.integrate import simps
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D
import matplotlib.mlab as mlab
from numpy.linalg import inv
from scipy.linalg import eigh
import time
import pandas as pd

start = time.time()

################################## MANUAL ##################################
# Define the geometry
# Define or import the moment curvature relationship
# Define the distinct points for cracking and yielding
# Define the discretization, default: dx=L/5, dy=W/5
# First do an elastic calculation with dq=1 to identify the moment distribution.
# Determine the number of load steps.
# Scale the load by: M_max / (Myy_xL_yW * load steps)
# Define the prescribed values for the moment in the corner points


def find_nearest(array, value):
    array = np.asarray(array)
    dif = array - value
    AA = []
    for idx in np.arange(len(dif)):
        if dif[idx] >= 0:
            AA.append(idx)
            break
    return AA[0]

#Geometry
L = 6.35/2		                    #Plate length [m]
W = 6.35/2			                #Plate width [m]
t = 0.22			                #Plate thickness [m]
bw = 0.2		                    #Beam width [m]
bh = 0.4		                    #Beam height [m]

#Moment curvature
df = pd.read_excel('M-kappa case study.xlsx')

curvxx = df.kappa_xx
momxx = df.M_xx
curvxx_factor = np.zeros(len(momxx))
curvxx_crack_pos = 0.000558788606982986
momxx_crack_pos = 18.2442166833721*1000
curvxx_crack_neg = -0.000558788606982986
momxx_crack_neg = -18.2442166833721*1000
curvxx_yield_pos = 0.019836995547896
momxx_yield_pos = 49.3184259057144*1000
curvxx_yield_neg = -0.019836995547896
momxx_yield_neg = -49.3184259057144*1000
EIin_xx = momxx_crack_pos / curvxx_crack_pos

curvyy = df.kappa_yy
momyy = df.M_yy
curvyy_factor = np.zeros(len(momyy))
curvyy_crack_pos = 0.000558788606982986
momyy_crack_pos = 18.129400110368*1000  #check if yy direction remains elastic
curvyy_crack_neg = -0.000558788606982986
momyy_crack_neg = -18.129400110368*1000
curvyy_yield_pos = 0.01871941833393
momyy_yield_pos = 28.3454204889273*1000
curvyy_yield_neg = -0.01871941833393
momyy_yield_neg = -28.3454204889273*1000
EIin_yy = momyy_crack_pos / curvyy_crack_pos

curv_beamyy = df.kappa_beam_case
mom_beamyy = df.M_beam_case
curv_beamyy_factor = np.zeros(len(momyy))
curv_beamyy_crack_pos = 0.000163911324715009
mom_beamyy_crack_pos = 64.1845821322212
curv_beamyy_crack_neg = -0.000163911324715009
mom_beamyy_crack_neg = -64.1845821322212
curv_beamyy_yield_pos = 0.00569591853384657
mom_beamyy_yield_pos = 553.618624784568
curv_beamyy_yield_neg = -0.00569591853384657
mom_beamyy_yield_neg = -553.618624784568
EIin_beam = mom_beamyy_crack_pos*1000 / curv_beamyy_crack_pos

print('ratio edge beam / slab yy =', EIin_beam / EIin_yy)

for i in np.arange(len(momxx) - 1):
    curvxx_factor[i + 1] = min(2 * ((momxx[i + 1] - momxx[i]) / (curvxx[i + 1] - curvxx[i])) / EIin_xx, 2)
for j in np.arange(len(momyy) - 1):
    curvyy_factor[j + 1] = min(2 * ((momyy[j + 1] - momyy[j]) / (curvyy[j + 1] - curvyy[j])) / EIin_yy, 2)

#Discretization
dx = L/9
dy = W/9
nx = int(L/dx)+2
ny = int(W/dy)+2

#Properties
nu = 0
Dxx = EIin_xx * np.ones((ny - 1, nx - 1))
Dyy = EIin_yy * np.ones((ny - 1, nx - 1))
Dxx_corner = Dxx[0,0]
Dyy_corner = Dyy[0,0]
Dyy[0::, 0] = EIin_beam
Dxy = 1/2*(1-nu)*np.sqrt(Dxx*Dyy)

#Load
dq = 54895.7187 / (4.755623281052069*200)
q_steps = 200

#Script
w_step = np.zeros((ny + 3, nx + 3))
tol = 0.000001
qindex = range(q_steps)
w = np.zeros([len(qindex), ny + 3, nx + 3])
increase = []
kM_xx = []
kM_yy = []
kM_xy = []
kM_beam = []
kL = []
kL_beam = []
u_slab = []
u_beam = []
x = np.linspace(0,L,nx-1)
y = np.linspace(0,W,ny-1)
X, Y = np.meshgrid(x, y)
mxx = np.zeros([ny-1, nx-1])
myy = np.zeros([ny-1, nx-1])
mxy = np.zeros([ny-1, nx-1])
Mxxfunctionxy = np.zeros([q_steps, ny-1, nx-1])
Myyfunctionxy = np.zeros([q_steps, ny-1, nx-1])
Mybeamfunction = np.zeros([q_steps, ny-1])
Mxx_xL_y0_plot = []
Mxx_xL_yW_plot = []
kappaxx_xL_y0_plot = []
kappaxx_xL_yW_plot = []
idx_mid_xplane = [1691, 1691, 1691, 1691, 1691, 1691, 1691, 1691, 1691, 1691]
idx_mid_yplane = [2407, 2407, 2407, 2407, 2407, 2407, 2407, 2407, 2407, 2407]
print('initial curv factor xx =', curvxx_factor[idx_mid_xplane])
print('initial curv factor yy =', curvyy_factor[idx_mid_yplane])

for l in qindex:
    for k in range(100000):
        w_step[0, 2] = (2 * (-2 + nu) * dy ** 2 * (w_step[3, 2] + w_step[1, 1] / 2 + w_step[1, 3] / 2 - w_step[3, 1] / 2 - w_step[3, 3] / 2 - w_step[1, 2]) * np.sqrt(Dxx[0, 0] * Dyy[0, 0]) - 2 * (L * W * dq * dy ** 3 + (w_step[3, 2] - w_step[4, 2] / 2 - w_step[1, 2]) * Dyy[0, 0]) * dx ** 2) / (dx ** 2 * Dyy[0, 0])
        w_step[0, 3] = (dy ** 2 * (nu - 2) * (w_step[1, 3 + 1] - w_step[3, 3 - 1] - w_step[3, 3 + 1] - 2 * w_step[1, 3] + 2 * w_step[3, 3] + w_step[1, 3 - 1]) * np.sqrt(Dxx[0, 3 - 2] * Dyy[0, 3 - 2]) + 2 * Dyy[0, 3 - 2] * (w_step[1, 3] - w_step[3, 3] + w_step[4, 3] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 3 - 2])
        w_step[0, 4] = (dy ** 2 * (nu - 2) * (w_step[1, 4 + 1] - w_step[3, 4 - 1] - w_step[3, 4 + 1] - 2 * w_step[1, 4] + 2 * w_step[3, 4] + w_step[1, 4 - 1]) * np.sqrt(Dxx[0, 4 - 2] * Dyy[0, 4 - 2]) + 2 * Dyy[0, 4 - 2] * (w_step[1, 4] - w_step[3, 4] + w_step[4, 4] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 4 - 2])
        w_step[0, 5] = (dy ** 2 * (nu - 2) * (w_step[1, 5 + 1] - w_step[3, 5 - 1] - w_step[3, 5 + 1] - 2 * w_step[1, 5] + 2 * w_step[3, 5] + w_step[1, 5 - 1]) * np.sqrt(Dxx[0, 5 - 2] * Dyy[0, 5 - 2]) + 2 * Dyy[0, 5 - 2] * (w_step[1, 5] - w_step[3, 5] + w_step[4, 5] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 5 - 2])
        w_step[0, 6] = (dy ** 2 * (nu - 2) * (w_step[1, 6 + 1] - w_step[3, 6 - 1] - w_step[3, 6 + 1] - 2 * w_step[1, 6] + 2 * w_step[3, 6] + w_step[1, 6 - 1]) * np.sqrt(Dxx[0, 6 - 2] * Dyy[0, 6 - 2]) + 2 * Dyy[0, 6 - 2] * (w_step[1, 6] - w_step[3, 6] + w_step[4, 6] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 6 - 2])
        w_step[0, 7] = (dy ** 2 * (nu - 2) * (w_step[1, 7 + 1] - w_step[3, 7 - 1] - w_step[3, 7 + 1] - 2 * w_step[1, 7] + 2 * w_step[3, 7] + w_step[1, 7 - 1]) * np.sqrt(Dxx[0, 7 - 2] * Dyy[0, 7 - 2]) + 2 * Dyy[0, 7 - 2] * (w_step[1, 7] - w_step[3, 7] + w_step[4, 7] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 7 - 2])
        w_step[0, 8] = (dy ** 2 * (nu - 2) * (w_step[1, 8 + 1] - w_step[3, 8 - 1] - w_step[3, 8 + 1] - 2 * w_step[1, 8] + 2 * w_step[3, 8] + w_step[1, 8 - 1]) * np.sqrt(Dxx[0, 8 - 2] * Dyy[0, 8 - 2]) + 2 * Dyy[0, 8 - 2] * (w_step[1, 8] - w_step[3, 8] + w_step[4, 8] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 8 - 2])
        w_step[0, 9] = (dy ** 2 * (nu - 2) * (w_step[1, 9 + 1] - w_step[3, 9 - 1] - w_step[3, 9 + 1] - 2 * w_step[1, 9] + 2 * w_step[3, 9] + w_step[1, 9 - 1]) * np.sqrt(Dxx[0, 9 - 2] * Dyy[0, 9 - 2]) + 2 * Dyy[0, 9 - 2] * (w_step[1, 9] - w_step[3, 9] + w_step[4, 9] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 9 - 2])
        w_step[0, 10] = (dy ** 2 * (nu - 2) * (w_step[1, 10 + 1] - w_step[3, 10 - 1] - w_step[3, 10 + 1] - 2 * w_step[1, 10] + 2 * w_step[3, 10] + w_step[1, 10 - 1]) * np.sqrt(Dxx[0, 10 - 2] * Dyy[0, 10 - 2]) + 2 * Dyy[0, 10 - 2] * (w_step[1, 10] - w_step[3, 10] + w_step[4, 10] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 10 - 2])
        w_step[0, 11] = (dy ** 2 * (nu - 2) * (w_step[1, 11 + 1] - w_step[3, 11 - 1] - w_step[3, 11 + 1] - 2 * w_step[1, 11] + 2 * w_step[3, 11] + w_step[1, 11 - 1]) * np.sqrt(Dxx[0, 11 - 2] * Dyy[0, 11 - 2]) + 2 * Dyy[0, 11 - 2] * (w_step[1, 11] - w_step[3, 11] + w_step[4, 11] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 11 - 2])
        #w_step[0, 12] = (dy ** 2 * (nu - 2) * (w_step[1, 12 + 1] - w_step[3, 12 - 1] - w_step[3, 12 + 1] - 2 * w_step[1, 12] + 2 * w_step[3, 12] + w_step[1, 12 - 1]) * np.sqrt(Dxx[0, 12 - 2] * Dyy[0, 12 - 2]) + 2 * Dyy[0, 12 - 2] * (w_step[1, 12] - w_step[3, 12] + w_step[4, 12] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 12 - 2])
        #w_step[0, 13] = (dy ** 2 * (nu - 2) * (w_step[1, 13 + 1] - w_step[3, 13 - 1] - w_step[3, 13 + 1] - 2 * w_step[1, 13] + 2 * w_step[3, 13] + w_step[1, 13 - 1]) * np.sqrt(Dxx[0, 13 - 2] * Dyy[0, 13 - 2]) + 2 * Dyy[0, 13 - 2] * (w_step[1, 13] - w_step[3, 13] + w_step[4, 13] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 13 - 2])
        #w_step[0, 14] = (dy ** 2 * (nu - 2) * (w_step[1, 14 + 1] - w_step[3, 14 - 1] - w_step[3, 14 + 1] - 2 * w_step[1, 14] + 2 * w_step[3, 14] + w_step[1, 14 - 1]) * np.sqrt(Dxx[0, 14 - 2] * Dyy[0, 14 - 2]) + 2 * Dyy[0, 14 - 2] * (w_step[1, 14] - w_step[3, 14] + w_step[4, 14] / 2) * dx ** 2) / (dx ** 2 * Dyy[0, 14 - 2])

        w_step[1, 1] = -w_step[3, 3]
        w_step[1, 2] = 2 * w_step[2, 2] - w_step[3, 2] - nu * np.sqrt(Dxx[0, 0] / Dyy[0, 0]) * dy ** 2 / dx ** 2 * (w_step[2, 3] - 2 * w_step[2, 2] + w_step[2, 1])
        w_step[1, 3] = 2 * w_step[2, 3] - w_step[3, 3] - nu * np.sqrt(Dxx[0, 3 - 2] / Dyy[0, 3 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 3 + 1] - 2 * w_step[2, 3] + w_step[2, 3 - 1])
        w_step[1, 4] = 2 * w_step[2, 4] - w_step[3, 4] - nu * np.sqrt(Dxx[0, 4 - 2] / Dyy[0, 4 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 4 + 1] - 2 * w_step[2, 4] + w_step[2, 4 - 1])
        w_step[1, 5] = 2 * w_step[2, 5] - w_step[3, 5] - nu * np.sqrt(Dxx[0, 5 - 2] / Dyy[0, 5 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 5 + 1] - 2 * w_step[2, 5] + w_step[2, 5 - 1])
        w_step[1, 6] = 2 * w_step[2, 6] - w_step[3, 6] - nu * np.sqrt(Dxx[0, 6 - 2] / Dyy[0, 6 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 6 + 1] - 2 * w_step[2, 6] + w_step[2, 6 - 1])
        w_step[1, 7] = 2 * w_step[2, 7] - w_step[3, 7] - nu * np.sqrt(Dxx[0, 7 - 2] / Dyy[0, 7 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 7 + 1] - 2 * w_step[2, 7] + w_step[2, 7 - 1])
        w_step[1, 8] = 2 * w_step[2, 8] - w_step[3, 8] - nu * np.sqrt(Dxx[0, 8 - 2] / Dyy[0, 8 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 8 + 1] - 2 * w_step[2, 8] + w_step[2, 8 - 1])
        w_step[1, 9] = 2 * w_step[2, 9] - w_step[3, 9] - nu * np.sqrt(Dxx[0, 9 - 2] / Dyy[0, 9 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 9 + 1] - 2 * w_step[2, 9] + w_step[2, 9 - 1])
        w_step[1, 10] = 2 * w_step[2, 10] - w_step[3, 10] - nu * np.sqrt(Dxx[0, 10 - 2] / Dyy[0, 10 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 10 + 1] - 2 * w_step[2, 10] + w_step[2, 10 - 1])
        w_step[1, 11] = 2 * w_step[2, 11] - w_step[3, 11] - nu * np.sqrt(Dxx[0, 11 - 2] / Dyy[0, 11 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 11 + 1] - 2 * w_step[2, 11] + w_step[2, 11 - 1])
        #w_step[1, 12] = 2 * w_step[2, 12] - w_step[3, 12] - nu * np.sqrt(Dxx[0, 12 - 2] / Dyy[0, 12 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 12 + 1] - 2 * w_step[2, 12] + w_step[2, 12 - 1])
        #w_step[1, 13] = 2 * w_step[2, 13] - w_step[3, 13] - nu * np.sqrt(Dxx[0, 13 - 2] / Dyy[0, 13 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 13 + 1] - 2 * w_step[2, 13] + w_step[2, 13 - 1])
        #w_step[1, 14] = 2 * w_step[2, 14] - w_step[3, 14] - nu * np.sqrt(Dxx[0, 14 - 2] / Dyy[0, 14 - 2]) * dy ** 2 / dx ** 2 * (w_step[2, 14 + 1] - 2 * w_step[2, 14] + w_step[2, 14 - 1])
        w_step[1, nx+1] = 2 * w_step[1, nx] - w_step[1, nx-1] - nu*dx**2/dy**2*(w_step[2, nx] - 2*w_step[1, nx] + w_step[0, nx]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[1, nx - 1] - w_step[1, nx] + nu/2*dx**2/dy**2*(w_step[2, nx] - 2*w_step[1, nx] + w_step[0, nx]))

        w_step[2, 0] = (2 * (-2 + nu) * (w_step[2, 3] + w_step[1, 1] / 2 - w_step[1, 3] / 2 + w_step[3, 1] / 2 - w_step[3, 3] / 2 - w_step[2, 1]) * dx ** 2 * np.sqrt(Dxx[0, 0] * Dyy[0, 0]) + 2 * dy ** 2 * (L * W * dq * dx ** 3 - (w_step[2, 3] - w_step[2, 4] / 2 - w_step[2, 1]) * Dxx[0, 0])) / (dy ** 2 * Dxx[0, 0])
        w_step[2, 1] = 2 * w_step[2, 2] - w_step[2, 3] - nu * np.sqrt(Dyy[0, 0] / Dxx[0, 0]) * dx ** 2 / dy ** 2 * (w_step[3, 2] - 2 * w_step[2, 2] + w_step[1, 2])
        w_step[2, 2] = 0
        w_step[2, 3] = (4 * dx ** 2 * (w_step[2 - 1, 3] + w_step[2 + 1, 3] - w_step[2 - 1, 3 - 1] / 2 - w_step[2 - 1, 3 + 1] / 2 - w_step[2 + 1, 3 - 1] / 2 - w_step[2 + 1, 3 + 1] / 2 + w_step[2, 3 - 1] + w_step[2, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 3 - 2] * Dyy[2 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 3 - 2] * (w_step[2 - 2, 3] - 4 * w_step[2 - 1, 3] - 4 * w_step[2 + 1, 3] + w_step[2 + 2, 3])) * dx ** 4 - Dxx[2 - 2, 3 - 2] * dy ** 4 * (w_step[2, 3 - 2] - 4 * w_step[2, 3 - 1] - 4 * w_step[2, 3 + 1] + w_step[2, 3 + 2])) / (6 * Dxx[2 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 3 - 2] * Dyy[2 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 4] = (4 * dx ** 2 * (w_step[2 - 1, 4] + w_step[2 + 1, 4] - w_step[2 - 1, 4 - 1] / 2 - w_step[2 - 1, 4 + 1] / 2 - w_step[2 + 1, 4 - 1] / 2 - w_step[2 + 1, 4 + 1] / 2 + w_step[2, 4 - 1] + w_step[2, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 4 - 2] * Dyy[2 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 4 - 2] * (w_step[2 - 2, 4] - 4 * w_step[2 - 1, 4] - 4 * w_step[2 + 1, 4] + w_step[2 + 2, 4])) * dx ** 4 - Dxx[2 - 2, 4 - 2] * dy ** 4 * (w_step[2, 4 - 2] - 4 * w_step[2, 4 - 1] - 4 * w_step[2, 4 + 1] + w_step[2, 4 + 2])) / (6 * Dxx[2 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 4 - 2] * Dyy[2 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 5] = (4 * dx ** 2 * (w_step[2 - 1, 5] + w_step[2 + 1, 5] - w_step[2 - 1, 5 - 1] / 2 - w_step[2 - 1, 5 + 1] / 2 - w_step[2 + 1, 5 - 1] / 2 - w_step[2 + 1, 5 + 1] / 2 + w_step[2, 5 - 1] + w_step[2, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 5 - 2] * Dyy[2 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 5 - 2] * (w_step[2 - 2, 5] - 4 * w_step[2 - 1, 5] - 4 * w_step[2 + 1, 5] + w_step[2 + 2, 5])) * dx ** 4 - Dxx[2 - 2, 5 - 2] * dy ** 4 * (w_step[2, 5 - 2] - 4 * w_step[2, 5 - 1] - 4 * w_step[2, 5 + 1] + w_step[2, 5 + 2])) / (6 * Dxx[2 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 5 - 2] * Dyy[2 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 6] = (4 * dx ** 2 * (w_step[2 - 1, 6] + w_step[2 + 1, 6] - w_step[2 - 1, 6 - 1] / 2 - w_step[2 - 1, 6 + 1] / 2 - w_step[2 + 1, 6 - 1] / 2 - w_step[2 + 1, 6 + 1] / 2 + w_step[2, 6 - 1] + w_step[2, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 6 - 2] * Dyy[2 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 6 - 2] * (w_step[2 - 2, 6] - 4 * w_step[2 - 1, 6] - 4 * w_step[2 + 1, 6] + w_step[2 + 2, 6])) * dx ** 4 - Dxx[2 - 2, 6 - 2] * dy ** 4 * (w_step[2, 6 - 2] - 4 * w_step[2, 6 - 1] - 4 * w_step[2, 6 + 1] + w_step[2, 6 + 2])) / (6 * Dxx[2 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 6 - 2] * Dyy[2 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 7] = (4 * dx ** 2 * (w_step[2 - 1, 7] + w_step[2 + 1, 7] - w_step[2 - 1, 7 - 1] / 2 - w_step[2 - 1, 7 + 1] / 2 - w_step[2 + 1, 7 - 1] / 2 - w_step[2 + 1, 7 + 1] / 2 + w_step[2, 7 - 1] + w_step[2, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 7 - 2] * Dyy[2 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 7 - 2] * (w_step[2 - 2, 7] - 4 * w_step[2 - 1, 7] - 4 * w_step[2 + 1, 7] + w_step[2 + 2, 7])) * dx ** 4 - Dxx[2 - 2, 7 - 2] * dy ** 4 * (w_step[2, 7 - 2] - 4 * w_step[2, 7 - 1] - 4 * w_step[2, 7 + 1] + w_step[2, 7 + 2])) / (6 * Dxx[2 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 7 - 2] * Dyy[2 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 8] = (4 * dx ** 2 * (w_step[2 - 1, 8] + w_step[2 + 1, 8] - w_step[2 - 1, 8 - 1] / 2 - w_step[2 - 1, 8 + 1] / 2 - w_step[2 + 1, 8 - 1] / 2 - w_step[2 + 1, 8 + 1] / 2 + w_step[2, 8 - 1] + w_step[2, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 8 - 2] * Dyy[2 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 8 - 2] * (w_step[2 - 2, 8] - 4 * w_step[2 - 1, 8] - 4 * w_step[2 + 1, 8] + w_step[2 + 2, 8])) * dx ** 4 - Dxx[2 - 2, 8 - 2] * dy ** 4 * (w_step[2, 8 - 2] - 4 * w_step[2, 8 - 1] - 4 * w_step[2, 8 + 1] + w_step[2, 8 + 2])) / (6 * Dxx[2 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 8 - 2] * Dyy[2 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 9] = (4 * dx ** 2 * (w_step[2 - 1, 9] + w_step[2 + 1, 9] - w_step[2 - 1, 9 - 1] / 2 - w_step[2 - 1, 9 + 1] / 2 - w_step[2 + 1, 9 - 1] / 2 - w_step[2 + 1, 9 + 1] / 2 + w_step[2, 9 - 1] + w_step[2, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 9 - 2] * Dyy[2 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 9 - 2] * (w_step[2 - 2, 9] - 4 * w_step[2 - 1, 9] - 4 * w_step[2 + 1, 9] + w_step[2 + 2, 9])) * dx ** 4 - Dxx[2 - 2, 9 - 2] * dy ** 4 * (w_step[2, 9 - 2] - 4 * w_step[2, 9 - 1] - 4 * w_step[2, 9 + 1] + w_step[2, 9 + 2])) / (6 * Dxx[2 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 9 - 2] * Dyy[2 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 10] = (4 * dx ** 2 * (w_step[2 - 1, 10] + w_step[2 + 1, 10] - w_step[2 - 1, 10 - 1] / 2 - w_step[2 - 1, 10 + 1] / 2 - w_step[2 + 1, 10 - 1] / 2 - w_step[2 + 1, 10 + 1] / 2 + w_step[2, 10 - 1] + w_step[2, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 10 - 2] * Dyy[2 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 10 - 2] * (w_step[2 - 2, 10] - 4 * w_step[2 - 1, 10] - 4 * w_step[2 + 1, 10] + w_step[2 + 2, 10])) * dx ** 4 - Dxx[2 - 2, 10 - 2] * dy ** 4 * (w_step[2, 10 - 2] - 4 * w_step[2, 10 - 1] - 4 * w_step[2, 10 + 1] + w_step[2, 10 + 2])) / (6 * Dxx[2 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 10 - 2] * Dyy[2 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, 11] = (4 * dx ** 2 * (w_step[2 - 1, 11] + w_step[2 + 1, 11] - w_step[2 - 1, 11 - 1] / 2 - w_step[2 - 1, 11 + 1] / 2 - w_step[2 + 1, 11 - 1] / 2 - w_step[2 + 1, 11 + 1] / 2 + w_step[2, 11 - 1] + w_step[2, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 11 - 2] * Dyy[2 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 11 - 2] * (w_step[2 - 2, 11] - 4 * w_step[2 - 1, 11] - 4 * w_step[2 + 1, 11] + w_step[2 + 2, 11])) * dx ** 4 - Dxx[2 - 2, 11 - 2] * dy ** 4 * (w_step[2, 11 - 2] - 4 * w_step[2, 11 - 1] - 4 * w_step[2, 11 + 1] + w_step[2, 11 + 2])) / (6 * Dxx[2 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 11 - 2] * Dyy[2 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[2, 12] = (4 * dx ** 2 * (w_step[2 - 1, 12] + w_step[2 + 1, 12] - w_step[2 - 1, 12 - 1] / 2 - w_step[2 - 1, 12 + 1] / 2 - w_step[2 + 1, 12 - 1] / 2 - w_step[2 + 1, 12 + 1] / 2 + w_step[2, 12 - 1] + w_step[2, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 12 - 2] * Dyy[2 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 12 - 2] * (w_step[2 - 2, 12] - 4 * w_step[2 - 1, 12] - 4 * w_step[2 + 1, 12] + w_step[2 + 2, 12])) * dx ** 4 - Dxx[2 - 2, 12 - 2] * dy ** 4 * (w_step[2, 12 - 2] - 4 * w_step[2, 12 - 1] - 4 * w_step[2, 12 + 1] + w_step[2, 12 + 2])) / (6 * Dxx[2 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 12 - 2] * Dyy[2 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[2, 13] = (4 * dx ** 2 * (w_step[2 - 1, 13] + w_step[2 + 1, 13] - w_step[2 - 1, 13 - 1] / 2 - w_step[2 - 1, 13 + 1] / 2 - w_step[2 + 1, 13 - 1] / 2 - w_step[2 + 1, 13 + 1] / 2 + w_step[2, 13 - 1] + w_step[2, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 13 - 2] * Dyy[2 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 13 - 2] * (w_step[2 - 2, 13] - 4 * w_step[2 - 1, 13] - 4 * w_step[2 + 1, 13] + w_step[2 + 2, 13])) * dx ** 4 - Dxx[2 - 2, 13 - 2] * dy ** 4 * (w_step[2, 13 - 2] - 4 * w_step[2, 13 - 1] - 4 * w_step[2, 13 + 1] + w_step[2, 13 + 2])) / (6 * Dxx[2 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 13 - 2] * Dyy[2 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[2, 14] = (4 * dx ** 2 * (w_step[2 - 1, 14] + w_step[2 + 1, 14] - w_step[2 - 1, 14 - 1] / 2 - w_step[2 - 1, 14 + 1] / 2 - w_step[2 + 1, 14 - 1] / 2 - w_step[2 + 1, 14 + 1] / 2 + w_step[2, 14 - 1] + w_step[2, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[2 - 2, 14 - 2] * Dyy[2 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[2 - 2, 14 - 2] * (w_step[2 - 2, 14] - 4 * w_step[2 - 1, 14] - 4 * w_step[2 + 1, 14] + w_step[2 + 2, 14])) * dx ** 4 - Dxx[2 - 2, 14 - 2] * dy ** 4 * (w_step[2, 14 - 2] - 4 * w_step[2, 14 - 1] - 4 * w_step[2, 14 + 1] + w_step[2, 14 + 2])) / (6 * Dxx[2 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[2 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[2 - 2, 14 - 2] * Dyy[2 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[2, nx + 1] = 2 * w_step[2, nx + 1 - 1] - w_step[2, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[2 + 1, nx + 1 - 1] - 2 * w_step[2, nx + 1 - 1] + w_step[2 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[2, nx + 1 - 2] - w_step[2, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[2 + 1, nx + 1 - 1] - 2 * w_step[2, nx + 1 - 1] + w_step[2 - 1, nx + 1 - 1]))
        w_step[2, nx + 2] = 2 * w_step[2, nx + 2 - 1] - 2 * w_step[2, nx + 2 - 3] + w_step[2, nx + 2 - 4]

        w_step[3, 0] = (dx ** 2 * (nu - 2) * (w_step[3 - 1, 0 + 1] - w_step[3 - 1, 0 + 3] + w_step[3 + 1, 0 + 1] - w_step[3 + 1, 0 + 3] - 2 * w_step[3, 0 + 1] + 2 * w_step[3, 0 + 3]) * np.sqrt(Dxx[3 - 2, 0] * Dyy[3 - 2, 0]) + 2 * dy ** 2 * Dxx[3 - 2, 0] * (w_step[3, 0 + 1] - w_step[3, 0 + 3] + w_step[3, 0 + 4] / 2)) / (dy ** 2 * Dxx[3 - 2, 0])
        w_step[3, 1] = 2 * w_step[3, 1 + 1] - w_step[3, 1 + 2] - nu * np.sqrt(Dyy[3 - 2, 1 - 1] / Dxx[3 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[3 + 1, 1 + 1] - 2 * w_step[3, 1 + 1] + w_step[3 - 1, 1 + 1])
        w_step[3, 2] = (4 * dx ** 2 * (w_step[3 - 1, 2] + w_step[3 + 1, 2] - w_step[3 - 1, 2 - 1] / 2 - w_step[3 - 1, 2 + 1] / 2 - w_step[3 + 1, 2 - 1] / 2 - w_step[3 + 1, 2 + 1] / 2 + w_step[3, 2 - 1] + w_step[3, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 2 - 2] * Dyy[3 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 2 - 2] * (w_step[3 - 2, 2] - 4 * w_step[3 - 1, 2] - 4 * w_step[3 + 1, 2] + w_step[3 + 2, 2])) * dx ** 4 - Dxx[3 - 2, 2 - 2] * dy ** 4 * (w_step[3, 2 - 2] - 4 * w_step[3, 2 - 1] - 4 * w_step[3, 2 + 1] + w_step[3, 2 + 2])) / (6 * Dxx[3 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 2 - 2] * Dyy[3 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 3] = (4 * dx ** 2 * (w_step[3 - 1, 3] + w_step[3 + 1, 3] - w_step[3 - 1, 3 - 1] / 2 - w_step[3 - 1, 3 + 1] / 2 - w_step[3 + 1, 3 - 1] / 2 - w_step[3 + 1, 3 + 1] / 2 + w_step[3, 3 - 1] + w_step[3, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 3 - 2] * Dyy[3 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 3 - 2] * (w_step[3 - 2, 3] - 4 * w_step[3 - 1, 3] - 4 * w_step[3 + 1, 3] + w_step[3 + 2, 3])) * dx ** 4 - Dxx[3 - 2, 3 - 2] * dy ** 4 * (w_step[3, 3 - 2] - 4 * w_step[3, 3 - 1] - 4 * w_step[3, 3 + 1] + w_step[3, 3 + 2])) / (6 * Dxx[3 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 3 - 2] * Dyy[3 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 4] = (4 * dx ** 2 * (w_step[3 - 1, 4] + w_step[3 + 1, 4] - w_step[3 - 1, 4 - 1] / 2 - w_step[3 - 1, 4 + 1] / 2 - w_step[3 + 1, 4 - 1] / 2 - w_step[3 + 1, 4 + 1] / 2 + w_step[3, 4 - 1] + w_step[3, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 4 - 2] * Dyy[3 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 4 - 2] * (w_step[3 - 2, 4] - 4 * w_step[3 - 1, 4] - 4 * w_step[3 + 1, 4] + w_step[3 + 2, 4])) * dx ** 4 - Dxx[3 - 2, 4 - 2] * dy ** 4 * (w_step[3, 4 - 2] - 4 * w_step[3, 4 - 1] - 4 * w_step[3, 4 + 1] + w_step[3, 4 + 2])) / (6 * Dxx[3 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 4 - 2] * Dyy[3 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 5] = (4 * dx ** 2 * (w_step[3 - 1, 5] + w_step[3 + 1, 5] - w_step[3 - 1, 5 - 1] / 2 - w_step[3 - 1, 5 + 1] / 2 - w_step[3 + 1, 5 - 1] / 2 - w_step[3 + 1, 5 + 1] / 2 + w_step[3, 5 - 1] + w_step[3, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 5 - 2] * Dyy[3 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 5 - 2] * (w_step[3 - 2, 5] - 4 * w_step[3 - 1, 5] - 4 * w_step[3 + 1, 5] + w_step[3 + 2, 5])) * dx ** 4 - Dxx[3 - 2, 5 - 2] * dy ** 4 * (w_step[3, 5 - 2] - 4 * w_step[3, 5 - 1] - 4 * w_step[3, 5 + 1] + w_step[3, 5 + 2])) / (6 * Dxx[3 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 5 - 2] * Dyy[3 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 6] = (4 * dx ** 2 * (w_step[3 - 1, 6] + w_step[3 + 1, 6] - w_step[3 - 1, 6 - 1] / 2 - w_step[3 - 1, 6 + 1] / 2 - w_step[3 + 1, 6 - 1] / 2 - w_step[3 + 1, 6 + 1] / 2 + w_step[3, 6 - 1] + w_step[3, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 6 - 2] * Dyy[3 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 6 - 2] * (w_step[3 - 2, 6] - 4 * w_step[3 - 1, 6] - 4 * w_step[3 + 1, 6] + w_step[3 + 2, 6])) * dx ** 4 - Dxx[3 - 2, 6 - 2] * dy ** 4 * (w_step[3, 6 - 2] - 4 * w_step[3, 6 - 1] - 4 * w_step[3, 6 + 1] + w_step[3, 6 + 2])) / (6 * Dxx[3 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 6 - 2] * Dyy[3 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 7] = (4 * dx ** 2 * (w_step[3 - 1, 7] + w_step[3 + 1, 7] - w_step[3 - 1, 7 - 1] / 2 - w_step[3 - 1, 7 + 1] / 2 - w_step[3 + 1, 7 - 1] / 2 - w_step[3 + 1, 7 + 1] / 2 + w_step[3, 7 - 1] + w_step[3, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 7 - 2] * Dyy[3 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 7 - 2] * (w_step[3 - 2, 7] - 4 * w_step[3 - 1, 7] - 4 * w_step[3 + 1, 7] + w_step[3 + 2, 7])) * dx ** 4 - Dxx[3 - 2, 7 - 2] * dy ** 4 * (w_step[3, 7 - 2] - 4 * w_step[3, 7 - 1] - 4 * w_step[3, 7 + 1] + w_step[3, 7 + 2])) / (6 * Dxx[3 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 7 - 2] * Dyy[3 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 8] = (4 * dx ** 2 * (w_step[3 - 1, 8] + w_step[3 + 1, 8] - w_step[3 - 1, 8 - 1] / 2 - w_step[3 - 1, 8 + 1] / 2 - w_step[3 + 1, 8 - 1] / 2 - w_step[3 + 1, 8 + 1] / 2 + w_step[3, 8 - 1] + w_step[3, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 8 - 2] * Dyy[3 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 8 - 2] * (w_step[3 - 2, 8] - 4 * w_step[3 - 1, 8] - 4 * w_step[3 + 1, 8] + w_step[3 + 2, 8])) * dx ** 4 - Dxx[3 - 2, 8 - 2] * dy ** 4 * (w_step[3, 8 - 2] - 4 * w_step[3, 8 - 1] - 4 * w_step[3, 8 + 1] + w_step[3, 8 + 2])) / (6 * Dxx[3 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 8 - 2] * Dyy[3 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 9] = (4 * dx ** 2 * (w_step[3 - 1, 9] + w_step[3 + 1, 9] - w_step[3 - 1, 9 - 1] / 2 - w_step[3 - 1, 9 + 1] / 2 - w_step[3 + 1, 9 - 1] / 2 - w_step[3 + 1, 9 + 1] / 2 + w_step[3, 9 - 1] + w_step[3, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 9 - 2] * Dyy[3 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 9 - 2] * (w_step[3 - 2, 9] - 4 * w_step[3 - 1, 9] - 4 * w_step[3 + 1, 9] + w_step[3 + 2, 9])) * dx ** 4 - Dxx[3 - 2, 9 - 2] * dy ** 4 * (w_step[3, 9 - 2] - 4 * w_step[3, 9 - 1] - 4 * w_step[3, 9 + 1] + w_step[3, 9 + 2])) / (6 * Dxx[3 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 9 - 2] * Dyy[3 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 10] = (4 * dx ** 2 * (w_step[3 - 1, 10] + w_step[3 + 1, 10] - w_step[3 - 1, 10 - 1] / 2 - w_step[3 - 1, 10 + 1] / 2 - w_step[3 + 1, 10 - 1] / 2 - w_step[3 + 1, 10 + 1] / 2 + w_step[3, 10 - 1] + w_step[3, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 10 - 2] * Dyy[3 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 10 - 2] * (w_step[3 - 2, 10] - 4 * w_step[3 - 1, 10] - 4 * w_step[3 + 1, 10] + w_step[3 + 2, 10])) * dx ** 4 - Dxx[3 - 2, 10 - 2] * dy ** 4 * (w_step[3, 10 - 2] - 4 * w_step[3, 10 - 1] - 4 * w_step[3, 10 + 1] + w_step[3, 10 + 2])) / (6 * Dxx[3 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 10 - 2] * Dyy[3 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, 11] = (4 * dx ** 2 * (w_step[3 - 1, 11] + w_step[3 + 1, 11] - w_step[3 - 1, 11 - 1] / 2 - w_step[3 - 1, 11 + 1] / 2 - w_step[3 + 1, 11 - 1] / 2 - w_step[3 + 1, 11 + 1] / 2 + w_step[3, 11 - 1] + w_step[3, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 11 - 2] * Dyy[3 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 11 - 2] * (w_step[3 - 2, 11] - 4 * w_step[3 - 1, 11] - 4 * w_step[3 + 1, 11] + w_step[3 + 2, 11])) * dx ** 4 - Dxx[3 - 2, 11 - 2] * dy ** 4 * (w_step[3, 11 - 2] - 4 * w_step[3, 11 - 1] - 4 * w_step[3, 11 + 1] + w_step[3, 11 + 2])) / (6 * Dxx[3 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 11 - 2] * Dyy[3 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[3, 12] = (4 * dx ** 2 * (w_step[3 - 1, 12] + w_step[3 + 1, 12] - w_step[3 - 1, 12 - 1] / 2 - w_step[3 - 1, 12 + 1] / 2 - w_step[3 + 1, 12 - 1] / 2 - w_step[3 + 1, 12 + 1] / 2 + w_step[3, 12 - 1] + w_step[3, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 12 - 2] * Dyy[3 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 12 - 2] * (w_step[3 - 2, 12] - 4 * w_step[3 - 1, 12] - 4 * w_step[3 + 1, 12] + w_step[3 + 2, 12])) * dx ** 4 - Dxx[3 - 2, 12 - 2] * dy ** 4 * (w_step[3, 12 - 2] - 4 * w_step[3, 12 - 1] - 4 * w_step[3, 12 + 1] + w_step[3, 12 + 2])) / (6 * Dxx[3 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 12 - 2] * Dyy[3 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[3, 13] = (4 * dx ** 2 * (w_step[3 - 1, 13] + w_step[3 + 1, 13] - w_step[3 - 1, 13 - 1] / 2 - w_step[3 - 1, 13 + 1] / 2 - w_step[3 + 1, 13 - 1] / 2 - w_step[3 + 1, 13 + 1] / 2 + w_step[3, 13 - 1] + w_step[3, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 13 - 2] * Dyy[3 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 13 - 2] * (w_step[3 - 2, 13] - 4 * w_step[3 - 1, 13] - 4 * w_step[3 + 1, 13] + w_step[3 + 2, 13])) * dx ** 4 - Dxx[3 - 2, 13 - 2] * dy ** 4 * (w_step[3, 13 - 2] - 4 * w_step[3, 13 - 1] - 4 * w_step[3, 13 + 1] + w_step[3, 13 + 2])) / (6 * Dxx[3 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 13 - 2] * Dyy[3 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[3, 14] = (4 * dx ** 2 * (w_step[3 - 1, 14] + w_step[3 + 1, 14] - w_step[3 - 1, 14 - 1] / 2 - w_step[3 - 1, 14 + 1] / 2 - w_step[3 + 1, 14 - 1] / 2 - w_step[3 + 1, 14 + 1] / 2 + w_step[3, 14 - 1] + w_step[3, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[3 - 2, 14 - 2] * Dyy[3 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[3 - 2, 14 - 2] * (w_step[3 - 2, 14] - 4 * w_step[3 - 1, 14] - 4 * w_step[3 + 1, 14] + w_step[3 + 2, 14])) * dx ** 4 - Dxx[3 - 2, 14 - 2] * dy ** 4 * (w_step[3, 14 - 2] - 4 * w_step[3, 14 - 1] - 4 * w_step[3, 14 + 1] + w_step[3, 14 + 2])) / (6 * Dxx[3 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[3 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[3 - 2, 14 - 2] * Dyy[3 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[3, nx + 1] = 2 * w_step[3, nx + 1 - 1] - w_step[3, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[3 + 1, nx + 1 - 1] - 2 * w_step[3, nx + 1 - 1] + w_step[3 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[3, nx + 1 - 2] - w_step[3, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[3 + 1, nx + 1 - 1] - 2 * w_step[3, nx + 1 - 1] + w_step[3 - 1, nx + 1 - 1]))
        w_step[3, nx + 2] = 2 * w_step[3, nx + 2 - 1] - 2 * w_step[3, nx + 2 - 3] + w_step[3, nx + 2 - 4]

        w_step[4, 0] = (dx ** 2 * (nu - 2) * (w_step[4 - 1, 0 + 1] - w_step[4 - 1, 0 + 3] + w_step[4 + 1, 0 + 1] - w_step[4 + 1, 0 + 3] - 2 * w_step[4, 0 + 1] + 2 * w_step[4, 0 + 3]) * np.sqrt(Dxx[4 - 2, 0] * Dyy[4 - 2, 0]) + 2 * dy ** 2 * Dxx[4 - 2, 0] * (w_step[4, 0 + 1] - w_step[4, 0 + 3] + w_step[4, 0 + 4] / 2)) / (dy ** 2 * Dxx[4 - 2, 0])
        w_step[4, 1] = 2 * w_step[4, 1 + 1] - w_step[4, 1 + 2] - nu * np.sqrt(Dyy[4 - 2, 1 - 1] / Dxx[4 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[4 + 1, 1 + 1] - 2 * w_step[4, 1 + 1] + w_step[4 - 1, 1 + 1])
        w_step[4, 2] = (4 * dx ** 2 * (w_step[4 - 1, 2] + w_step[4 + 1, 2] - w_step[4 - 1, 2 - 1] / 2 - w_step[4 - 1, 2 + 1] / 2 - w_step[4 + 1, 2 - 1] / 2 - w_step[4 + 1, 2 + 1] / 2 + w_step[4, 2 - 1] + w_step[4, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 2 - 2] * Dyy[4 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 2 - 2] * (w_step[4 - 2, 2] - 4 * w_step[4 - 1, 2] - 4 * w_step[4 + 1, 2] + w_step[4 + 2, 2])) * dx ** 4 - Dxx[4 - 2, 2 - 2] * dy ** 4 * (w_step[4, 2 - 2] - 4 * w_step[4, 2 - 1] - 4 * w_step[4, 2 + 1] + w_step[4, 2 + 2])) / (6 * Dxx[4 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 2 - 2] * Dyy[4 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 3] = (4 * dx ** 2 * (w_step[4 - 1, 3] + w_step[4 + 1, 3] - w_step[4 - 1, 3 - 1] / 2 - w_step[4 - 1, 3 + 1] / 2 - w_step[4 + 1, 3 - 1] / 2 - w_step[4 + 1, 3 + 1] / 2 + w_step[4, 3 - 1] + w_step[4, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 3 - 2] * Dyy[4 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 3 - 2] * (w_step[4 - 2, 3] - 4 * w_step[4 - 1, 3] - 4 * w_step[4 + 1, 3] + w_step[4 + 2, 3])) * dx ** 4 - Dxx[4 - 2, 3 - 2] * dy ** 4 * (w_step[4, 3 - 2] - 4 * w_step[4, 3 - 1] - 4 * w_step[4, 3 + 1] + w_step[4, 3 + 2])) / (6 * Dxx[4 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 3 - 2] * Dyy[4 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 4] = (4 * dx ** 2 * (w_step[4 - 1, 4] + w_step[4 + 1, 4] - w_step[4 - 1, 4 - 1] / 2 - w_step[4 - 1, 4 + 1] / 2 - w_step[4 + 1, 4 - 1] / 2 - w_step[4 + 1, 4 + 1] / 2 + w_step[4, 4 - 1] + w_step[4, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 4 - 2] * Dyy[4 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 4 - 2] * (w_step[4 - 2, 4] - 4 * w_step[4 - 1, 4] - 4 * w_step[4 + 1, 4] + w_step[4 + 2, 4])) * dx ** 4 - Dxx[4 - 2, 4 - 2] * dy ** 4 * (w_step[4, 4 - 2] - 4 * w_step[4, 4 - 1] - 4 * w_step[4, 4 + 1] + w_step[4, 4 + 2])) / (6 * Dxx[4 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 4 - 2] * Dyy[4 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 5] = (4 * dx ** 2 * (w_step[4 - 1, 5] + w_step[4 + 1, 5] - w_step[4 - 1, 5 - 1] / 2 - w_step[4 - 1, 5 + 1] / 2 - w_step[4 + 1, 5 - 1] / 2 - w_step[4 + 1, 5 + 1] / 2 + w_step[4, 5 - 1] + w_step[4, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 5 - 2] * Dyy[4 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 5 - 2] * (w_step[4 - 2, 5] - 4 * w_step[4 - 1, 5] - 4 * w_step[4 + 1, 5] + w_step[4 + 2, 5])) * dx ** 4 - Dxx[4 - 2, 5 - 2] * dy ** 4 * (w_step[4, 5 - 2] - 4 * w_step[4, 5 - 1] - 4 * w_step[4, 5 + 1] + w_step[4, 5 + 2])) / (6 * Dxx[4 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 5 - 2] * Dyy[4 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 6] = (4 * dx ** 2 * (w_step[4 - 1, 6] + w_step[4 + 1, 6] - w_step[4 - 1, 6 - 1] / 2 - w_step[4 - 1, 6 + 1] / 2 - w_step[4 + 1, 6 - 1] / 2 - w_step[4 + 1, 6 + 1] / 2 + w_step[4, 6 - 1] + w_step[4, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 6 - 2] * Dyy[4 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 6 - 2] * (w_step[4 - 2, 6] - 4 * w_step[4 - 1, 6] - 4 * w_step[4 + 1, 6] + w_step[4 + 2, 6])) * dx ** 4 - Dxx[4 - 2, 6 - 2] * dy ** 4 * (w_step[4, 6 - 2] - 4 * w_step[4, 6 - 1] - 4 * w_step[4, 6 + 1] + w_step[4, 6 + 2])) / (6 * Dxx[4 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 6 - 2] * Dyy[4 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 7] = (4 * dx ** 2 * (w_step[4 - 1, 7] + w_step[4 + 1, 7] - w_step[4 - 1, 7 - 1] / 2 - w_step[4 - 1, 7 + 1] / 2 - w_step[4 + 1, 7 - 1] / 2 - w_step[4 + 1, 7 + 1] / 2 + w_step[4, 7 - 1] + w_step[4, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 7 - 2] * Dyy[4 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 7 - 2] * (w_step[4 - 2, 7] - 4 * w_step[4 - 1, 7] - 4 * w_step[4 + 1, 7] + w_step[4 + 2, 7])) * dx ** 4 - Dxx[4 - 2, 7 - 2] * dy ** 4 * (w_step[4, 7 - 2] - 4 * w_step[4, 7 - 1] - 4 * w_step[4, 7 + 1] + w_step[4, 7 + 2])) / (6 * Dxx[4 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 7 - 2] * Dyy[4 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 8] = (4 * dx ** 2 * (w_step[4 - 1, 8] + w_step[4 + 1, 8] - w_step[4 - 1, 8 - 1] / 2 - w_step[4 - 1, 8 + 1] / 2 - w_step[4 + 1, 8 - 1] / 2 - w_step[4 + 1, 8 + 1] / 2 + w_step[4, 8 - 1] + w_step[4, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 8 - 2] * Dyy[4 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 8 - 2] * (w_step[4 - 2, 8] - 4 * w_step[4 - 1, 8] - 4 * w_step[4 + 1, 8] + w_step[4 + 2, 8])) * dx ** 4 - Dxx[4 - 2, 8 - 2] * dy ** 4 * (w_step[4, 8 - 2] - 4 * w_step[4, 8 - 1] - 4 * w_step[4, 8 + 1] + w_step[4, 8 + 2])) / (6 * Dxx[4 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 8 - 2] * Dyy[4 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 9] = (4 * dx ** 2 * (w_step[4 - 1, 9] + w_step[4 + 1, 9] - w_step[4 - 1, 9 - 1] / 2 - w_step[4 - 1, 9 + 1] / 2 - w_step[4 + 1, 9 - 1] / 2 - w_step[4 + 1, 9 + 1] / 2 + w_step[4, 9 - 1] + w_step[4, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 9 - 2] * Dyy[4 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 9 - 2] * (w_step[4 - 2, 9] - 4 * w_step[4 - 1, 9] - 4 * w_step[4 + 1, 9] + w_step[4 + 2, 9])) * dx ** 4 - Dxx[4 - 2, 9 - 2] * dy ** 4 * (w_step[4, 9 - 2] - 4 * w_step[4, 9 - 1] - 4 * w_step[4, 9 + 1] + w_step[4, 9 + 2])) / (6 * Dxx[4 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 9 - 2] * Dyy[4 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 10] = (4 * dx ** 2 * (w_step[4 - 1, 10] + w_step[4 + 1, 10] - w_step[4 - 1, 10 - 1] / 2 - w_step[4 - 1, 10 + 1] / 2 - w_step[4 + 1, 10 - 1] / 2 - w_step[4 + 1, 10 + 1] / 2 + w_step[4, 10 - 1] + w_step[4, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 10 - 2] * Dyy[4 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 10 - 2] * (w_step[4 - 2, 10] - 4 * w_step[4 - 1, 10] - 4 * w_step[4 + 1, 10] + w_step[4 + 2, 10])) * dx ** 4 - Dxx[4 - 2, 10 - 2] * dy ** 4 * (w_step[4, 10 - 2] - 4 * w_step[4, 10 - 1] - 4 * w_step[4, 10 + 1] + w_step[4, 10 + 2])) / (6 * Dxx[4 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 10 - 2] * Dyy[4 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, 11] = (4 * dx ** 2 * (w_step[4 - 1, 11] + w_step[4 + 1, 11] - w_step[4 - 1, 11 - 1] / 2 - w_step[4 - 1, 11 + 1] / 2 - w_step[4 + 1, 11 - 1] / 2 - w_step[4 + 1, 11 + 1] / 2 + w_step[4, 11 - 1] + w_step[4, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 11 - 2] * Dyy[4 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 11 - 2] * (w_step[4 - 2, 11] - 4 * w_step[4 - 1, 11] - 4 * w_step[4 + 1, 11] + w_step[4 + 2, 11])) * dx ** 4 - Dxx[4 - 2, 11 - 2] * dy ** 4 * (w_step[4, 11 - 2] - 4 * w_step[4, 11 - 1] - 4 * w_step[4, 11 + 1] + w_step[4, 11 + 2])) / (6 * Dxx[4 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 11 - 2] * Dyy[4 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[4, 12] = (4 * dx ** 2 * (w_step[4 - 1, 12] + w_step[4 + 1, 12] - w_step[4 - 1, 12 - 1] / 2 - w_step[4 - 1, 12 + 1] / 2 - w_step[4 + 1, 12 - 1] / 2 - w_step[4 + 1, 12 + 1] / 2 + w_step[4, 12 - 1] + w_step[4, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 12 - 2] * Dyy[4 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 12 - 2] * (w_step[4 - 2, 12] - 4 * w_step[4 - 1, 12] - 4 * w_step[4 + 1, 12] + w_step[4 + 2, 12])) * dx ** 4 - Dxx[4 - 2, 12 - 2] * dy ** 4 * (w_step[4, 12 - 2] - 4 * w_step[4, 12 - 1] - 4 * w_step[4, 12 + 1] + w_step[4, 12 + 2])) / (6 * Dxx[4 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 12 - 2] * Dyy[4 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[4, 13] = (4 * dx ** 2 * (w_step[4 - 1, 13] + w_step[4 + 1, 13] - w_step[4 - 1, 13 - 1] / 2 - w_step[4 - 1, 13 + 1] / 2 - w_step[4 + 1, 13 - 1] / 2 - w_step[4 + 1, 13 + 1] / 2 + w_step[4, 13 - 1] + w_step[4, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 13 - 2] * Dyy[4 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 13 - 2] * (w_step[4 - 2, 13] - 4 * w_step[4 - 1, 13] - 4 * w_step[4 + 1, 13] + w_step[4 + 2, 13])) * dx ** 4 - Dxx[4 - 2, 13 - 2] * dy ** 4 * (w_step[4, 13 - 2] - 4 * w_step[4, 13 - 1] - 4 * w_step[4, 13 + 1] + w_step[4, 13 + 2])) / (6 * Dxx[4 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 13 - 2] * Dyy[4 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[4, 14] = (4 * dx ** 2 * (w_step[4 - 1, 14] + w_step[4 + 1, 14] - w_step[4 - 1, 14 - 1] / 2 - w_step[4 - 1, 14 + 1] / 2 - w_step[4 + 1, 14 - 1] / 2 - w_step[4 + 1, 14 + 1] / 2 + w_step[4, 14 - 1] + w_step[4, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[4 - 2, 14 - 2] * Dyy[4 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[4 - 2, 14 - 2] * (w_step[4 - 2, 14] - 4 * w_step[4 - 1, 14] - 4 * w_step[4 + 1, 14] + w_step[4 + 2, 14])) * dx ** 4 - Dxx[4 - 2, 14 - 2] * dy ** 4 * (w_step[4, 14 - 2] - 4 * w_step[4, 14 - 1] - 4 * w_step[4, 14 + 1] + w_step[4, 14 + 2])) / (6 * Dxx[4 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[4 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[4 - 2, 14 - 2] * Dyy[4 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[4, nx + 1] = 2 * w_step[4, nx + 1 - 1] - w_step[4, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[4 + 1, nx + 1 - 1] - 2 * w_step[4, nx + 1 - 1] + w_step[4 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[4, nx + 1 - 2] - w_step[4, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[4 + 1, nx + 1 - 1] - 2 * w_step[4, nx + 1 - 1] + w_step[4 - 1, nx + 1 - 1]))
        w_step[4, nx + 2] = 2 * w_step[4, nx + 2 - 1] - 2 * w_step[4, nx + 2 - 3] + w_step[4, nx + 2 - 4]

        w_step[5, 0] = (dx ** 2 * (nu - 2) * (w_step[5 - 1, 0 + 1] - w_step[5 - 1, 0 + 3] + w_step[5 + 1, 0 + 1] - w_step[5 + 1, 0 + 3] - 2 * w_step[5, 0 + 1] + 2 * w_step[5, 0 + 3]) * np.sqrt(Dxx[5 - 2, 0] * Dyy[5 - 2, 0]) + 2 * dy ** 2 * Dxx[5 - 2, 0] * (w_step[5, 0 + 1] - w_step[5, 0 + 3] + w_step[5, 0 + 4] / 2)) / (dy ** 2 * Dxx[5 - 2, 0])
        w_step[5, 1] = 2 * w_step[5, 1 + 1] - w_step[5, 1 + 2] - nu * np.sqrt(Dyy[5 - 2, 1 - 1] / Dxx[5 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[5 + 1, 1 + 1] - 2 * w_step[5, 1 + 1] + w_step[5 - 1, 1 + 1])
        w_step[5, 2] = (4 * dx ** 2 * (w_step[5 - 1, 2] + w_step[5 + 1, 2] - w_step[5 - 1, 2 - 1] / 2 - w_step[5 - 1, 2 + 1] / 2 - w_step[5 + 1, 2 - 1] / 2 - w_step[5 + 1, 2 + 1] / 2 + w_step[5, 2 - 1] + w_step[5, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 2 - 2] * Dyy[5 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 2 - 2] * (w_step[5 - 2, 2] - 4 * w_step[5 - 1, 2] - 4 * w_step[5 + 1, 2] + w_step[5 + 2, 2])) * dx ** 4 - Dxx[5 - 2, 2 - 2] * dy ** 4 * (w_step[5, 2 - 2] - 4 * w_step[5, 2 - 1] - 4 * w_step[5, 2 + 1] + w_step[5, 2 + 2])) / (6 * Dxx[5 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 2 - 2] * Dyy[5 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 3] = (4 * dx ** 2 * (w_step[5 - 1, 3] + w_step[5 + 1, 3] - w_step[5 - 1, 3 - 1] / 2 - w_step[5 - 1, 3 + 1] / 2 - w_step[5 + 1, 3 - 1] / 2 - w_step[5 + 1, 3 + 1] / 2 + w_step[5, 3 - 1] + w_step[5, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 3 - 2] * Dyy[5 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 3 - 2] * (w_step[5 - 2, 3] - 4 * w_step[5 - 1, 3] - 4 * w_step[5 + 1, 3] + w_step[5 + 2, 3])) * dx ** 4 - Dxx[5 - 2, 3 - 2] * dy ** 4 * (w_step[5, 3 - 2] - 4 * w_step[5, 3 - 1] - 4 * w_step[5, 3 + 1] + w_step[5, 3 + 2])) / (6 * Dxx[5 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 3 - 2] * Dyy[5 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 4] = (4 * dx ** 2 * (w_step[5 - 1, 4] + w_step[5 + 1, 4] - w_step[5 - 1, 4 - 1] / 2 - w_step[5 - 1, 4 + 1] / 2 - w_step[5 + 1, 4 - 1] / 2 - w_step[5 + 1, 4 + 1] / 2 + w_step[5, 4 - 1] + w_step[5, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 4 - 2] * Dyy[5 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 4 - 2] * (w_step[5 - 2, 4] - 4 * w_step[5 - 1, 4] - 4 * w_step[5 + 1, 4] + w_step[5 + 2, 4])) * dx ** 4 - Dxx[5 - 2, 4 - 2] * dy ** 4 * (w_step[5, 4 - 2] - 4 * w_step[5, 4 - 1] - 4 * w_step[5, 4 + 1] + w_step[5, 4 + 2])) / (6 * Dxx[5 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 4 - 2] * Dyy[5 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 5] = (4 * dx ** 2 * (w_step[5 - 1, 5] + w_step[5 + 1, 5] - w_step[5 - 1, 5 - 1] / 2 - w_step[5 - 1, 5 + 1] / 2 - w_step[5 + 1, 5 - 1] / 2 - w_step[5 + 1, 5 + 1] / 2 + w_step[5, 5 - 1] + w_step[5, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 5 - 2] * Dyy[5 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 5 - 2] * (w_step[5 - 2, 5] - 4 * w_step[5 - 1, 5] - 4 * w_step[5 + 1, 5] + w_step[5 + 2, 5])) * dx ** 4 - Dxx[5 - 2, 5 - 2] * dy ** 4 * (w_step[5, 5 - 2] - 4 * w_step[5, 5 - 1] - 4 * w_step[5, 5 + 1] + w_step[5, 5 + 2])) / (6 * Dxx[5 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 5 - 2] * Dyy[5 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 6] = (4 * dx ** 2 * (w_step[5 - 1, 6] + w_step[5 + 1, 6] - w_step[5 - 1, 6 - 1] / 2 - w_step[5 - 1, 6 + 1] / 2 - w_step[5 + 1, 6 - 1] / 2 - w_step[5 + 1, 6 + 1] / 2 + w_step[5, 6 - 1] + w_step[5, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 6 - 2] * Dyy[5 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 6 - 2] * (w_step[5 - 2, 6] - 4 * w_step[5 - 1, 6] - 4 * w_step[5 + 1, 6] + w_step[5 + 2, 6])) * dx ** 4 - Dxx[5 - 2, 6 - 2] * dy ** 4 * (w_step[5, 6 - 2] - 4 * w_step[5, 6 - 1] - 4 * w_step[5, 6 + 1] + w_step[5, 6 + 2])) / (6 * Dxx[5 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 6 - 2] * Dyy[5 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 7] = (4 * dx ** 2 * (w_step[5 - 1, 7] + w_step[5 + 1, 7] - w_step[5 - 1, 7 - 1] / 2 - w_step[5 - 1, 7 + 1] / 2 - w_step[5 + 1, 7 - 1] / 2 - w_step[5 + 1, 7 + 1] / 2 + w_step[5, 7 - 1] + w_step[5, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 7 - 2] * Dyy[5 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 7 - 2] * (w_step[5 - 2, 7] - 4 * w_step[5 - 1, 7] - 4 * w_step[5 + 1, 7] + w_step[5 + 2, 7])) * dx ** 4 - Dxx[5 - 2, 7 - 2] * dy ** 4 * (w_step[5, 7 - 2] - 4 * w_step[5, 7 - 1] - 4 * w_step[5, 7 + 1] + w_step[5, 7 + 2])) / (6 * Dxx[5 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 7 - 2] * Dyy[5 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 8] = (4 * dx ** 2 * (w_step[5 - 1, 8] + w_step[5 + 1, 8] - w_step[5 - 1, 8 - 1] / 2 - w_step[5 - 1, 8 + 1] / 2 - w_step[5 + 1, 8 - 1] / 2 - w_step[5 + 1, 8 + 1] / 2 + w_step[5, 8 - 1] + w_step[5, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 8 - 2] * Dyy[5 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 8 - 2] * (w_step[5 - 2, 8] - 4 * w_step[5 - 1, 8] - 4 * w_step[5 + 1, 8] + w_step[5 + 2, 8])) * dx ** 4 - Dxx[5 - 2, 8 - 2] * dy ** 4 * (w_step[5, 8 - 2] - 4 * w_step[5, 8 - 1] - 4 * w_step[5, 8 + 1] + w_step[5, 8 + 2])) / (6 * Dxx[5 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 8 - 2] * Dyy[5 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 9] = (4 * dx ** 2 * (w_step[5 - 1, 9] + w_step[5 + 1, 9] - w_step[5 - 1, 9 - 1] / 2 - w_step[5 - 1, 9 + 1] / 2 - w_step[5 + 1, 9 - 1] / 2 - w_step[5 + 1, 9 + 1] / 2 + w_step[5, 9 - 1] + w_step[5, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 9 - 2] * Dyy[5 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 9 - 2] * (w_step[5 - 2, 9] - 4 * w_step[5 - 1, 9] - 4 * w_step[5 + 1, 9] + w_step[5 + 2, 9])) * dx ** 4 - Dxx[5 - 2, 9 - 2] * dy ** 4 * (w_step[5, 9 - 2] - 4 * w_step[5, 9 - 1] - 4 * w_step[5, 9 + 1] + w_step[5, 9 + 2])) / (6 * Dxx[5 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 9 - 2] * Dyy[5 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 10] = (4 * dx ** 2 * (w_step[5 - 1, 10] + w_step[5 + 1, 10] - w_step[5 - 1, 10 - 1] / 2 - w_step[5 - 1, 10 + 1] / 2 - w_step[5 + 1, 10 - 1] / 2 - w_step[5 + 1, 10 + 1] / 2 + w_step[5, 10 - 1] + w_step[5, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 10 - 2] * Dyy[5 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 10 - 2] * (w_step[5 - 2, 10] - 4 * w_step[5 - 1, 10] - 4 * w_step[5 + 1, 10] + w_step[5 + 2, 10])) * dx ** 4 - Dxx[5 - 2, 10 - 2] * dy ** 4 * (w_step[5, 10 - 2] - 4 * w_step[5, 10 - 1] - 4 * w_step[5, 10 + 1] + w_step[5, 10 + 2])) / (6 * Dxx[5 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 10 - 2] * Dyy[5 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, 11] = (4 * dx ** 2 * (w_step[5 - 1, 11] + w_step[5 + 1, 11] - w_step[5 - 1, 11 - 1] / 2 - w_step[5 - 1, 11 + 1] / 2 - w_step[5 + 1, 11 - 1] / 2 - w_step[5 + 1, 11 + 1] / 2 + w_step[5, 11 - 1] + w_step[5, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 11 - 2] * Dyy[5 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 11 - 2] * (w_step[5 - 2, 11] - 4 * w_step[5 - 1, 11] - 4 * w_step[5 + 1, 11] + w_step[5 + 2, 11])) * dx ** 4 - Dxx[5 - 2, 11 - 2] * dy ** 4 * (w_step[5, 11 - 2] - 4 * w_step[5, 11 - 1] - 4 * w_step[5, 11 + 1] + w_step[5, 11 + 2])) / (6 * Dxx[5 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 11 - 2] * Dyy[5 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[5, 12] = (4 * dx ** 2 * (w_step[5 - 1, 12] + w_step[5 + 1, 12] - w_step[5 - 1, 12 - 1] / 2 - w_step[5 - 1, 12 + 1] / 2 - w_step[5 + 1, 12 - 1] / 2 - w_step[5 + 1, 12 + 1] / 2 + w_step[5, 12 - 1] + w_step[5, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 12 - 2] * Dyy[5 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 12 - 2] * (w_step[5 - 2, 12] - 4 * w_step[5 - 1, 12] - 4 * w_step[5 + 1, 12] + w_step[5 + 2, 12])) * dx ** 4 - Dxx[5 - 2, 12 - 2] * dy ** 4 * (w_step[5, 12 - 2] - 4 * w_step[5, 12 - 1] - 4 * w_step[5, 12 + 1] + w_step[5, 12 + 2])) / (6 * Dxx[5 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 12 - 2] * Dyy[5 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[5, 13] = (4 * dx ** 2 * (w_step[5 - 1, 13] + w_step[5 + 1, 13] - w_step[5 - 1, 13 - 1] / 2 - w_step[5 - 1, 13 + 1] / 2 - w_step[5 + 1, 13 - 1] / 2 - w_step[5 + 1, 13 + 1] / 2 + w_step[5, 13 - 1] + w_step[5, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 13 - 2] * Dyy[5 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 13 - 2] * (w_step[5 - 2, 13] - 4 * w_step[5 - 1, 13] - 4 * w_step[5 + 1, 13] + w_step[5 + 2, 13])) * dx ** 4 - Dxx[5 - 2, 13 - 2] * dy ** 4 * (w_step[5, 13 - 2] - 4 * w_step[5, 13 - 1] - 4 * w_step[5, 13 + 1] + w_step[5, 13 + 2])) / (6 * Dxx[5 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 13 - 2] * Dyy[5 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[5, 14] = (4 * dx ** 2 * (w_step[5 - 1, 14] + w_step[5 + 1, 14] - w_step[5 - 1, 14 - 1] / 2 - w_step[5 - 1, 14 + 1] / 2 - w_step[5 + 1, 14 - 1] / 2 - w_step[5 + 1, 14 + 1] / 2 + w_step[5, 14 - 1] + w_step[5, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[5 - 2, 14 - 2] * Dyy[5 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[5 - 2, 14 - 2] * (w_step[5 - 2, 14] - 4 * w_step[5 - 1, 14] - 4 * w_step[5 + 1, 14] + w_step[5 + 2, 14])) * dx ** 4 - Dxx[5 - 2, 14 - 2] * dy ** 4 * (w_step[5, 14 - 2] - 4 * w_step[5, 14 - 1] - 4 * w_step[5, 14 + 1] + w_step[5, 14 + 2])) / (6 * Dxx[5 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[5 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[5 - 2, 14 - 2] * Dyy[5 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[5, nx + 1] = 2 * w_step[5, nx + 1 - 1] - w_step[5, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[5 + 1, nx + 1 - 1] - 2 * w_step[5, nx + 1 - 1] + w_step[5 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[5, nx + 1 - 2] - w_step[5, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[5 + 1, nx + 1 - 1] - 2 * w_step[5, nx + 1 - 1] + w_step[5 - 1, nx + 1 - 1]))
        w_step[5, nx + 2] = 2 * w_step[5, nx + 2 - 1] - 2 * w_step[5, nx + 2 - 3] + w_step[5, nx + 2 - 4]

        w_step[6, 0] = (dx ** 2 * (nu - 2) * (w_step[6 - 1, 0 + 1] - w_step[6 - 1, 0 + 3] + w_step[6 + 1, 0 + 1] - w_step[6 + 1, 0 + 3] - 2 * w_step[6, 0 + 1] + 2 * w_step[6, 0 + 3]) * np.sqrt(Dxx[6 - 2, 0] * Dyy[6 - 2, 0]) + 2 * dy ** 2 * Dxx[6 - 2, 0] * (w_step[6, 0 + 1] - w_step[6, 0 + 3] + w_step[6, 0 + 4] / 2)) / (dy ** 2 * Dxx[6 - 2, 0])
        w_step[6, 1] = 2 * w_step[6, 1 + 1] - w_step[6, 1 + 2] - nu * np.sqrt(Dyy[6 - 2, 1 - 1] / Dxx[6 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[6 + 1, 1 + 1] - 2 * w_step[6, 1 + 1] + w_step[6 - 1, 1 + 1])
        w_step[6, 2] = (4 * dx ** 2 * (w_step[6 - 1, 2] + w_step[6 + 1, 2] - w_step[6 - 1, 2 - 1] / 2 - w_step[6 - 1, 2 + 1] / 2 - w_step[6 + 1, 2 - 1] / 2 - w_step[6 + 1, 2 + 1] / 2 + w_step[6, 2 - 1] + w_step[6, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 2 - 2] * Dyy[6 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 2 - 2] * (w_step[6 - 2, 2] - 4 * w_step[6 - 1, 2] - 4 * w_step[6 + 1, 2] + w_step[6 + 2, 2])) * dx ** 4 - Dxx[6 - 2, 2 - 2] * dy ** 4 * (w_step[6, 2 - 2] - 4 * w_step[6, 2 - 1] - 4 * w_step[6, 2 + 1] + w_step[6, 2 + 2])) / (6 * Dxx[6 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 2 - 2] * Dyy[6 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 3] = (4 * dx ** 2 * (w_step[6 - 1, 3] + w_step[6 + 1, 3] - w_step[6 - 1, 3 - 1] / 2 - w_step[6 - 1, 3 + 1] / 2 - w_step[6 + 1, 3 - 1] / 2 - w_step[6 + 1, 3 + 1] / 2 + w_step[6, 3 - 1] + w_step[6, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 3 - 2] * Dyy[6 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 3 - 2] * (w_step[6 - 2, 3] - 4 * w_step[6 - 1, 3] - 4 * w_step[6 + 1, 3] + w_step[6 + 2, 3])) * dx ** 4 - Dxx[6 - 2, 3 - 2] * dy ** 4 * (w_step[6, 3 - 2] - 4 * w_step[6, 3 - 1] - 4 * w_step[6, 3 + 1] + w_step[6, 3 + 2])) / (6 * Dxx[6 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 3 - 2] * Dyy[6 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 4] = (4 * dx ** 2 * (w_step[6 - 1, 4] + w_step[6 + 1, 4] - w_step[6 - 1, 4 - 1] / 2 - w_step[6 - 1, 4 + 1] / 2 - w_step[6 + 1, 4 - 1] / 2 - w_step[6 + 1, 4 + 1] / 2 + w_step[6, 4 - 1] + w_step[6, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 4 - 2] * Dyy[6 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 4 - 2] * (w_step[6 - 2, 4] - 4 * w_step[6 - 1, 4] - 4 * w_step[6 + 1, 4] + w_step[6 + 2, 4])) * dx ** 4 - Dxx[6 - 2, 4 - 2] * dy ** 4 * (w_step[6, 4 - 2] - 4 * w_step[6, 4 - 1] - 4 * w_step[6, 4 + 1] + w_step[6, 4 + 2])) / (6 * Dxx[6 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 4 - 2] * Dyy[6 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 5] = (4 * dx ** 2 * (w_step[6 - 1, 5] + w_step[6 + 1, 5] - w_step[6 - 1, 5 - 1] / 2 - w_step[6 - 1, 5 + 1] / 2 - w_step[6 + 1, 5 - 1] / 2 - w_step[6 + 1, 5 + 1] / 2 + w_step[6, 5 - 1] + w_step[6, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 5 - 2] * Dyy[6 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 5 - 2] * (w_step[6 - 2, 5] - 4 * w_step[6 - 1, 5] - 4 * w_step[6 + 1, 5] + w_step[6 + 2, 5])) * dx ** 4 - Dxx[6 - 2, 5 - 2] * dy ** 4 * (w_step[6, 5 - 2] - 4 * w_step[6, 5 - 1] - 4 * w_step[6, 5 + 1] + w_step[6, 5 + 2])) / (6 * Dxx[6 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 5 - 2] * Dyy[6 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 6] = (4 * dx ** 2 * (w_step[6 - 1, 6] + w_step[6 + 1, 6] - w_step[6 - 1, 6 - 1] / 2 - w_step[6 - 1, 6 + 1] / 2 - w_step[6 + 1, 6 - 1] / 2 - w_step[6 + 1, 6 + 1] / 2 + w_step[6, 6 - 1] + w_step[6, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 6 - 2] * Dyy[6 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 6 - 2] * (w_step[6 - 2, 6] - 4 * w_step[6 - 1, 6] - 4 * w_step[6 + 1, 6] + w_step[6 + 2, 6])) * dx ** 4 - Dxx[6 - 2, 6 - 2] * dy ** 4 * (w_step[6, 6 - 2] - 4 * w_step[6, 6 - 1] - 4 * w_step[6, 6 + 1] + w_step[6, 6 + 2])) / (6 * Dxx[6 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 6 - 2] * Dyy[6 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 7] = (4 * dx ** 2 * (w_step[6 - 1, 7] + w_step[6 + 1, 7] - w_step[6 - 1, 7 - 1] / 2 - w_step[6 - 1, 7 + 1] / 2 - w_step[6 + 1, 7 - 1] / 2 - w_step[6 + 1, 7 + 1] / 2 + w_step[6, 7 - 1] + w_step[6, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 7 - 2] * Dyy[6 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 7 - 2] * (w_step[6 - 2, 7] - 4 * w_step[6 - 1, 7] - 4 * w_step[6 + 1, 7] + w_step[6 + 2, 7])) * dx ** 4 - Dxx[6 - 2, 7 - 2] * dy ** 4 * (w_step[6, 7 - 2] - 4 * w_step[6, 7 - 1] - 4 * w_step[6, 7 + 1] + w_step[6, 7 + 2])) / (6 * Dxx[6 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 7 - 2] * Dyy[6 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 8] = (4 * dx ** 2 * (w_step[6 - 1, 8] + w_step[6 + 1, 8] - w_step[6 - 1, 8 - 1] / 2 - w_step[6 - 1, 8 + 1] / 2 - w_step[6 + 1, 8 - 1] / 2 - w_step[6 + 1, 8 + 1] / 2 + w_step[6, 8 - 1] + w_step[6, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 8 - 2] * Dyy[6 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 8 - 2] * (w_step[6 - 2, 8] - 4 * w_step[6 - 1, 8] - 4 * w_step[6 + 1, 8] + w_step[6 + 2, 8])) * dx ** 4 - Dxx[6 - 2, 8 - 2] * dy ** 4 * (w_step[6, 8 - 2] - 4 * w_step[6, 8 - 1] - 4 * w_step[6, 8 + 1] + w_step[6, 8 + 2])) / (6 * Dxx[6 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 8 - 2] * Dyy[6 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 9] = (4 * dx ** 2 * (w_step[6 - 1, 9] + w_step[6 + 1, 9] - w_step[6 - 1, 9 - 1] / 2 - w_step[6 - 1, 9 + 1] / 2 - w_step[6 + 1, 9 - 1] / 2 - w_step[6 + 1, 9 + 1] / 2 + w_step[6, 9 - 1] + w_step[6, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 9 - 2] * Dyy[6 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 9 - 2] * (w_step[6 - 2, 9] - 4 * w_step[6 - 1, 9] - 4 * w_step[6 + 1, 9] + w_step[6 + 2, 9])) * dx ** 4 - Dxx[6 - 2, 9 - 2] * dy ** 4 * (w_step[6, 9 - 2] - 4 * w_step[6, 9 - 1] - 4 * w_step[6, 9 + 1] + w_step[6, 9 + 2])) / (6 * Dxx[6 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 9 - 2] * Dyy[6 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 10] = (4 * dx ** 2 * (w_step[6 - 1, 10] + w_step[6 + 1, 10] - w_step[6 - 1, 10 - 1] / 2 - w_step[6 - 1, 10 + 1] / 2 - w_step[6 + 1, 10 - 1] / 2 - w_step[6 + 1, 10 + 1] / 2 + w_step[6, 10 - 1] + w_step[6, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 10 - 2] * Dyy[6 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 10 - 2] * (w_step[6 - 2, 10] - 4 * w_step[6 - 1, 10] - 4 * w_step[6 + 1, 10] + w_step[6 + 2, 10])) * dx ** 4 - Dxx[6 - 2, 10 - 2] * dy ** 4 * (w_step[6, 10 - 2] - 4 * w_step[6, 10 - 1] - 4 * w_step[6, 10 + 1] + w_step[6, 10 + 2])) / (6 * Dxx[6 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 10 - 2] * Dyy[6 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, 11] = (4 * dx ** 2 * (w_step[6 - 1, 11] + w_step[6 + 1, 11] - w_step[6 - 1, 11 - 1] / 2 - w_step[6 - 1, 11 + 1] / 2 - w_step[6 + 1, 11 - 1] / 2 - w_step[6 + 1, 11 + 1] / 2 + w_step[6, 11 - 1] + w_step[6, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 11 - 2] * Dyy[6 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 11 - 2] * (w_step[6 - 2, 11] - 4 * w_step[6 - 1, 11] - 4 * w_step[6 + 1, 11] + w_step[6 + 2, 11])) * dx ** 4 - Dxx[6 - 2, 11 - 2] * dy ** 4 * (w_step[6, 11 - 2] - 4 * w_step[6, 11 - 1] - 4 * w_step[6, 11 + 1] + w_step[6, 11 + 2])) / (6 * Dxx[6 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 11 - 2] * Dyy[6 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[6, 12] = (4 * dx ** 2 * (w_step[6 - 1, 12] + w_step[6 + 1, 12] - w_step[6 - 1, 12 - 1] / 2 - w_step[6 - 1, 12 + 1] / 2 - w_step[6 + 1, 12 - 1] / 2 - w_step[6 + 1, 12 + 1] / 2 + w_step[6, 12 - 1] + w_step[6, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 12 - 2] * Dyy[6 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 12 - 2] * (w_step[6 - 2, 12] - 4 * w_step[6 - 1, 12] - 4 * w_step[6 + 1, 12] + w_step[6 + 2, 12])) * dx ** 4 - Dxx[6 - 2, 12 - 2] * dy ** 4 * (w_step[6, 12 - 2] - 4 * w_step[6, 12 - 1] - 4 * w_step[6, 12 + 1] + w_step[6, 12 + 2])) / (6 * Dxx[6 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 12 - 2] * Dyy[6 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[6, 13] = (4 * dx ** 2 * (w_step[6 - 1, 13] + w_step[6 + 1, 13] - w_step[6 - 1, 13 - 1] / 2 - w_step[6 - 1, 13 + 1] / 2 - w_step[6 + 1, 13 - 1] / 2 - w_step[6 + 1, 13 + 1] / 2 + w_step[6, 13 - 1] + w_step[6, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 13 - 2] * Dyy[6 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 13 - 2] * (w_step[6 - 2, 13] - 4 * w_step[6 - 1, 13] - 4 * w_step[6 + 1, 13] + w_step[6 + 2, 13])) * dx ** 4 - Dxx[6 - 2, 13 - 2] * dy ** 4 * (w_step[6, 13 - 2] - 4 * w_step[6, 13 - 1] - 4 * w_step[6, 13 + 1] + w_step[6, 13 + 2])) / (6 * Dxx[6 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 13 - 2] * Dyy[6 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[6, 14] = (4 * dx ** 2 * (w_step[6 - 1, 14] + w_step[6 + 1, 14] - w_step[6 - 1, 14 - 1] / 2 - w_step[6 - 1, 14 + 1] / 2 - w_step[6 + 1, 14 - 1] / 2 - w_step[6 + 1, 14 + 1] / 2 + w_step[6, 14 - 1] + w_step[6, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[6 - 2, 14 - 2] * Dyy[6 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[6 - 2, 14 - 2] * (w_step[6 - 2, 14] - 4 * w_step[6 - 1, 14] - 4 * w_step[6 + 1, 14] + w_step[6 + 2, 14])) * dx ** 4 - Dxx[6 - 2, 14 - 2] * dy ** 4 * (w_step[6, 14 - 2] - 4 * w_step[6, 14 - 1] - 4 * w_step[6, 14 + 1] + w_step[6, 14 + 2])) / (6 * Dxx[6 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[6 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[6 - 2, 14 - 2] * Dyy[6 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[6, nx + 1] = 2 * w_step[6, nx + 1 - 1] - w_step[6, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[6 + 1, nx + 1 - 1] - 2 * w_step[6, nx + 1 - 1] + w_step[6 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[6, nx + 1 - 2] - w_step[6, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[6 + 1, nx + 1 - 1] - 2 * w_step[6, nx + 1 - 1] + w_step[6 - 1, nx + 1 - 1]))
        w_step[6, nx + 2] = 2 * w_step[6, nx + 2 - 1] - 2 * w_step[6, nx + 2 - 3] + w_step[6, nx + 2 - 4]

        w_step[7, 0] = (dx ** 2 * (nu - 2) * (w_step[7 - 1, 0 + 1] - w_step[7 - 1, 0 + 3] + w_step[7 + 1, 0 + 1] - w_step[7 + 1, 0 + 3] - 2 * w_step[7, 0 + 1] + 2 * w_step[7, 0 + 3]) * np.sqrt(Dxx[7 - 2, 0] * Dyy[7 - 2, 0]) + 2 * dy ** 2 * Dxx[7 - 2, 0] * (w_step[7, 0 + 1] - w_step[7, 0 + 3] + w_step[7, 0 + 4] / 2)) / (dy ** 2 * Dxx[7 - 2, 0])
        w_step[7, 1] = 2 * w_step[7, 1 + 1] - w_step[7, 1 + 2] - nu * np.sqrt(Dyy[7 - 2, 1 - 1] / Dxx[7 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[7 + 1, 1 + 1] - 2 * w_step[7, 1 + 1] + w_step[7 - 1, 1 + 1])
        w_step[7, 2] = (4 * dx ** 2 * (w_step[7 - 1, 2] + w_step[7 + 1, 2] - w_step[7 - 1, 2 - 1] / 2 - w_step[7 - 1, 2 + 1] / 2 - w_step[7 + 1, 2 - 1] / 2 - w_step[7 + 1, 2 + 1] / 2 + w_step[7, 2 - 1] + w_step[7, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 2 - 2] * Dyy[7 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 2 - 2] * (w_step[7 - 2, 2] - 4 * w_step[7 - 1, 2] - 4 * w_step[7 + 1, 2] + w_step[7 + 2, 2])) * dx ** 4 - Dxx[7 - 2, 2 - 2] * dy ** 4 * (w_step[7, 2 - 2] - 4 * w_step[7, 2 - 1] - 4 * w_step[7, 2 + 1] + w_step[7, 2 + 2])) / (6 * Dxx[7 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 2 - 2] * Dyy[7 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 3] = (4 * dx ** 2 * (w_step[7 - 1, 3] + w_step[7 + 1, 3] - w_step[7 - 1, 3 - 1] / 2 - w_step[7 - 1, 3 + 1] / 2 - w_step[7 + 1, 3 - 1] / 2 - w_step[7 + 1, 3 + 1] / 2 + w_step[7, 3 - 1] + w_step[7, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 3 - 2] * Dyy[7 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 3 - 2] * (w_step[7 - 2, 3] - 4 * w_step[7 - 1, 3] - 4 * w_step[7 + 1, 3] + w_step[7 + 2, 3])) * dx ** 4 - Dxx[7 - 2, 3 - 2] * dy ** 4 * (w_step[7, 3 - 2] - 4 * w_step[7, 3 - 1] - 4 * w_step[7, 3 + 1] + w_step[7, 3 + 2])) / (6 * Dxx[7 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 3 - 2] * Dyy[7 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 4] = (4 * dx ** 2 * (w_step[7 - 1, 4] + w_step[7 + 1, 4] - w_step[7 - 1, 4 - 1] / 2 - w_step[7 - 1, 4 + 1] / 2 - w_step[7 + 1, 4 - 1] / 2 - w_step[7 + 1, 4 + 1] / 2 + w_step[7, 4 - 1] + w_step[7, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 4 - 2] * Dyy[7 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 4 - 2] * (w_step[7 - 2, 4] - 4 * w_step[7 - 1, 4] - 4 * w_step[7 + 1, 4] + w_step[7 + 2, 4])) * dx ** 4 - Dxx[7 - 2, 4 - 2] * dy ** 4 * (w_step[7, 4 - 2] - 4 * w_step[7, 4 - 1] - 4 * w_step[7, 4 + 1] + w_step[7, 4 + 2])) / (6 * Dxx[7 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 4 - 2] * Dyy[7 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 5] = (4 * dx ** 2 * (w_step[7 - 1, 5] + w_step[7 + 1, 5] - w_step[7 - 1, 5 - 1] / 2 - w_step[7 - 1, 5 + 1] / 2 - w_step[7 + 1, 5 - 1] / 2 - w_step[7 + 1, 5 + 1] / 2 + w_step[7, 5 - 1] + w_step[7, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 5 - 2] * Dyy[7 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 5 - 2] * (w_step[7 - 2, 5] - 4 * w_step[7 - 1, 5] - 4 * w_step[7 + 1, 5] + w_step[7 + 2, 5])) * dx ** 4 - Dxx[7 - 2, 5 - 2] * dy ** 4 * (w_step[7, 5 - 2] - 4 * w_step[7, 5 - 1] - 4 * w_step[7, 5 + 1] + w_step[7, 5 + 2])) / (6 * Dxx[7 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 5 - 2] * Dyy[7 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 6] = (4 * dx ** 2 * (w_step[7 - 1, 6] + w_step[7 + 1, 6] - w_step[7 - 1, 6 - 1] / 2 - w_step[7 - 1, 6 + 1] / 2 - w_step[7 + 1, 6 - 1] / 2 - w_step[7 + 1, 6 + 1] / 2 + w_step[7, 6 - 1] + w_step[7, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 6 - 2] * Dyy[7 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 6 - 2] * (w_step[7 - 2, 6] - 4 * w_step[7 - 1, 6] - 4 * w_step[7 + 1, 6] + w_step[7 + 2, 6])) * dx ** 4 - Dxx[7 - 2, 6 - 2] * dy ** 4 * (w_step[7, 6 - 2] - 4 * w_step[7, 6 - 1] - 4 * w_step[7, 6 + 1] + w_step[7, 6 + 2])) / (6 * Dxx[7 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 6 - 2] * Dyy[7 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 7] = (4 * dx ** 2 * (w_step[7 - 1, 7] + w_step[7 + 1, 7] - w_step[7 - 1, 7 - 1] / 2 - w_step[7 - 1, 7 + 1] / 2 - w_step[7 + 1, 7 - 1] / 2 - w_step[7 + 1, 7 + 1] / 2 + w_step[7, 7 - 1] + w_step[7, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 7 - 2] * Dyy[7 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 7 - 2] * (w_step[7 - 2, 7] - 4 * w_step[7 - 1, 7] - 4 * w_step[7 + 1, 7] + w_step[7 + 2, 7])) * dx ** 4 - Dxx[7 - 2, 7 - 2] * dy ** 4 * (w_step[7, 7 - 2] - 4 * w_step[7, 7 - 1] - 4 * w_step[7, 7 + 1] + w_step[7, 7 + 2])) / (6 * Dxx[7 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 7 - 2] * Dyy[7 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 8] = (4 * dx ** 2 * (w_step[7 - 1, 8] + w_step[7 + 1, 8] - w_step[7 - 1, 8 - 1] / 2 - w_step[7 - 1, 8 + 1] / 2 - w_step[7 + 1, 8 - 1] / 2 - w_step[7 + 1, 8 + 1] / 2 + w_step[7, 8 - 1] + w_step[7, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 8 - 2] * Dyy[7 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 8 - 2] * (w_step[7 - 2, 8] - 4 * w_step[7 - 1, 8] - 4 * w_step[7 + 1, 8] + w_step[7 + 2, 8])) * dx ** 4 - Dxx[7 - 2, 8 - 2] * dy ** 4 * (w_step[7, 8 - 2] - 4 * w_step[7, 8 - 1] - 4 * w_step[7, 8 + 1] + w_step[7, 8 + 2])) / (6 * Dxx[7 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 8 - 2] * Dyy[7 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 9] = (4 * dx ** 2 * (w_step[7 - 1, 9] + w_step[7 + 1, 9] - w_step[7 - 1, 9 - 1] / 2 - w_step[7 - 1, 9 + 1] / 2 - w_step[7 + 1, 9 - 1] / 2 - w_step[7 + 1, 9 + 1] / 2 + w_step[7, 9 - 1] + w_step[7, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 9 - 2] * Dyy[7 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 9 - 2] * (w_step[7 - 2, 9] - 4 * w_step[7 - 1, 9] - 4 * w_step[7 + 1, 9] + w_step[7 + 2, 9])) * dx ** 4 - Dxx[7 - 2, 9 - 2] * dy ** 4 * (w_step[7, 9 - 2] - 4 * w_step[7, 9 - 1] - 4 * w_step[7, 9 + 1] + w_step[7, 9 + 2])) / (6 * Dxx[7 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 9 - 2] * Dyy[7 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 10] = (4 * dx ** 2 * (w_step[7 - 1, 10] + w_step[7 + 1, 10] - w_step[7 - 1, 10 - 1] / 2 - w_step[7 - 1, 10 + 1] / 2 - w_step[7 + 1, 10 - 1] / 2 - w_step[7 + 1, 10 + 1] / 2 + w_step[7, 10 - 1] + w_step[7, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 10 - 2] * Dyy[7 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 10 - 2] * (w_step[7 - 2, 10] - 4 * w_step[7 - 1, 10] - 4 * w_step[7 + 1, 10] + w_step[7 + 2, 10])) * dx ** 4 - Dxx[7 - 2, 10 - 2] * dy ** 4 * (w_step[7, 10 - 2] - 4 * w_step[7, 10 - 1] - 4 * w_step[7, 10 + 1] + w_step[7, 10 + 2])) / (6 * Dxx[7 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 10 - 2] * Dyy[7 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, 11] = (4 * dx ** 2 * (w_step[7 - 1, 11] + w_step[7 + 1, 11] - w_step[7 - 1, 11 - 1] / 2 - w_step[7 - 1, 11 + 1] / 2 - w_step[7 + 1, 11 - 1] / 2 - w_step[7 + 1, 11 + 1] / 2 + w_step[7, 11 - 1] + w_step[7, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 11 - 2] * Dyy[7 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 11 - 2] * (w_step[7 - 2, 11] - 4 * w_step[7 - 1, 11] - 4 * w_step[7 + 1, 11] + w_step[7 + 2, 11])) * dx ** 4 - Dxx[7 - 2, 11 - 2] * dy ** 4 * (w_step[7, 11 - 2] - 4 * w_step[7, 11 - 1] - 4 * w_step[7, 11 + 1] + w_step[7, 11 + 2])) / (6 * Dxx[7 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 11 - 2] * Dyy[7 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[7, 12] = (4 * dx ** 2 * (w_step[7 - 1, 12] + w_step[7 + 1, 12] - w_step[7 - 1, 12 - 1] / 2 - w_step[7 - 1, 12 + 1] / 2 - w_step[7 + 1, 12 - 1] / 2 - w_step[7 + 1, 12 + 1] / 2 + w_step[7, 12 - 1] + w_step[7, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 12 - 2] * Dyy[7 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 12 - 2] * (w_step[7 - 2, 12] - 4 * w_step[7 - 1, 12] - 4 * w_step[7 + 1, 12] + w_step[7 + 2, 12])) * dx ** 4 - Dxx[7 - 2, 12 - 2] * dy ** 4 * (w_step[7, 12 - 2] - 4 * w_step[7, 12 - 1] - 4 * w_step[7, 12 + 1] + w_step[7, 12 + 2])) / (6 * Dxx[7 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 12 - 2] * Dyy[7 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[7, 13] = (4 * dx ** 2 * (w_step[7 - 1, 13] + w_step[7 + 1, 13] - w_step[7 - 1, 13 - 1] / 2 - w_step[7 - 1, 13 + 1] / 2 - w_step[7 + 1, 13 - 1] / 2 - w_step[7 + 1, 13 + 1] / 2 + w_step[7, 13 - 1] + w_step[7, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 13 - 2] * Dyy[7 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 13 - 2] * (w_step[7 - 2, 13] - 4 * w_step[7 - 1, 13] - 4 * w_step[7 + 1, 13] + w_step[7 + 2, 13])) * dx ** 4 - Dxx[7 - 2, 13 - 2] * dy ** 4 * (w_step[7, 13 - 2] - 4 * w_step[7, 13 - 1] - 4 * w_step[7, 13 + 1] + w_step[7, 13 + 2])) / (6 * Dxx[7 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 13 - 2] * Dyy[7 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[7, 14] = (4 * dx ** 2 * (w_step[7 - 1, 14] + w_step[7 + 1, 14] - w_step[7 - 1, 14 - 1] / 2 - w_step[7 - 1, 14 + 1] / 2 - w_step[7 + 1, 14 - 1] / 2 - w_step[7 + 1, 14 + 1] / 2 + w_step[7, 14 - 1] + w_step[7, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[7 - 2, 14 - 2] * Dyy[7 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[7 - 2, 14 - 2] * (w_step[7 - 2, 14] - 4 * w_step[7 - 1, 14] - 4 * w_step[7 + 1, 14] + w_step[7 + 2, 14])) * dx ** 4 - Dxx[7 - 2, 14 - 2] * dy ** 4 * (w_step[7, 14 - 2] - 4 * w_step[7, 14 - 1] - 4 * w_step[7, 14 + 1] + w_step[7, 14 + 2])) / (6 * Dxx[7 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[7 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[7 - 2, 14 - 2] * Dyy[7 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[7, nx + 1] = 2 * w_step[7, nx + 1 - 1] - w_step[7, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[7 + 1, nx + 1 - 1] - 2 * w_step[7, nx + 1 - 1] + w_step[7 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[7, nx + 1 - 2] - w_step[7, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[7 + 1, nx + 1 - 1] - 2 * w_step[7, nx + 1 - 1] + w_step[7 - 1, nx + 1 - 1]))
        w_step[7, nx + 2] = 2 * w_step[7, nx + 2 - 1] - 2 * w_step[7, nx + 2 - 3] + w_step[7, nx + 2 - 4]

        w_step[8, 0] = (dx ** 2 * (nu - 2) * (w_step[8 - 1, 0 + 1] - w_step[8 - 1, 0 + 3] + w_step[8 + 1, 0 + 1] - w_step[8 + 1, 0 + 3] - 2 * w_step[8, 0 + 1] + 2 * w_step[8, 0 + 3]) * np.sqrt(Dxx[8 - 2, 0] * Dyy[8 - 2, 0]) + 2 * dy ** 2 * Dxx[8 - 2, 0] * (w_step[8, 0 + 1] - w_step[8, 0 + 3] + w_step[8, 0 + 4] / 2)) / (dy ** 2 * Dxx[8 - 2, 0])
        w_step[8, 1] = 2 * w_step[8, 1 + 1] - w_step[8, 1 + 2] - nu * np.sqrt(Dyy[8 - 2, 1 - 1] / Dxx[8 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[8 + 1, 1 + 1] - 2 * w_step[8, 1 + 1] + w_step[8 - 1, 1 + 1])
        w_step[8, 2] = (4 * dx ** 2 * (w_step[8 - 1, 2] + w_step[8 + 1, 2] - w_step[8 - 1, 2 - 1] / 2 - w_step[8 - 1, 2 + 1] / 2 - w_step[8 + 1, 2 - 1] / 2 - w_step[8 + 1, 2 + 1] / 2 + w_step[8, 2 - 1] + w_step[8, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 2 - 2] * Dyy[8 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 2 - 2] * (w_step[8 - 2, 2] - 4 * w_step[8 - 1, 2] - 4 * w_step[8 + 1, 2] + w_step[8 + 2, 2])) * dx ** 4 - Dxx[8 - 2, 2 - 2] * dy ** 4 * (w_step[8, 2 - 2] - 4 * w_step[8, 2 - 1] - 4 * w_step[8, 2 + 1] + w_step[8, 2 + 2])) / (6 * Dxx[8 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 2 - 2] * Dyy[8 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 3] = (4 * dx ** 2 * (w_step[8 - 1, 3] + w_step[8 + 1, 3] - w_step[8 - 1, 3 - 1] / 2 - w_step[8 - 1, 3 + 1] / 2 - w_step[8 + 1, 3 - 1] / 2 - w_step[8 + 1, 3 + 1] / 2 + w_step[8, 3 - 1] + w_step[8, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 3 - 2] * Dyy[8 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 3 - 2] * (w_step[8 - 2, 3] - 4 * w_step[8 - 1, 3] - 4 * w_step[8 + 1, 3] + w_step[8 + 2, 3])) * dx ** 4 - Dxx[8 - 2, 3 - 2] * dy ** 4 * (w_step[8, 3 - 2] - 4 * w_step[8, 3 - 1] - 4 * w_step[8, 3 + 1] + w_step[8, 3 + 2])) / (6 * Dxx[8 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 3 - 2] * Dyy[8 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 4] = (4 * dx ** 2 * (w_step[8 - 1, 4] + w_step[8 + 1, 4] - w_step[8 - 1, 4 - 1] / 2 - w_step[8 - 1, 4 + 1] / 2 - w_step[8 + 1, 4 - 1] / 2 - w_step[8 + 1, 4 + 1] / 2 + w_step[8, 4 - 1] + w_step[8, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 4 - 2] * Dyy[8 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 4 - 2] * (w_step[8 - 2, 4] - 4 * w_step[8 - 1, 4] - 4 * w_step[8 + 1, 4] + w_step[8 + 2, 4])) * dx ** 4 - Dxx[8 - 2, 4 - 2] * dy ** 4 * (w_step[8, 4 - 2] - 4 * w_step[8, 4 - 1] - 4 * w_step[8, 4 + 1] + w_step[8, 4 + 2])) / (6 * Dxx[8 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 4 - 2] * Dyy[8 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 5] = (4 * dx ** 2 * (w_step[8 - 1, 5] + w_step[8 + 1, 5] - w_step[8 - 1, 5 - 1] / 2 - w_step[8 - 1, 5 + 1] / 2 - w_step[8 + 1, 5 - 1] / 2 - w_step[8 + 1, 5 + 1] / 2 + w_step[8, 5 - 1] + w_step[8, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 5 - 2] * Dyy[8 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 5 - 2] * (w_step[8 - 2, 5] - 4 * w_step[8 - 1, 5] - 4 * w_step[8 + 1, 5] + w_step[8 + 2, 5])) * dx ** 4 - Dxx[8 - 2, 5 - 2] * dy ** 4 * (w_step[8, 5 - 2] - 4 * w_step[8, 5 - 1] - 4 * w_step[8, 5 + 1] + w_step[8, 5 + 2])) / (6 * Dxx[8 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 5 - 2] * Dyy[8 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 6] = (4 * dx ** 2 * (w_step[8 - 1, 6] + w_step[8 + 1, 6] - w_step[8 - 1, 6 - 1] / 2 - w_step[8 - 1, 6 + 1] / 2 - w_step[8 + 1, 6 - 1] / 2 - w_step[8 + 1, 6 + 1] / 2 + w_step[8, 6 - 1] + w_step[8, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 6 - 2] * Dyy[8 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 6 - 2] * (w_step[8 - 2, 6] - 4 * w_step[8 - 1, 6] - 4 * w_step[8 + 1, 6] + w_step[8 + 2, 6])) * dx ** 4 - Dxx[8 - 2, 6 - 2] * dy ** 4 * (w_step[8, 6 - 2] - 4 * w_step[8, 6 - 1] - 4 * w_step[8, 6 + 1] + w_step[8, 6 + 2])) / (6 * Dxx[8 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 6 - 2] * Dyy[8 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 7] = (4 * dx ** 2 * (w_step[8 - 1, 7] + w_step[8 + 1, 7] - w_step[8 - 1, 7 - 1] / 2 - w_step[8 - 1, 7 + 1] / 2 - w_step[8 + 1, 7 - 1] / 2 - w_step[8 + 1, 7 + 1] / 2 + w_step[8, 7 - 1] + w_step[8, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 7 - 2] * Dyy[8 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 7 - 2] * (w_step[8 - 2, 7] - 4 * w_step[8 - 1, 7] - 4 * w_step[8 + 1, 7] + w_step[8 + 2, 7])) * dx ** 4 - Dxx[8 - 2, 7 - 2] * dy ** 4 * (w_step[8, 7 - 2] - 4 * w_step[8, 7 - 1] - 4 * w_step[8, 7 + 1] + w_step[8, 7 + 2])) / (6 * Dxx[8 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 7 - 2] * Dyy[8 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 8] = (4 * dx ** 2 * (w_step[8 - 1, 8] + w_step[8 + 1, 8] - w_step[8 - 1, 8 - 1] / 2 - w_step[8 - 1, 8 + 1] / 2 - w_step[8 + 1, 8 - 1] / 2 - w_step[8 + 1, 8 + 1] / 2 + w_step[8, 8 - 1] + w_step[8, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 8 - 2] * Dyy[8 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 8 - 2] * (w_step[8 - 2, 8] - 4 * w_step[8 - 1, 8] - 4 * w_step[8 + 1, 8] + w_step[8 + 2, 8])) * dx ** 4 - Dxx[8 - 2, 8 - 2] * dy ** 4 * (w_step[8, 8 - 2] - 4 * w_step[8, 8 - 1] - 4 * w_step[8, 8 + 1] + w_step[8, 8 + 2])) / (6 * Dxx[8 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 8 - 2] * Dyy[8 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 9] = (4 * dx ** 2 * (w_step[8 - 1, 9] + w_step[8 + 1, 9] - w_step[8 - 1, 9 - 1] / 2 - w_step[8 - 1, 9 + 1] / 2 - w_step[8 + 1, 9 - 1] / 2 - w_step[8 + 1, 9 + 1] / 2 + w_step[8, 9 - 1] + w_step[8, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 9 - 2] * Dyy[8 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 9 - 2] * (w_step[8 - 2, 9] - 4 * w_step[8 - 1, 9] - 4 * w_step[8 + 1, 9] + w_step[8 + 2, 9])) * dx ** 4 - Dxx[8 - 2, 9 - 2] * dy ** 4 * (w_step[8, 9 - 2] - 4 * w_step[8, 9 - 1] - 4 * w_step[8, 9 + 1] + w_step[8, 9 + 2])) / (6 * Dxx[8 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 9 - 2] * Dyy[8 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 10] = (4 * dx ** 2 * (w_step[8 - 1, 10] + w_step[8 + 1, 10] - w_step[8 - 1, 10 - 1] / 2 - w_step[8 - 1, 10 + 1] / 2 - w_step[8 + 1, 10 - 1] / 2 - w_step[8 + 1, 10 + 1] / 2 + w_step[8, 10 - 1] + w_step[8, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 10 - 2] * Dyy[8 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 10 - 2] * (w_step[8 - 2, 10] - 4 * w_step[8 - 1, 10] - 4 * w_step[8 + 1, 10] + w_step[8 + 2, 10])) * dx ** 4 - Dxx[8 - 2, 10 - 2] * dy ** 4 * (w_step[8, 10 - 2] - 4 * w_step[8, 10 - 1] - 4 * w_step[8, 10 + 1] + w_step[8, 10 + 2])) / (6 * Dxx[8 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 10 - 2] * Dyy[8 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, 11] = (4 * dx ** 2 * (w_step[8 - 1, 11] + w_step[8 + 1, 11] - w_step[8 - 1, 11 - 1] / 2 - w_step[8 - 1, 11 + 1] / 2 - w_step[8 + 1, 11 - 1] / 2 - w_step[8 + 1, 11 + 1] / 2 + w_step[8, 11 - 1] + w_step[8, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 11 - 2] * Dyy[8 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 11 - 2] * (w_step[8 - 2, 11] - 4 * w_step[8 - 1, 11] - 4 * w_step[8 + 1, 11] + w_step[8 + 2, 11])) * dx ** 4 - Dxx[8 - 2, 11 - 2] * dy ** 4 * (w_step[8, 11 - 2] - 4 * w_step[8, 11 - 1] - 4 * w_step[8, 11 + 1] + w_step[8, 11 + 2])) / (6 * Dxx[8 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 11 - 2] * Dyy[8 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[8, 12] = (4 * dx ** 2 * (w_step[8 - 1, 12] + w_step[8 + 1, 12] - w_step[8 - 1, 12 - 1] / 2 - w_step[8 - 1, 12 + 1] / 2 - w_step[8 + 1, 12 - 1] / 2 - w_step[8 + 1, 12 + 1] / 2 + w_step[8, 12 - 1] + w_step[8, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 12 - 2] * Dyy[8 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 12 - 2] * (w_step[8 - 2, 12] - 4 * w_step[8 - 1, 12] - 4 * w_step[8 + 1, 12] + w_step[8 + 2, 12])) * dx ** 4 - Dxx[8 - 2, 12 - 2] * dy ** 4 * (w_step[8, 12 - 2] - 4 * w_step[8, 12 - 1] - 4 * w_step[8, 12 + 1] + w_step[8, 12 + 2])) / (6 * Dxx[8 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 12 - 2] * Dyy[8 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[8, 13] = (4 * dx ** 2 * (w_step[8 - 1, 13] + w_step[8 + 1, 13] - w_step[8 - 1, 13 - 1] / 2 - w_step[8 - 1, 13 + 1] / 2 - w_step[8 + 1, 13 - 1] / 2 - w_step[8 + 1, 13 + 1] / 2 + w_step[8, 13 - 1] + w_step[8, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 13 - 2] * Dyy[8 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 13 - 2] * (w_step[8 - 2, 13] - 4 * w_step[8 - 1, 13] - 4 * w_step[8 + 1, 13] + w_step[8 + 2, 13])) * dx ** 4 - Dxx[8 - 2, 13 - 2] * dy ** 4 * (w_step[8, 13 - 2] - 4 * w_step[8, 13 - 1] - 4 * w_step[8, 13 + 1] + w_step[8, 13 + 2])) / (6 * Dxx[8 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 13 - 2] * Dyy[8 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[8, 14] = (4 * dx ** 2 * (w_step[8 - 1, 14] + w_step[8 + 1, 14] - w_step[8 - 1, 14 - 1] / 2 - w_step[8 - 1, 14 + 1] / 2 - w_step[8 + 1, 14 - 1] / 2 - w_step[8 + 1, 14 + 1] / 2 + w_step[8, 14 - 1] + w_step[8, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[8 - 2, 14 - 2] * Dyy[8 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[8 - 2, 14 - 2] * (w_step[8 - 2, 14] - 4 * w_step[8 - 1, 14] - 4 * w_step[8 + 1, 14] + w_step[8 + 2, 14])) * dx ** 4 - Dxx[8 - 2, 14 - 2] * dy ** 4 * (w_step[8, 14 - 2] - 4 * w_step[8, 14 - 1] - 4 * w_step[8, 14 + 1] + w_step[8, 14 + 2])) / (6 * Dxx[8 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[8 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[8 - 2, 14 - 2] * Dyy[8 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[8, nx + 1] = 2 * w_step[8, nx + 1 - 1] - w_step[8, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[8 + 1, nx + 1 - 1] - 2 * w_step[8, nx + 1 - 1] + w_step[8 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[8, nx + 1 - 2] - w_step[8, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[8 + 1, nx + 1 - 1] - 2 * w_step[8, nx + 1 - 1] + w_step[8 - 1, nx + 1 - 1]))
        w_step[8, nx + 2] = 2 * w_step[8, nx + 2 - 1] - 2 * w_step[8, nx + 2 - 3] + w_step[8, nx + 2 - 4]

        w_step[9, 0] = (dx ** 2 * (nu - 2) * (w_step[9 - 1, 0 + 1] - w_step[9 - 1, 0 + 3] + w_step[9 + 1, 0 + 1] - w_step[9 + 1, 0 + 3] - 2 * w_step[9, 0 + 1] + 2 * w_step[9, 0 + 3]) * np.sqrt(Dxx[9 - 2, 0] * Dyy[9 - 2, 0]) + 2 * dy ** 2 * Dxx[9 - 2, 0] * (w_step[9, 0 + 1] - w_step[9, 0 + 3] + w_step[9, 0 + 4] / 2)) / (dy ** 2 * Dxx[9 - 2, 0])
        w_step[9, 1] = 2 * w_step[9, 1 + 1] - w_step[9, 1 + 2] - nu * np.sqrt(Dyy[9 - 2, 1 - 1] / Dxx[9 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[9 + 1, 1 + 1] - 2 * w_step[9, 1 + 1] + w_step[9 - 1, 1 + 1])
        w_step[9, 2] = (4 * dx ** 2 * (w_step[9 - 1, 2] + w_step[9 + 1, 2] - w_step[9 - 1, 2 - 1] / 2 - w_step[9 - 1, 2 + 1] / 2 - w_step[9 + 1, 2 - 1] / 2 - w_step[9 + 1, 2 + 1] / 2 + w_step[9, 2 - 1] + w_step[9, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 2 - 2] * Dyy[9 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 2 - 2] * (w_step[9 - 2, 2] - 4 * w_step[9 - 1, 2] - 4 * w_step[9 + 1, 2] + w_step[9 + 2, 2])) * dx ** 4 - Dxx[9 - 2, 2 - 2] * dy ** 4 * (w_step[9, 2 - 2] - 4 * w_step[9, 2 - 1] - 4 * w_step[9, 2 + 1] + w_step[9, 2 + 2])) / (6 * Dxx[9 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 2 - 2] * Dyy[9 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 3] = (4 * dx ** 2 * (w_step[9 - 1, 3] + w_step[9 + 1, 3] - w_step[9 - 1, 3 - 1] / 2 - w_step[9 - 1, 3 + 1] / 2 - w_step[9 + 1, 3 - 1] / 2 - w_step[9 + 1, 3 + 1] / 2 + w_step[9, 3 - 1] + w_step[9, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 3 - 2] * Dyy[9 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 3 - 2] * (w_step[9 - 2, 3] - 4 * w_step[9 - 1, 3] - 4 * w_step[9 + 1, 3] + w_step[9 + 2, 3])) * dx ** 4 - Dxx[9 - 2, 3 - 2] * dy ** 4 * (w_step[9, 3 - 2] - 4 * w_step[9, 3 - 1] - 4 * w_step[9, 3 + 1] + w_step[9, 3 + 2])) / (6 * Dxx[9 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 3 - 2] * Dyy[9 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 4] = (4 * dx ** 2 * (w_step[9 - 1, 4] + w_step[9 + 1, 4] - w_step[9 - 1, 4 - 1] / 2 - w_step[9 - 1, 4 + 1] / 2 - w_step[9 + 1, 4 - 1] / 2 - w_step[9 + 1, 4 + 1] / 2 + w_step[9, 4 - 1] + w_step[9, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 4 - 2] * Dyy[9 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 4 - 2] * (w_step[9 - 2, 4] - 4 * w_step[9 - 1, 4] - 4 * w_step[9 + 1, 4] + w_step[9 + 2, 4])) * dx ** 4 - Dxx[9 - 2, 4 - 2] * dy ** 4 * (w_step[9, 4 - 2] - 4 * w_step[9, 4 - 1] - 4 * w_step[9, 4 + 1] + w_step[9, 4 + 2])) / (6 * Dxx[9 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 4 - 2] * Dyy[9 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 5] = (4 * dx ** 2 * (w_step[9 - 1, 5] + w_step[9 + 1, 5] - w_step[9 - 1, 5 - 1] / 2 - w_step[9 - 1, 5 + 1] / 2 - w_step[9 + 1, 5 - 1] / 2 - w_step[9 + 1, 5 + 1] / 2 + w_step[9, 5 - 1] + w_step[9, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 5 - 2] * Dyy[9 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 5 - 2] * (w_step[9 - 2, 5] - 4 * w_step[9 - 1, 5] - 4 * w_step[9 + 1, 5] + w_step[9 + 2, 5])) * dx ** 4 - Dxx[9 - 2, 5 - 2] * dy ** 4 * (w_step[9, 5 - 2] - 4 * w_step[9, 5 - 1] - 4 * w_step[9, 5 + 1] + w_step[9, 5 + 2])) / (6 * Dxx[9 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 5 - 2] * Dyy[9 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 6] = (4 * dx ** 2 * (w_step[9 - 1, 6] + w_step[9 + 1, 6] - w_step[9 - 1, 6 - 1] / 2 - w_step[9 - 1, 6 + 1] / 2 - w_step[9 + 1, 6 - 1] / 2 - w_step[9 + 1, 6 + 1] / 2 + w_step[9, 6 - 1] + w_step[9, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 6 - 2] * Dyy[9 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 6 - 2] * (w_step[9 - 2, 6] - 4 * w_step[9 - 1, 6] - 4 * w_step[9 + 1, 6] + w_step[9 + 2, 6])) * dx ** 4 - Dxx[9 - 2, 6 - 2] * dy ** 4 * (w_step[9, 6 - 2] - 4 * w_step[9, 6 - 1] - 4 * w_step[9, 6 + 1] + w_step[9, 6 + 2])) / (6 * Dxx[9 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 6 - 2] * Dyy[9 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 7] = (4 * dx ** 2 * (w_step[9 - 1, 7] + w_step[9 + 1, 7] - w_step[9 - 1, 7 - 1] / 2 - w_step[9 - 1, 7 + 1] / 2 - w_step[9 + 1, 7 - 1] / 2 - w_step[9 + 1, 7 + 1] / 2 + w_step[9, 7 - 1] + w_step[9, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 7 - 2] * Dyy[9 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 7 - 2] * (w_step[9 - 2, 7] - 4 * w_step[9 - 1, 7] - 4 * w_step[9 + 1, 7] + w_step[9 + 2, 7])) * dx ** 4 - Dxx[9 - 2, 7 - 2] * dy ** 4 * (w_step[9, 7 - 2] - 4 * w_step[9, 7 - 1] - 4 * w_step[9, 7 + 1] + w_step[9, 7 + 2])) / (6 * Dxx[9 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 7 - 2] * Dyy[9 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 8] = (4 * dx ** 2 * (w_step[9 - 1, 8] + w_step[9 + 1, 8] - w_step[9 - 1, 8 - 1] / 2 - w_step[9 - 1, 8 + 1] / 2 - w_step[9 + 1, 8 - 1] / 2 - w_step[9 + 1, 8 + 1] / 2 + w_step[9, 8 - 1] + w_step[9, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 8 - 2] * Dyy[9 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 8 - 2] * (w_step[9 - 2, 8] - 4 * w_step[9 - 1, 8] - 4 * w_step[9 + 1, 8] + w_step[9 + 2, 8])) * dx ** 4 - Dxx[9 - 2, 8 - 2] * dy ** 4 * (w_step[9, 8 - 2] - 4 * w_step[9, 8 - 1] - 4 * w_step[9, 8 + 1] + w_step[9, 8 + 2])) / (6 * Dxx[9 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 8 - 2] * Dyy[9 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 9] = (4 * dx ** 2 * (w_step[9 - 1, 9] + w_step[9 + 1, 9] - w_step[9 - 1, 9 - 1] / 2 - w_step[9 - 1, 9 + 1] / 2 - w_step[9 + 1, 9 - 1] / 2 - w_step[9 + 1, 9 + 1] / 2 + w_step[9, 9 - 1] + w_step[9, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 9 - 2] * Dyy[9 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 9 - 2] * (w_step[9 - 2, 9] - 4 * w_step[9 - 1, 9] - 4 * w_step[9 + 1, 9] + w_step[9 + 2, 9])) * dx ** 4 - Dxx[9 - 2, 9 - 2] * dy ** 4 * (w_step[9, 9 - 2] - 4 * w_step[9, 9 - 1] - 4 * w_step[9, 9 + 1] + w_step[9, 9 + 2])) / (6 * Dxx[9 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 9 - 2] * Dyy[9 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 10] = (4 * dx ** 2 * (w_step[9 - 1, 10] + w_step[9 + 1, 10] - w_step[9 - 1, 10 - 1] / 2 - w_step[9 - 1, 10 + 1] / 2 - w_step[9 + 1, 10 - 1] / 2 - w_step[9 + 1, 10 + 1] / 2 + w_step[9, 10 - 1] + w_step[9, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 10 - 2] * Dyy[9 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 10 - 2] * (w_step[9 - 2, 10] - 4 * w_step[9 - 1, 10] - 4 * w_step[9 + 1, 10] + w_step[9 + 2, 10])) * dx ** 4 - Dxx[9 - 2, 10 - 2] * dy ** 4 * (w_step[9, 10 - 2] - 4 * w_step[9, 10 - 1] - 4 * w_step[9, 10 + 1] + w_step[9, 10 + 2])) / (6 * Dxx[9 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 10 - 2] * Dyy[9 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, 11] = (4 * dx ** 2 * (w_step[9 - 1, 11] + w_step[9 + 1, 11] - w_step[9 - 1, 11 - 1] / 2 - w_step[9 - 1, 11 + 1] / 2 - w_step[9 + 1, 11 - 1] / 2 - w_step[9 + 1, 11 + 1] / 2 + w_step[9, 11 - 1] + w_step[9, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 11 - 2] * Dyy[9 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 11 - 2] * (w_step[9 - 2, 11] - 4 * w_step[9 - 1, 11] - 4 * w_step[9 + 1, 11] + w_step[9 + 2, 11])) * dx ** 4 - Dxx[9 - 2, 11 - 2] * dy ** 4 * (w_step[9, 11 - 2] - 4 * w_step[9, 11 - 1] - 4 * w_step[9, 11 + 1] + w_step[9, 11 + 2])) / (6 * Dxx[9 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 11 - 2] * Dyy[9 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[9, 12] = (4 * dx ** 2 * (w_step[9 - 1, 12] + w_step[9 + 1, 12] - w_step[9 - 1, 12 - 1] / 2 - w_step[9 - 1, 12 + 1] / 2 - w_step[9 + 1, 12 - 1] / 2 - w_step[9 + 1, 12 + 1] / 2 + w_step[9, 12 - 1] + w_step[9, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 12 - 2] * Dyy[9 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 12 - 2] * (w_step[9 - 2, 12] - 4 * w_step[9 - 1, 12] - 4 * w_step[9 + 1, 12] + w_step[9 + 2, 12])) * dx ** 4 - Dxx[9 - 2, 12 - 2] * dy ** 4 * (w_step[9, 12 - 2] - 4 * w_step[9, 12 - 1] - 4 * w_step[9, 12 + 1] + w_step[9, 12 + 2])) / (6 * Dxx[9 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 12 - 2] * Dyy[9 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[9, 13] = (4 * dx ** 2 * (w_step[9 - 1, 13] + w_step[9 + 1, 13] - w_step[9 - 1, 13 - 1] / 2 - w_step[9 - 1, 13 + 1] / 2 - w_step[9 + 1, 13 - 1] / 2 - w_step[9 + 1, 13 + 1] / 2 + w_step[9, 13 - 1] + w_step[9, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 13 - 2] * Dyy[9 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 13 - 2] * (w_step[9 - 2, 13] - 4 * w_step[9 - 1, 13] - 4 * w_step[9 + 1, 13] + w_step[9 + 2, 13])) * dx ** 4 - Dxx[9 - 2, 13 - 2] * dy ** 4 * (w_step[9, 13 - 2] - 4 * w_step[9, 13 - 1] - 4 * w_step[9, 13 + 1] + w_step[9, 13 + 2])) / (6 * Dxx[9 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 13 - 2] * Dyy[9 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[9, 14] = (4 * dx ** 2 * (w_step[9 - 1, 14] + w_step[9 + 1, 14] - w_step[9 - 1, 14 - 1] / 2 - w_step[9 - 1, 14 + 1] / 2 - w_step[9 + 1, 14 - 1] / 2 - w_step[9 + 1, 14 + 1] / 2 + w_step[9, 14 - 1] + w_step[9, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[9 - 2, 14 - 2] * Dyy[9 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[9 - 2, 14 - 2] * (w_step[9 - 2, 14] - 4 * w_step[9 - 1, 14] - 4 * w_step[9 + 1, 14] + w_step[9 + 2, 14])) * dx ** 4 - Dxx[9 - 2, 14 - 2] * dy ** 4 * (w_step[9, 14 - 2] - 4 * w_step[9, 14 - 1] - 4 * w_step[9, 14 + 1] + w_step[9, 14 + 2])) / (6 * Dxx[9 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[9 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[9 - 2, 14 - 2] * Dyy[9 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[9, nx + 1] = 2 * w_step[9, nx + 1 - 1] - w_step[9, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[9 + 1, nx + 1 - 1] - 2 * w_step[9, nx + 1 - 1] + w_step[9 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[9, nx + 1 - 2] - w_step[9, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[9 + 1, nx + 1 - 1] - 2 * w_step[9, nx + 1 - 1] + w_step[9 - 1, nx + 1 - 1]))
        w_step[9, nx + 2] = 2 * w_step[9, nx + 2 - 1] - 2 * w_step[9, nx + 2 - 3] + w_step[9, nx + 2 - 4]

        w_step[10, 0] = (dx ** 2 * (nu - 2) * (w_step[10 - 1, 0 + 1] - w_step[10 - 1, 0 + 3] + w_step[10 + 1, 0 + 1] - w_step[10 + 1, 0 + 3] - 2 * w_step[10, 0 + 1] + 2 * w_step[10, 0 + 3]) * np.sqrt(Dxx[10 - 2, 0] * Dyy[10 - 2, 0]) + 2 * dy ** 2 * Dxx[10 - 2, 0] * (w_step[10, 0 + 1] - w_step[10, 0 + 3] + w_step[10, 0 + 4] / 2)) / (dy ** 2 * Dxx[10 - 2, 0])
        w_step[10, 1] = 2 * w_step[10, 1 + 1] - w_step[10, 1 + 2] - nu * np.sqrt(Dyy[10 - 2, 1 - 1] / Dxx[10 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[10 + 1, 1 + 1] - 2 * w_step[10, 1 + 1] + w_step[10 - 1, 1 + 1])
        w_step[10, 2] = (4 * dx ** 2 * (w_step[10 - 1, 2] + w_step[10 + 1, 2] - w_step[10 - 1, 2 - 1] / 2 - w_step[10 - 1, 2 + 1] / 2 - w_step[10 + 1, 2 - 1] / 2 - w_step[10 + 1, 2 + 1] / 2 + w_step[10, 2 - 1] + w_step[10, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 2 - 2] * Dyy[10 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 2 - 2] * (w_step[10 - 2, 2] - 4 * w_step[10 - 1, 2] - 4 * w_step[10 + 1, 2] + w_step[10 + 2, 2])) * dx ** 4 - Dxx[10 - 2, 2 - 2] * dy ** 4 * (w_step[10, 2 - 2] - 4 * w_step[10, 2 - 1] - 4 * w_step[10, 2 + 1] + w_step[10, 2 + 2])) / (6 * Dxx[10 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 2 - 2] * Dyy[10 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 3] = (4 * dx ** 2 * (w_step[10 - 1, 3] + w_step[10 + 1, 3] - w_step[10 - 1, 3 - 1] / 2 - w_step[10 - 1, 3 + 1] / 2 - w_step[10 + 1, 3 - 1] / 2 - w_step[10 + 1, 3 + 1] / 2 + w_step[10, 3 - 1] + w_step[10, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 3 - 2] * Dyy[10 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 3 - 2] * (w_step[10 - 2, 3] - 4 * w_step[10 - 1, 3] - 4 * w_step[10 + 1, 3] + w_step[10 + 2, 3])) * dx ** 4 - Dxx[10 - 2, 3 - 2] * dy ** 4 * (w_step[10, 3 - 2] - 4 * w_step[10, 3 - 1] - 4 * w_step[10, 3 + 1] + w_step[10, 3 + 2])) / (6 * Dxx[10 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 3 - 2] * Dyy[10 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 4] = (4 * dx ** 2 * (w_step[10 - 1, 4] + w_step[10 + 1, 4] - w_step[10 - 1, 4 - 1] / 2 - w_step[10 - 1, 4 + 1] / 2 - w_step[10 + 1, 4 - 1] / 2 - w_step[10 + 1, 4 + 1] / 2 + w_step[10, 4 - 1] + w_step[10, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 4 - 2] * Dyy[10 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 4 - 2] * (w_step[10 - 2, 4] - 4 * w_step[10 - 1, 4] - 4 * w_step[10 + 1, 4] + w_step[10 + 2, 4])) * dx ** 4 - Dxx[10 - 2, 4 - 2] * dy ** 4 * (w_step[10, 4 - 2] - 4 * w_step[10, 4 - 1] - 4 * w_step[10, 4 + 1] + w_step[10, 4 + 2])) / (6 * Dxx[10 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 4 - 2] * Dyy[10 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 5] = (4 * dx ** 2 * (w_step[10 - 1, 5] + w_step[10 + 1, 5] - w_step[10 - 1, 5 - 1] / 2 - w_step[10 - 1, 5 + 1] / 2 - w_step[10 + 1, 5 - 1] / 2 - w_step[10 + 1, 5 + 1] / 2 + w_step[10, 5 - 1] + w_step[10, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 5 - 2] * Dyy[10 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 5 - 2] * (w_step[10 - 2, 5] - 4 * w_step[10 - 1, 5] - 4 * w_step[10 + 1, 5] + w_step[10 + 2, 5])) * dx ** 4 - Dxx[10 - 2, 5 - 2] * dy ** 4 * (w_step[10, 5 - 2] - 4 * w_step[10, 5 - 1] - 4 * w_step[10, 5 + 1] + w_step[10, 5 + 2])) / (6 * Dxx[10 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 5 - 2] * Dyy[10 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 6] = (4 * dx ** 2 * (w_step[10 - 1, 6] + w_step[10 + 1, 6] - w_step[10 - 1, 6 - 1] / 2 - w_step[10 - 1, 6 + 1] / 2 - w_step[10 + 1, 6 - 1] / 2 - w_step[10 + 1, 6 + 1] / 2 + w_step[10, 6 - 1] + w_step[10, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 6 - 2] * Dyy[10 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 6 - 2] * (w_step[10 - 2, 6] - 4 * w_step[10 - 1, 6] - 4 * w_step[10 + 1, 6] + w_step[10 + 2, 6])) * dx ** 4 - Dxx[10 - 2, 6 - 2] * dy ** 4 * (w_step[10, 6 - 2] - 4 * w_step[10, 6 - 1] - 4 * w_step[10, 6 + 1] + w_step[10, 6 + 2])) / (6 * Dxx[10 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 6 - 2] * Dyy[10 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 7] = (4 * dx ** 2 * (w_step[10 - 1, 7] + w_step[10 + 1, 7] - w_step[10 - 1, 7 - 1] / 2 - w_step[10 - 1, 7 + 1] / 2 - w_step[10 + 1, 7 - 1] / 2 - w_step[10 + 1, 7 + 1] / 2 + w_step[10, 7 - 1] + w_step[10, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 7 - 2] * Dyy[10 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 7 - 2] * (w_step[10 - 2, 7] - 4 * w_step[10 - 1, 7] - 4 * w_step[10 + 1, 7] + w_step[10 + 2, 7])) * dx ** 4 - Dxx[10 - 2, 7 - 2] * dy ** 4 * (w_step[10, 7 - 2] - 4 * w_step[10, 7 - 1] - 4 * w_step[10, 7 + 1] + w_step[10, 7 + 2])) / (6 * Dxx[10 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 7 - 2] * Dyy[10 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 8] = (4 * dx ** 2 * (w_step[10 - 1, 8] + w_step[10 + 1, 8] - w_step[10 - 1, 8 - 1] / 2 - w_step[10 - 1, 8 + 1] / 2 - w_step[10 + 1, 8 - 1] / 2 - w_step[10 + 1, 8 + 1] / 2 + w_step[10, 8 - 1] + w_step[10, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 8 - 2] * Dyy[10 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 8 - 2] * (w_step[10 - 2, 8] - 4 * w_step[10 - 1, 8] - 4 * w_step[10 + 1, 8] + w_step[10 + 2, 8])) * dx ** 4 - Dxx[10 - 2, 8 - 2] * dy ** 4 * (w_step[10, 8 - 2] - 4 * w_step[10, 8 - 1] - 4 * w_step[10, 8 + 1] + w_step[10, 8 + 2])) / (6 * Dxx[10 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 8 - 2] * Dyy[10 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 9] = (4 * dx ** 2 * (w_step[10 - 1, 9] + w_step[10 + 1, 9] - w_step[10 - 1, 9 - 1] / 2 - w_step[10 - 1, 9 + 1] / 2 - w_step[10 + 1, 9 - 1] / 2 - w_step[10 + 1, 9 + 1] / 2 + w_step[10, 9 - 1] + w_step[10, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 9 - 2] * Dyy[10 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 9 - 2] * (w_step[10 - 2, 9] - 4 * w_step[10 - 1, 9] - 4 * w_step[10 + 1, 9] + w_step[10 + 2, 9])) * dx ** 4 - Dxx[10 - 2, 9 - 2] * dy ** 4 * (w_step[10, 9 - 2] - 4 * w_step[10, 9 - 1] - 4 * w_step[10, 9 + 1] + w_step[10, 9 + 2])) / (6 * Dxx[10 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 9 - 2] * Dyy[10 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 10] = (4 * dx ** 2 * (w_step[10 - 1, 10] + w_step[10 + 1, 10] - w_step[10 - 1, 10 - 1] / 2 - w_step[10 - 1, 10 + 1] / 2 - w_step[10 + 1, 10 - 1] / 2 - w_step[10 + 1, 10 + 1] / 2 + w_step[10, 10 - 1] + w_step[10, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 10 - 2] * Dyy[10 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 10 - 2] * (w_step[10 - 2, 10] - 4 * w_step[10 - 1, 10] - 4 * w_step[10 + 1, 10] + w_step[10 + 2, 10])) * dx ** 4 - Dxx[10 - 2, 10 - 2] * dy ** 4 * (w_step[10, 10 - 2] - 4 * w_step[10, 10 - 1] - 4 * w_step[10, 10 + 1] + w_step[10, 10 + 2])) / (6 * Dxx[10 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 10 - 2] * Dyy[10 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, 11] = (4 * dx ** 2 * (w_step[10 - 1, 11] + w_step[10 + 1, 11] - w_step[10 - 1, 11 - 1] / 2 - w_step[10 - 1, 11 + 1] / 2 - w_step[10 + 1, 11 - 1] / 2 - w_step[10 + 1, 11 + 1] / 2 + w_step[10, 11 - 1] + w_step[10, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 11 - 2] * Dyy[10 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 11 - 2] * (w_step[10 - 2, 11] - 4 * w_step[10 - 1, 11] - 4 * w_step[10 + 1, 11] + w_step[10 + 2, 11])) * dx ** 4 - Dxx[10 - 2, 11 - 2] * dy ** 4 * (w_step[10, 11 - 2] - 4 * w_step[10, 11 - 1] - 4 * w_step[10, 11 + 1] + w_step[10, 11 + 2])) / (6 * Dxx[10 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 11 - 2] * Dyy[10 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[10, 12] = (4 * dx ** 2 * (w_step[10 - 1, 12] + w_step[10 + 1, 12] - w_step[10 - 1, 12 - 1] / 2 - w_step[10 - 1, 12 + 1] / 2 - w_step[10 + 1, 12 - 1] / 2 - w_step[10 + 1, 12 + 1] / 2 + w_step[10, 12 - 1] + w_step[10, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 12 - 2] * Dyy[10 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 12 - 2] * (w_step[10 - 2, 12] - 4 * w_step[10 - 1, 12] - 4 * w_step[10 + 1, 12] + w_step[10 + 2, 12])) * dx ** 4 - Dxx[10 - 2, 12 - 2] * dy ** 4 * (w_step[10, 12 - 2] - 4 * w_step[10, 12 - 1] - 4 * w_step[10, 12 + 1] + w_step[10, 12 + 2])) / (6 * Dxx[10 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 12 - 2] * Dyy[10 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[10, 13] = (4 * dx ** 2 * (w_step[10 - 1, 13] + w_step[10 + 1, 13] - w_step[10 - 1, 13 - 1] / 2 - w_step[10 - 1, 13 + 1] / 2 - w_step[10 + 1, 13 - 1] / 2 - w_step[10 + 1, 13 + 1] / 2 + w_step[10, 13 - 1] + w_step[10, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 13 - 2] * Dyy[10 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 13 - 2] * (w_step[10 - 2, 13] - 4 * w_step[10 - 1, 13] - 4 * w_step[10 + 1, 13] + w_step[10 + 2, 13])) * dx ** 4 - Dxx[10 - 2, 13 - 2] * dy ** 4 * (w_step[10, 13 - 2] - 4 * w_step[10, 13 - 1] - 4 * w_step[10, 13 + 1] + w_step[10, 13 + 2])) / (6 * Dxx[10 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 13 - 2] * Dyy[10 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[10, 14] = (4 * dx ** 2 * (w_step[10 - 1, 14] + w_step[10 + 1, 14] - w_step[10 - 1, 14 - 1] / 2 - w_step[10 - 1, 14 + 1] / 2 - w_step[10 + 1, 14 - 1] / 2 - w_step[10 + 1, 14 + 1] / 2 + w_step[10, 14 - 1] + w_step[10, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[10 - 2, 14 - 2] * Dyy[10 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[10 - 2, 14 - 2] * (w_step[10 - 2, 14] - 4 * w_step[10 - 1, 14] - 4 * w_step[10 + 1, 14] + w_step[10 + 2, 14])) * dx ** 4 - Dxx[10 - 2, 14 - 2] * dy ** 4 * (w_step[10, 14 - 2] - 4 * w_step[10, 14 - 1] - 4 * w_step[10, 14 + 1] + w_step[10, 14 + 2])) / (6 * Dxx[10 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[10 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[10 - 2, 14 - 2] * Dyy[10 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[10, nx + 1] = 2 * w_step[10, nx + 1 - 1] - w_step[10, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[10 + 1, nx + 1 - 1] - 2 * w_step[10, nx + 1 - 1] + w_step[10 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[10, nx + 1 - 2] - w_step[10, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[10 + 1, nx + 1 - 1] - 2 * w_step[10, nx + 1 - 1] + w_step[10 - 1, nx + 1 - 1]))
        w_step[10, nx + 2] = 2 * w_step[10, nx + 2 - 1] - 2 * w_step[10, nx + 2 - 3] + w_step[10, nx + 2 - 4]

        w_step[11, 0] = (dx ** 2 * (nu - 2) * (w_step[11 - 1, 0 + 1] - w_step[11 - 1, 0 + 3] + w_step[11 + 1, 0 + 1] - w_step[11 + 1, 0 + 3] - 2 * w_step[11, 0 + 1] + 2 * w_step[11, 0 + 3]) * np.sqrt(Dxx[11 - 2, 0] * Dyy[11 - 2, 0]) + 2 * dy ** 2 * Dxx[11 - 2, 0] * (w_step[11, 0 + 1] - w_step[11, 0 + 3] + w_step[11, 0 + 4] / 2)) / (dy ** 2 * Dxx[11 - 2, 0])
        w_step[11, 1] = 2 * w_step[11, 1 + 1] - w_step[11, 1 + 2] - nu * np.sqrt(Dyy[11 - 2, 1 - 1] / Dxx[11 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[11 + 1, 1 + 1] - 2 * w_step[11, 1 + 1] + w_step[11 - 1, 1 + 1])
        w_step[11, 2] = (4 * dx ** 2 * (w_step[11 - 1, 2] + w_step[11 + 1, 2] - w_step[11 - 1, 2 - 1] / 2 - w_step[11 - 1, 2 + 1] / 2 - w_step[11 + 1, 2 - 1] / 2 - w_step[11 + 1, 2 + 1] / 2 + w_step[11, 2 - 1] + w_step[11, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 2 - 2] * Dyy[11 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 2 - 2] * (w_step[11 - 2, 2] - 4 * w_step[11 - 1, 2] - 4 * w_step[11 + 1, 2] + w_step[11 + 2, 2])) * dx ** 4 - Dxx[11 - 2, 2 - 2] * dy ** 4 * (w_step[11, 2 - 2] - 4 * w_step[11, 2 - 1] - 4 * w_step[11, 2 + 1] + w_step[11, 2 + 2])) / (6 * Dxx[11 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 2 - 2] * Dyy[11 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 3] = (4 * dx ** 2 * (w_step[11 - 1, 3] + w_step[11 + 1, 3] - w_step[11 - 1, 3 - 1] / 2 - w_step[11 - 1, 3 + 1] / 2 - w_step[11 + 1, 3 - 1] / 2 - w_step[11 + 1, 3 + 1] / 2 + w_step[11, 3 - 1] + w_step[11, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 3 - 2] * Dyy[11 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 3 - 2] * (w_step[11 - 2, 3] - 4 * w_step[11 - 1, 3] - 4 * w_step[11 + 1, 3] + w_step[11 + 2, 3])) * dx ** 4 - Dxx[11 - 2, 3 - 2] * dy ** 4 * (w_step[11, 3 - 2] - 4 * w_step[11, 3 - 1] - 4 * w_step[11, 3 + 1] + w_step[11, 3 + 2])) / (6 * Dxx[11 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 3 - 2] * Dyy[11 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 4] = (4 * dx ** 2 * (w_step[11 - 1, 4] + w_step[11 + 1, 4] - w_step[11 - 1, 4 - 1] / 2 - w_step[11 - 1, 4 + 1] / 2 - w_step[11 + 1, 4 - 1] / 2 - w_step[11 + 1, 4 + 1] / 2 + w_step[11, 4 - 1] + w_step[11, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 4 - 2] * Dyy[11 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 4 - 2] * (w_step[11 - 2, 4] - 4 * w_step[11 - 1, 4] - 4 * w_step[11 + 1, 4] + w_step[11 + 2, 4])) * dx ** 4 - Dxx[11 - 2, 4 - 2] * dy ** 4 * (w_step[11, 4 - 2] - 4 * w_step[11, 4 - 1] - 4 * w_step[11, 4 + 1] + w_step[11, 4 + 2])) / (6 * Dxx[11 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 4 - 2] * Dyy[11 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 5] = (4 * dx ** 2 * (w_step[11 - 1, 5] + w_step[11 + 1, 5] - w_step[11 - 1, 5 - 1] / 2 - w_step[11 - 1, 5 + 1] / 2 - w_step[11 + 1, 5 - 1] / 2 - w_step[11 + 1, 5 + 1] / 2 + w_step[11, 5 - 1] + w_step[11, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 5 - 2] * Dyy[11 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 5 - 2] * (w_step[11 - 2, 5] - 4 * w_step[11 - 1, 5] - 4 * w_step[11 + 1, 5] + w_step[11 + 2, 5])) * dx ** 4 - Dxx[11 - 2, 5 - 2] * dy ** 4 * (w_step[11, 5 - 2] - 4 * w_step[11, 5 - 1] - 4 * w_step[11, 5 + 1] + w_step[11, 5 + 2])) / (6 * Dxx[11 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 5 - 2] * Dyy[11 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 6] = (4 * dx ** 2 * (w_step[11 - 1, 6] + w_step[11 + 1, 6] - w_step[11 - 1, 6 - 1] / 2 - w_step[11 - 1, 6 + 1] / 2 - w_step[11 + 1, 6 - 1] / 2 - w_step[11 + 1, 6 + 1] / 2 + w_step[11, 6 - 1] + w_step[11, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 6 - 2] * Dyy[11 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 6 - 2] * (w_step[11 - 2, 6] - 4 * w_step[11 - 1, 6] - 4 * w_step[11 + 1, 6] + w_step[11 + 2, 6])) * dx ** 4 - Dxx[11 - 2, 6 - 2] * dy ** 4 * (w_step[11, 6 - 2] - 4 * w_step[11, 6 - 1] - 4 * w_step[11, 6 + 1] + w_step[11, 6 + 2])) / (6 * Dxx[11 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 6 - 2] * Dyy[11 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 7] = (4 * dx ** 2 * (w_step[11 - 1, 7] + w_step[11 + 1, 7] - w_step[11 - 1, 7 - 1] / 2 - w_step[11 - 1, 7 + 1] / 2 - w_step[11 + 1, 7 - 1] / 2 - w_step[11 + 1, 7 + 1] / 2 + w_step[11, 7 - 1] + w_step[11, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 7 - 2] * Dyy[11 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 7 - 2] * (w_step[11 - 2, 7] - 4 * w_step[11 - 1, 7] - 4 * w_step[11 + 1, 7] + w_step[11 + 2, 7])) * dx ** 4 - Dxx[11 - 2, 7 - 2] * dy ** 4 * (w_step[11, 7 - 2] - 4 * w_step[11, 7 - 1] - 4 * w_step[11, 7 + 1] + w_step[11, 7 + 2])) / (6 * Dxx[11 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 7 - 2] * Dyy[11 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 8] = (4 * dx ** 2 * (w_step[11 - 1, 8] + w_step[11 + 1, 8] - w_step[11 - 1, 8 - 1] / 2 - w_step[11 - 1, 8 + 1] / 2 - w_step[11 + 1, 8 - 1] / 2 - w_step[11 + 1, 8 + 1] / 2 + w_step[11, 8 - 1] + w_step[11, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 8 - 2] * Dyy[11 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 8 - 2] * (w_step[11 - 2, 8] - 4 * w_step[11 - 1, 8] - 4 * w_step[11 + 1, 8] + w_step[11 + 2, 8])) * dx ** 4 - Dxx[11 - 2, 8 - 2] * dy ** 4 * (w_step[11, 8 - 2] - 4 * w_step[11, 8 - 1] - 4 * w_step[11, 8 + 1] + w_step[11, 8 + 2])) / (6 * Dxx[11 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 8 - 2] * Dyy[11 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 9] = (4 * dx ** 2 * (w_step[11 - 1, 9] + w_step[11 + 1, 9] - w_step[11 - 1, 9 - 1] / 2 - w_step[11 - 1, 9 + 1] / 2 - w_step[11 + 1, 9 - 1] / 2 - w_step[11 + 1, 9 + 1] / 2 + w_step[11, 9 - 1] + w_step[11, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 9 - 2] * Dyy[11 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 9 - 2] * (w_step[11 - 2, 9] - 4 * w_step[11 - 1, 9] - 4 * w_step[11 + 1, 9] + w_step[11 + 2, 9])) * dx ** 4 - Dxx[11 - 2, 9 - 2] * dy ** 4 * (w_step[11, 9 - 2] - 4 * w_step[11, 9 - 1] - 4 * w_step[11, 9 + 1] + w_step[11, 9 + 2])) / (6 * Dxx[11 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 9 - 2] * Dyy[11 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 10] = (4 * dx ** 2 * (w_step[11 - 1, 10] + w_step[11 + 1, 10] - w_step[11 - 1, 10 - 1] / 2 - w_step[11 - 1, 10 + 1] / 2 - w_step[11 + 1, 10 - 1] / 2 - w_step[11 + 1, 10 + 1] / 2 + w_step[11, 10 - 1] + w_step[11, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 10 - 2] * Dyy[11 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 10 - 2] * (w_step[11 - 2, 10] - 4 * w_step[11 - 1, 10] - 4 * w_step[11 + 1, 10] + w_step[11 + 2, 10])) * dx ** 4 - Dxx[11 - 2, 10 - 2] * dy ** 4 * (w_step[11, 10 - 2] - 4 * w_step[11, 10 - 1] - 4 * w_step[11, 10 + 1] + w_step[11, 10 + 2])) / (6 * Dxx[11 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 10 - 2] * Dyy[11 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, 11] = (4 * dx ** 2 * (w_step[11 - 1, 11] + w_step[11 + 1, 11] - w_step[11 - 1, 11 - 1] / 2 - w_step[11 - 1, 11 + 1] / 2 - w_step[11 + 1, 11 - 1] / 2 - w_step[11 + 1, 11 + 1] / 2 + w_step[11, 11 - 1] + w_step[11, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 11 - 2] * Dyy[11 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 11 - 2] * (w_step[11 - 2, 11] - 4 * w_step[11 - 1, 11] - 4 * w_step[11 + 1, 11] + w_step[11 + 2, 11])) * dx ** 4 - Dxx[11 - 2, 11 - 2] * dy ** 4 * (w_step[11, 11 - 2] - 4 * w_step[11, 11 - 1] - 4 * w_step[11, 11 + 1] + w_step[11, 11 + 2])) / (6 * Dxx[11 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 11 - 2] * Dyy[11 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[11, 12] = (4 * dx ** 2 * (w_step[11 - 1, 12] + w_step[11 + 1, 12] - w_step[11 - 1, 12 - 1] / 2 - w_step[11 - 1, 12 + 1] / 2 - w_step[11 + 1, 12 - 1] / 2 - w_step[11 + 1, 12 + 1] / 2 + w_step[11, 12 - 1] + w_step[11, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 12 - 2] * Dyy[11 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 12 - 2] * (w_step[11 - 2, 12] - 4 * w_step[11 - 1, 12] - 4 * w_step[11 + 1, 12] + w_step[11 + 2, 12])) * dx ** 4 - Dxx[11 - 2, 12 - 2] * dy ** 4 * (w_step[11, 12 - 2] - 4 * w_step[11, 12 - 1] - 4 * w_step[11, 12 + 1] + w_step[11, 12 + 2])) / (6 * Dxx[11 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 12 - 2] * Dyy[11 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[11, 13] = (4 * dx ** 2 * (w_step[11 - 1, 13] + w_step[11 + 1, 13] - w_step[11 - 1, 13 - 1] / 2 - w_step[11 - 1, 13 + 1] / 2 - w_step[11 + 1, 13 - 1] / 2 - w_step[11 + 1, 13 + 1] / 2 + w_step[11, 13 - 1] + w_step[11, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 13 - 2] * Dyy[11 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 13 - 2] * (w_step[11 - 2, 13] - 4 * w_step[11 - 1, 13] - 4 * w_step[11 + 1, 13] + w_step[11 + 2, 13])) * dx ** 4 - Dxx[11 - 2, 13 - 2] * dy ** 4 * (w_step[11, 13 - 2] - 4 * w_step[11, 13 - 1] - 4 * w_step[11, 13 + 1] + w_step[11, 13 + 2])) / (6 * Dxx[11 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 13 - 2] * Dyy[11 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[11, 14] = (4 * dx ** 2 * (w_step[11 - 1, 14] + w_step[11 + 1, 14] - w_step[11 - 1, 14 - 1] / 2 - w_step[11 - 1, 14 + 1] / 2 - w_step[11 + 1, 14 - 1] / 2 - w_step[11 + 1, 14 + 1] / 2 + w_step[11, 14 - 1] + w_step[11, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[11 - 2, 14 - 2] * Dyy[11 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[11 - 2, 14 - 2] * (w_step[11 - 2, 14] - 4 * w_step[11 - 1, 14] - 4 * w_step[11 + 1, 14] + w_step[11 + 2, 14])) * dx ** 4 - Dxx[11 - 2, 14 - 2] * dy ** 4 * (w_step[11, 14 - 2] - 4 * w_step[11, 14 - 1] - 4 * w_step[11, 14 + 1] + w_step[11, 14 + 2])) / (6 * Dxx[11 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[11 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[11 - 2, 14 - 2] * Dyy[11 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        w_step[11, nx + 1] = 2 * w_step[11, nx + 1 - 1] - w_step[11, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[11 + 1, nx + 1 - 1] - 2 * w_step[11, nx + 1 - 1] + w_step[11 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[11, nx + 1 - 2] - w_step[11, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[11 + 1, nx + 1 - 1] - 2 * w_step[11, nx + 1 - 1] + w_step[11 - 1, nx + 1 - 1]))
        w_step[11, nx + 2] = 2 * w_step[11, nx + 2 - 1] - 2 * w_step[11, nx + 2 - 3] + w_step[11, nx + 2 - 4]

        #w_step[12, 0] = (dx ** 2 * (nu - 2) * (w_step[12 - 1, 0 + 1] - w_step[12 - 1, 0 + 3] + w_step[12 + 1, 0 + 1] - w_step[12 + 1, 0 + 3] - 2 * w_step[12, 0 + 1] + 2 * w_step[12, 0 + 3]) * np.sqrt(Dxx[12 - 2, 0] * Dyy[12 - 2, 0]) + 2 * dy ** 2 * Dxx[12 - 2, 0] * (w_step[12, 0 + 1] - w_step[12, 0 + 3] + w_step[12, 0 + 4] / 2)) / (dy ** 2 * Dxx[12 - 2, 0])
        #w_step[12, 1] = 2 * w_step[12, 1 + 1] - w_step[12, 1 + 2] - nu * np.sqrt(Dyy[12 - 2, 1 - 1] / Dxx[12 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[12 + 1, 1 + 1] - 2 * w_step[12, 1 + 1] + w_step[12 - 1, 1 + 1])
        #w_step[12, 2] = (4 * dx ** 2 * (w_step[12 - 1, 2] + w_step[12 + 1, 2] - w_step[12 - 1, 2 - 1] / 2 - w_step[12 - 1, 2 + 1] / 2 - w_step[12 + 1, 2 - 1] / 2 - w_step[12 + 1, 2 + 1] / 2 + w_step[12, 2 - 1] + w_step[12, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 2 - 2] * Dyy[12 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 2 - 2] * (w_step[12 - 2, 2] - 4 * w_step[12 - 1, 2] - 4 * w_step[12 + 1, 2] + w_step[12 + 2, 2])) * dx ** 4 - Dxx[12 - 2, 2 - 2] * dy ** 4 * (w_step[12, 2 - 2] - 4 * w_step[12, 2 - 1] - 4 * w_step[12, 2 + 1] + w_step[12, 2 + 2])) / (6 * Dxx[12 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 2 - 2] * Dyy[12 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 3] = (4 * dx ** 2 * (w_step[12 - 1, 3] + w_step[12 + 1, 3] - w_step[12 - 1, 3 - 1] / 2 - w_step[12 - 1, 3 + 1] / 2 - w_step[12 + 1, 3 - 1] / 2 - w_step[12 + 1, 3 + 1] / 2 + w_step[12, 3 - 1] + w_step[12, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 3 - 2] * Dyy[12 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 3 - 2] * (w_step[12 - 2, 3] - 4 * w_step[12 - 1, 3] - 4 * w_step[12 + 1, 3] + w_step[12 + 2, 3])) * dx ** 4 - Dxx[12 - 2, 3 - 2] * dy ** 4 * (w_step[12, 3 - 2] - 4 * w_step[12, 3 - 1] - 4 * w_step[12, 3 + 1] + w_step[12, 3 + 2])) / (6 * Dxx[12 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 3 - 2] * Dyy[12 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 4] = (4 * dx ** 2 * (w_step[12 - 1, 4] + w_step[12 + 1, 4] - w_step[12 - 1, 4 - 1] / 2 - w_step[12 - 1, 4 + 1] / 2 - w_step[12 + 1, 4 - 1] / 2 - w_step[12 + 1, 4 + 1] / 2 + w_step[12, 4 - 1] + w_step[12, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 4 - 2] * Dyy[12 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 4 - 2] * (w_step[12 - 2, 4] - 4 * w_step[12 - 1, 4] - 4 * w_step[12 + 1, 4] + w_step[12 + 2, 4])) * dx ** 4 - Dxx[12 - 2, 4 - 2] * dy ** 4 * (w_step[12, 4 - 2] - 4 * w_step[12, 4 - 1] - 4 * w_step[12, 4 + 1] + w_step[12, 4 + 2])) / (6 * Dxx[12 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 4 - 2] * Dyy[12 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 5] = (4 * dx ** 2 * (w_step[12 - 1, 5] + w_step[12 + 1, 5] - w_step[12 - 1, 5 - 1] / 2 - w_step[12 - 1, 5 + 1] / 2 - w_step[12 + 1, 5 - 1] / 2 - w_step[12 + 1, 5 + 1] / 2 + w_step[12, 5 - 1] + w_step[12, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 5 - 2] * Dyy[12 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 5 - 2] * (w_step[12 - 2, 5] - 4 * w_step[12 - 1, 5] - 4 * w_step[12 + 1, 5] + w_step[12 + 2, 5])) * dx ** 4 - Dxx[12 - 2, 5 - 2] * dy ** 4 * (w_step[12, 5 - 2] - 4 * w_step[12, 5 - 1] - 4 * w_step[12, 5 + 1] + w_step[12, 5 + 2])) / (6 * Dxx[12 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 5 - 2] * Dyy[12 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 6] = (4 * dx ** 2 * (w_step[12 - 1, 6] + w_step[12 + 1, 6] - w_step[12 - 1, 6 - 1] / 2 - w_step[12 - 1, 6 + 1] / 2 - w_step[12 + 1, 6 - 1] / 2 - w_step[12 + 1, 6 + 1] / 2 + w_step[12, 6 - 1] + w_step[12, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 6 - 2] * Dyy[12 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 6 - 2] * (w_step[12 - 2, 6] - 4 * w_step[12 - 1, 6] - 4 * w_step[12 + 1, 6] + w_step[12 + 2, 6])) * dx ** 4 - Dxx[12 - 2, 6 - 2] * dy ** 4 * (w_step[12, 6 - 2] - 4 * w_step[12, 6 - 1] - 4 * w_step[12, 6 + 1] + w_step[12, 6 + 2])) / (6 * Dxx[12 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 6 - 2] * Dyy[12 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 7] = (4 * dx ** 2 * (w_step[12 - 1, 7] + w_step[12 + 1, 7] - w_step[12 - 1, 7 - 1] / 2 - w_step[12 - 1, 7 + 1] / 2 - w_step[12 + 1, 7 - 1] / 2 - w_step[12 + 1, 7 + 1] / 2 + w_step[12, 7 - 1] + w_step[12, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 7 - 2] * Dyy[12 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 7 - 2] * (w_step[12 - 2, 7] - 4 * w_step[12 - 1, 7] - 4 * w_step[12 + 1, 7] + w_step[12 + 2, 7])) * dx ** 4 - Dxx[12 - 2, 7 - 2] * dy ** 4 * (w_step[12, 7 - 2] - 4 * w_step[12, 7 - 1] - 4 * w_step[12, 7 + 1] + w_step[12, 7 + 2])) / (6 * Dxx[12 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 7 - 2] * Dyy[12 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 8] = (4 * dx ** 2 * (w_step[12 - 1, 8] + w_step[12 + 1, 8] - w_step[12 - 1, 8 - 1] / 2 - w_step[12 - 1, 8 + 1] / 2 - w_step[12 + 1, 8 - 1] / 2 - w_step[12 + 1, 8 + 1] / 2 + w_step[12, 8 - 1] + w_step[12, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 8 - 2] * Dyy[12 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 8 - 2] * (w_step[12 - 2, 8] - 4 * w_step[12 - 1, 8] - 4 * w_step[12 + 1, 8] + w_step[12 + 2, 8])) * dx ** 4 - Dxx[12 - 2, 8 - 2] * dy ** 4 * (w_step[12, 8 - 2] - 4 * w_step[12, 8 - 1] - 4 * w_step[12, 8 + 1] + w_step[12, 8 + 2])) / (6 * Dxx[12 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 8 - 2] * Dyy[12 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 9] = (4 * dx ** 2 * (w_step[12 - 1, 9] + w_step[12 + 1, 9] - w_step[12 - 1, 9 - 1] / 2 - w_step[12 - 1, 9 + 1] / 2 - w_step[12 + 1, 9 - 1] / 2 - w_step[12 + 1, 9 + 1] / 2 + w_step[12, 9 - 1] + w_step[12, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 9 - 2] * Dyy[12 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 9 - 2] * (w_step[12 - 2, 9] - 4 * w_step[12 - 1, 9] - 4 * w_step[12 + 1, 9] + w_step[12 + 2, 9])) * dx ** 4 - Dxx[12 - 2, 9 - 2] * dy ** 4 * (w_step[12, 9 - 2] - 4 * w_step[12, 9 - 1] - 4 * w_step[12, 9 + 1] + w_step[12, 9 + 2])) / (6 * Dxx[12 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 9 - 2] * Dyy[12 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 10] = (4 * dx ** 2 * (w_step[12 - 1, 10] + w_step[12 + 1, 10] - w_step[12 - 1, 10 - 1] / 2 - w_step[12 - 1, 10 + 1] / 2 - w_step[12 + 1, 10 - 1] / 2 - w_step[12 + 1, 10 + 1] / 2 + w_step[12, 10 - 1] + w_step[12, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 10 - 2] * Dyy[12 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 10 - 2] * (w_step[12 - 2, 10] - 4 * w_step[12 - 1, 10] - 4 * w_step[12 + 1, 10] + w_step[12 + 2, 10])) * dx ** 4 - Dxx[12 - 2, 10 - 2] * dy ** 4 * (w_step[12, 10 - 2] - 4 * w_step[12, 10 - 1] - 4 * w_step[12, 10 + 1] + w_step[12, 10 + 2])) / (6 * Dxx[12 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 10 - 2] * Dyy[12 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 11] = (4 * dx ** 2 * (w_step[12 - 1, 11] + w_step[12 + 1, 11] - w_step[12 - 1, 11 - 1] / 2 - w_step[12 - 1, 11 + 1] / 2 - w_step[12 + 1, 11 - 1] / 2 - w_step[12 + 1, 11 + 1] / 2 + w_step[12, 11 - 1] + w_step[12, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 11 - 2] * Dyy[12 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 11 - 2] * (w_step[12 - 2, 11] - 4 * w_step[12 - 1, 11] - 4 * w_step[12 + 1, 11] + w_step[12 + 2, 11])) * dx ** 4 - Dxx[12 - 2, 11 - 2] * dy ** 4 * (w_step[12, 11 - 2] - 4 * w_step[12, 11 - 1] - 4 * w_step[12, 11 + 1] + w_step[12, 11 + 2])) / (6 * Dxx[12 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 11 - 2] * Dyy[12 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 12] = (4 * dx ** 2 * (w_step[12 - 1, 12] + w_step[12 + 1, 12] - w_step[12 - 1, 12 - 1] / 2 - w_step[12 - 1, 12 + 1] / 2 - w_step[12 + 1, 12 - 1] / 2 - w_step[12 + 1, 12 + 1] / 2 + w_step[12, 12 - 1] + w_step[12, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 12 - 2] * Dyy[12 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 12 - 2] * (w_step[12 - 2, 12] - 4 * w_step[12 - 1, 12] - 4 * w_step[12 + 1, 12] + w_step[12 + 2, 12])) * dx ** 4 - Dxx[12 - 2, 12 - 2] * dy ** 4 * (w_step[12, 12 - 2] - 4 * w_step[12, 12 - 1] - 4 * w_step[12, 12 + 1] + w_step[12, 12 + 2])) / (6 * Dxx[12 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 12 - 2] * Dyy[12 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 13] = (4 * dx ** 2 * (w_step[12 - 1, 13] + w_step[12 + 1, 13] - w_step[12 - 1, 13 - 1] / 2 - w_step[12 - 1, 13 + 1] / 2 - w_step[12 + 1, 13 - 1] / 2 - w_step[12 + 1, 13 + 1] / 2 + w_step[12, 13 - 1] + w_step[12, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 13 - 2] * Dyy[12 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 13 - 2] * (w_step[12 - 2, 13] - 4 * w_step[12 - 1, 13] - 4 * w_step[12 + 1, 13] + w_step[12 + 2, 13])) * dx ** 4 - Dxx[12 - 2, 13 - 2] * dy ** 4 * (w_step[12, 13 - 2] - 4 * w_step[12, 13 - 1] - 4 * w_step[12, 13 + 1] + w_step[12, 13 + 2])) / (6 * Dxx[12 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 13 - 2] * Dyy[12 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, 14] = (4 * dx ** 2 * (w_step[12 - 1, 14] + w_step[12 + 1, 14] - w_step[12 - 1, 14 - 1] / 2 - w_step[12 - 1, 14 + 1] / 2 - w_step[12 + 1, 14 - 1] / 2 - w_step[12 + 1, 14 + 1] / 2 + w_step[12, 14 - 1] + w_step[12, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[12 - 2, 14 - 2] * Dyy[12 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[12 - 2, 14 - 2] * (w_step[12 - 2, 14] - 4 * w_step[12 - 1, 14] - 4 * w_step[12 + 1, 14] + w_step[12 + 2, 14])) * dx ** 4 - Dxx[12 - 2, 14 - 2] * dy ** 4 * (w_step[12, 14 - 2] - 4 * w_step[12, 14 - 1] - 4 * w_step[12, 14 + 1] + w_step[12, 14 + 2])) / (6 * Dxx[12 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[12 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[12 - 2, 14 - 2] * Dyy[12 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        #w_step[12, nx + 1] = 2 * w_step[12, nx + 1 - 1] - w_step[12, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[12 + 1, nx + 1 - 1] - 2 * w_step[12, nx + 1 - 1] + w_step[12 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[12, nx + 1 - 2] - w_step[12, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[12 + 1, nx + 1 - 1] - 2 * w_step[12, nx + 1 - 1] + w_step[12 - 1, nx + 1 - 1]))
        #w_step[12, nx + 2] = 2 * w_step[12, nx + 2 - 1] - 2 * w_step[12, nx + 2 - 3] + w_step[12, nx + 2 - 4]

        #w_step[13, 0] = (dx ** 2 * (nu - 2) * (w_step[13 - 1, 0 + 1] - w_step[13 - 1, 0 + 3] + w_step[13 + 1, 0 + 1] - w_step[13 + 1, 0 + 3] - 2 * w_step[13, 0 + 1] + 2 * w_step[13, 0 + 3]) * np.sqrt(Dxx[13 - 2, 0] * Dyy[13 - 2, 0]) + 2 * dy ** 2 * Dxx[13 - 2, 0] * (w_step[13, 0 + 1] - w_step[13, 0 + 3] + w_step[13, 0 + 4] / 2)) / (dy ** 2 * Dxx[13 - 2, 0])
        #w_step[13, 1] = 2 * w_step[13, 1 + 1] - w_step[13, 1 + 2] - nu * np.sqrt(Dyy[13 - 2, 1 - 1] / Dxx[13 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[13 + 1, 1 + 1] - 2 * w_step[13, 1 + 1] + w_step[13 - 1, 1 + 1])
        #w_step[13, 2] = (4 * dx ** 2 * (w_step[13 - 1, 2] + w_step[13 + 1, 2] - w_step[13 - 1, 2 - 1] / 2 - w_step[13 - 1, 2 + 1] / 2 - w_step[13 + 1, 2 - 1] / 2 - w_step[13 + 1, 2 + 1] / 2 + w_step[13, 2 - 1] + w_step[13, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 2 - 2] * Dyy[13 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 2 - 2] * (w_step[13 - 2, 2] - 4 * w_step[13 - 1, 2] - 4 * w_step[13 + 1, 2] + w_step[13 + 2, 2])) * dx ** 4 - Dxx[13 - 2, 2 - 2] * dy ** 4 * (w_step[13, 2 - 2] - 4 * w_step[13, 2 - 1] - 4 * w_step[13, 2 + 1] + w_step[13, 2 + 2])) / (6 * Dxx[13 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 2 - 2] * Dyy[13 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 3] = (4 * dx ** 2 * (w_step[13 - 1, 3] + w_step[13 + 1, 3] - w_step[13 - 1, 3 - 1] / 2 - w_step[13 - 1, 3 + 1] / 2 - w_step[13 + 1, 3 - 1] / 2 - w_step[13 + 1, 3 + 1] / 2 + w_step[13, 3 - 1] + w_step[13, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 3 - 2] * Dyy[13 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 3 - 2] * (w_step[13 - 2, 3] - 4 * w_step[13 - 1, 3] - 4 * w_step[13 + 1, 3] + w_step[13 + 2, 3])) * dx ** 4 - Dxx[13 - 2, 3 - 2] * dy ** 4 * (w_step[13, 3 - 2] - 4 * w_step[13, 3 - 1] - 4 * w_step[13, 3 + 1] + w_step[13, 3 + 2])) / (6 * Dxx[13 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 3 - 2] * Dyy[13 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 4] = (4 * dx ** 2 * (w_step[13 - 1, 4] + w_step[13 + 1, 4] - w_step[13 - 1, 4 - 1] / 2 - w_step[13 - 1, 4 + 1] / 2 - w_step[13 + 1, 4 - 1] / 2 - w_step[13 + 1, 4 + 1] / 2 + w_step[13, 4 - 1] + w_step[13, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 4 - 2] * Dyy[13 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 4 - 2] * (w_step[13 - 2, 4] - 4 * w_step[13 - 1, 4] - 4 * w_step[13 + 1, 4] + w_step[13 + 2, 4])) * dx ** 4 - Dxx[13 - 2, 4 - 2] * dy ** 4 * (w_step[13, 4 - 2] - 4 * w_step[13, 4 - 1] - 4 * w_step[13, 4 + 1] + w_step[13, 4 + 2])) / (6 * Dxx[13 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 4 - 2] * Dyy[13 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 5] = (4 * dx ** 2 * (w_step[13 - 1, 5] + w_step[13 + 1, 5] - w_step[13 - 1, 5 - 1] / 2 - w_step[13 - 1, 5 + 1] / 2 - w_step[13 + 1, 5 - 1] / 2 - w_step[13 + 1, 5 + 1] / 2 + w_step[13, 5 - 1] + w_step[13, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 5 - 2] * Dyy[13 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 5 - 2] * (w_step[13 - 2, 5] - 4 * w_step[13 - 1, 5] - 4 * w_step[13 + 1, 5] + w_step[13 + 2, 5])) * dx ** 4 - Dxx[13 - 2, 5 - 2] * dy ** 4 * (w_step[13, 5 - 2] - 4 * w_step[13, 5 - 1] - 4 * w_step[13, 5 + 1] + w_step[13, 5 + 2])) / (6 * Dxx[13 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 5 - 2] * Dyy[13 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 6] = (4 * dx ** 2 * (w_step[13 - 1, 6] + w_step[13 + 1, 6] - w_step[13 - 1, 6 - 1] / 2 - w_step[13 - 1, 6 + 1] / 2 - w_step[13 + 1, 6 - 1] / 2 - w_step[13 + 1, 6 + 1] / 2 + w_step[13, 6 - 1] + w_step[13, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 6 - 2] * Dyy[13 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 6 - 2] * (w_step[13 - 2, 6] - 4 * w_step[13 - 1, 6] - 4 * w_step[13 + 1, 6] + w_step[13 + 2, 6])) * dx ** 4 - Dxx[13 - 2, 6 - 2] * dy ** 4 * (w_step[13, 6 - 2] - 4 * w_step[13, 6 - 1] - 4 * w_step[13, 6 + 1] + w_step[13, 6 + 2])) / (6 * Dxx[13 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 6 - 2] * Dyy[13 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 7] = (4 * dx ** 2 * (w_step[13 - 1, 7] + w_step[13 + 1, 7] - w_step[13 - 1, 7 - 1] / 2 - w_step[13 - 1, 7 + 1] / 2 - w_step[13 + 1, 7 - 1] / 2 - w_step[13 + 1, 7 + 1] / 2 + w_step[13, 7 - 1] + w_step[13, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 7 - 2] * Dyy[13 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 7 - 2] * (w_step[13 - 2, 7] - 4 * w_step[13 - 1, 7] - 4 * w_step[13 + 1, 7] + w_step[13 + 2, 7])) * dx ** 4 - Dxx[13 - 2, 7 - 2] * dy ** 4 * (w_step[13, 7 - 2] - 4 * w_step[13, 7 - 1] - 4 * w_step[13, 7 + 1] + w_step[13, 7 + 2])) / (6 * Dxx[13 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 7 - 2] * Dyy[13 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 8] = (4 * dx ** 2 * (w_step[13 - 1, 8] + w_step[13 + 1, 8] - w_step[13 - 1, 8 - 1] / 2 - w_step[13 - 1, 8 + 1] / 2 - w_step[13 + 1, 8 - 1] / 2 - w_step[13 + 1, 8 + 1] / 2 + w_step[13, 8 - 1] + w_step[13, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 8 - 2] * Dyy[13 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 8 - 2] * (w_step[13 - 2, 8] - 4 * w_step[13 - 1, 8] - 4 * w_step[13 + 1, 8] + w_step[13 + 2, 8])) * dx ** 4 - Dxx[13 - 2, 8 - 2] * dy ** 4 * (w_step[13, 8 - 2] - 4 * w_step[13, 8 - 1] - 4 * w_step[13, 8 + 1] + w_step[13, 8 + 2])) / (6 * Dxx[13 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 8 - 2] * Dyy[13 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 9] = (4 * dx ** 2 * (w_step[13 - 1, 9] + w_step[13 + 1, 9] - w_step[13 - 1, 9 - 1] / 2 - w_step[13 - 1, 9 + 1] / 2 - w_step[13 + 1, 9 - 1] / 2 - w_step[13 + 1, 9 + 1] / 2 + w_step[13, 9 - 1] + w_step[13, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 9 - 2] * Dyy[13 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 9 - 2] * (w_step[13 - 2, 9] - 4 * w_step[13 - 1, 9] - 4 * w_step[13 + 1, 9] + w_step[13 + 2, 9])) * dx ** 4 - Dxx[13 - 2, 9 - 2] * dy ** 4 * (w_step[13, 9 - 2] - 4 * w_step[13, 9 - 1] - 4 * w_step[13, 9 + 1] + w_step[13, 9 + 2])) / (6 * Dxx[13 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 9 - 2] * Dyy[13 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 10] = (4 * dx ** 2 * (w_step[13 - 1, 10] + w_step[13 + 1, 10] - w_step[13 - 1, 10 - 1] / 2 - w_step[13 - 1, 10 + 1] / 2 - w_step[13 + 1, 10 - 1] / 2 - w_step[13 + 1, 10 + 1] / 2 + w_step[13, 10 - 1] + w_step[13, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 10 - 2] * Dyy[13 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 10 - 2] * (w_step[13 - 2, 10] - 4 * w_step[13 - 1, 10] - 4 * w_step[13 + 1, 10] + w_step[13 + 2, 10])) * dx ** 4 - Dxx[13 - 2, 10 - 2] * dy ** 4 * (w_step[13, 10 - 2] - 4 * w_step[13, 10 - 1] - 4 * w_step[13, 10 + 1] + w_step[13, 10 + 2])) / (6 * Dxx[13 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 10 - 2] * Dyy[13 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 11] = (4 * dx ** 2 * (w_step[13 - 1, 11] + w_step[13 + 1, 11] - w_step[13 - 1, 11 - 1] / 2 - w_step[13 - 1, 11 + 1] / 2 - w_step[13 + 1, 11 - 1] / 2 - w_step[13 + 1, 11 + 1] / 2 + w_step[13, 11 - 1] + w_step[13, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 11 - 2] * Dyy[13 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 11 - 2] * (w_step[13 - 2, 11] - 4 * w_step[13 - 1, 11] - 4 * w_step[13 + 1, 11] + w_step[13 + 2, 11])) * dx ** 4 - Dxx[13 - 2, 11 - 2] * dy ** 4 * (w_step[13, 11 - 2] - 4 * w_step[13, 11 - 1] - 4 * w_step[13, 11 + 1] + w_step[13, 11 + 2])) / (6 * Dxx[13 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 11 - 2] * Dyy[13 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 12] = (4 * dx ** 2 * (w_step[13 - 1, 12] + w_step[13 + 1, 12] - w_step[13 - 1, 12 - 1] / 2 - w_step[13 - 1, 12 + 1] / 2 - w_step[13 + 1, 12 - 1] / 2 - w_step[13 + 1, 12 + 1] / 2 + w_step[13, 12 - 1] + w_step[13, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 12 - 2] * Dyy[13 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 12 - 2] * (w_step[13 - 2, 12] - 4 * w_step[13 - 1, 12] - 4 * w_step[13 + 1, 12] + w_step[13 + 2, 12])) * dx ** 4 - Dxx[13 - 2, 12 - 2] * dy ** 4 * (w_step[13, 12 - 2] - 4 * w_step[13, 12 - 1] - 4 * w_step[13, 12 + 1] + w_step[13, 12 + 2])) / (6 * Dxx[13 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 12 - 2] * Dyy[13 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 13] = (4 * dx ** 2 * (w_step[13 - 1, 13] + w_step[13 + 1, 13] - w_step[13 - 1, 13 - 1] / 2 - w_step[13 - 1, 13 + 1] / 2 - w_step[13 + 1, 13 - 1] / 2 - w_step[13 + 1, 13 + 1] / 2 + w_step[13, 13 - 1] + w_step[13, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 13 - 2] * Dyy[13 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 13 - 2] * (w_step[13 - 2, 13] - 4 * w_step[13 - 1, 13] - 4 * w_step[13 + 1, 13] + w_step[13 + 2, 13])) * dx ** 4 - Dxx[13 - 2, 13 - 2] * dy ** 4 * (w_step[13, 13 - 2] - 4 * w_step[13, 13 - 1] - 4 * w_step[13, 13 + 1] + w_step[13, 13 + 2])) / (6 * Dxx[13 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 13 - 2] * Dyy[13 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, 14] = (4 * dx ** 2 * (w_step[13 - 1, 14] + w_step[13 + 1, 14] - w_step[13 - 1, 14 - 1] / 2 - w_step[13 - 1, 14 + 1] / 2 - w_step[13 + 1, 14 - 1] / 2 - w_step[13 + 1, 14 + 1] / 2 + w_step[13, 14 - 1] + w_step[13, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[13 - 2, 14 - 2] * Dyy[13 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[13 - 2, 14 - 2] * (w_step[13 - 2, 14] - 4 * w_step[13 - 1, 14] - 4 * w_step[13 + 1, 14] + w_step[13 + 2, 14])) * dx ** 4 - Dxx[13 - 2, 14 - 2] * dy ** 4 * (w_step[13, 14 - 2] - 4 * w_step[13, 14 - 1] - 4 * w_step[13, 14 + 1] + w_step[13, 14 + 2])) / (6 * Dxx[13 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[13 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[13 - 2, 14 - 2] * Dyy[13 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        #w_step[13, nx + 1] = 2 * w_step[13, nx + 1 - 1] - w_step[13, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[13 + 1, nx + 1 - 1] - 2 * w_step[13, nx + 1 - 1] + w_step[13 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[13, nx + 1 - 2] - w_step[13, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[13 + 1, nx + 1 - 1] - 2 * w_step[13, nx + 1 - 1] + w_step[13 - 1, nx + 1 - 1]))
        #w_step[13, nx + 2] = 2 * w_step[13, nx + 2 - 1] - 2 * w_step[13, nx + 2 - 3] + w_step[13, nx + 2 - 4]

        #w_step[14, 0] = (dx ** 2 * (nu - 2) * (w_step[14 - 1, 0 + 1] - w_step[14 - 1, 0 + 3] + w_step[14 + 1, 0 + 1] - w_step[14 + 1, 0 + 3] - 2 * w_step[14, 0 + 1] + 2 * w_step[14, 0 + 3]) * np.sqrt(Dxx[14 - 2, 0] * Dyy[14 - 2, 0]) + 2 * dy ** 2 * Dxx[14 - 2, 0] * (w_step[14, 0 + 1] - w_step[14, 0 + 3] + w_step[14, 0 + 4] / 2)) / (dy ** 2 * Dxx[14 - 2, 0])
        #w_step[14, 1] = 2 * w_step[14, 1 + 1] - w_step[14, 1 + 2] - nu * np.sqrt(Dyy[14 - 2, 1 - 1] / Dxx[14 - 2, 1 - 1]) * dx ** 2 / dy ** 2 * (w_step[14 + 1, 1 + 1] - 2 * w_step[14, 1 + 1] + w_step[14 - 1, 1 + 1])
        #w_step[14, 2] = (4 * dx ** 2 * (w_step[14 - 1, 2] + w_step[14 + 1, 2] - w_step[14 - 1, 2 - 1] / 2 - w_step[14 - 1, 2 + 1] / 2 - w_step[14 + 1, 2 - 1] / 2 - w_step[14 + 1, 2 + 1] / 2 + w_step[14, 2 - 1] + w_step[14, 2 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 2 - 2] * Dyy[14 - 2, 2 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 2 - 2] * (w_step[14 - 2, 2] - 4 * w_step[14 - 1, 2] - 4 * w_step[14 + 1, 2] + w_step[14 + 2, 2])) * dx ** 4 - Dxx[14 - 2, 2 - 2] * dy ** 4 * (w_step[14, 2 - 2] - 4 * w_step[14, 2 - 1] - 4 * w_step[14, 2 + 1] + w_step[14, 2 + 2])) / (6 * Dxx[14 - 2, 2 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 2 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 2 - 2] * Dyy[14 - 2, 2 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 3] = (4 * dx ** 2 * (w_step[14 - 1, 3] + w_step[14 + 1, 3] - w_step[14 - 1, 3 - 1] / 2 - w_step[14 - 1, 3 + 1] / 2 - w_step[14 + 1, 3 - 1] / 2 - w_step[14 + 1, 3 + 1] / 2 + w_step[14, 3 - 1] + w_step[14, 3 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 3 - 2] * Dyy[14 - 2, 3 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 3 - 2] * (w_step[14 - 2, 3] - 4 * w_step[14 - 1, 3] - 4 * w_step[14 + 1, 3] + w_step[14 + 2, 3])) * dx ** 4 - Dxx[14 - 2, 3 - 2] * dy ** 4 * (w_step[14, 3 - 2] - 4 * w_step[14, 3 - 1] - 4 * w_step[14, 3 + 1] + w_step[14, 3 + 2])) / (6 * Dxx[14 - 2, 3 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 3 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 3 - 2] * Dyy[14 - 2, 3 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 4] = (4 * dx ** 2 * (w_step[14 - 1, 4] + w_step[14 + 1, 4] - w_step[14 - 1, 4 - 1] / 2 - w_step[14 - 1, 4 + 1] / 2 - w_step[14 + 1, 4 - 1] / 2 - w_step[14 + 1, 4 + 1] / 2 + w_step[14, 4 - 1] + w_step[14, 4 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 4 - 2] * Dyy[14 - 2, 4 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 4 - 2] * (w_step[14 - 2, 4] - 4 * w_step[14 - 1, 4] - 4 * w_step[14 + 1, 4] + w_step[14 + 2, 4])) * dx ** 4 - Dxx[14 - 2, 4 - 2] * dy ** 4 * (w_step[14, 4 - 2] - 4 * w_step[14, 4 - 1] - 4 * w_step[14, 4 + 1] + w_step[14, 4 + 2])) / (6 * Dxx[14 - 2, 4 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 4 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 4 - 2] * Dyy[14 - 2, 4 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 5] = (4 * dx ** 2 * (w_step[14 - 1, 5] + w_step[14 + 1, 5] - w_step[14 - 1, 5 - 1] / 2 - w_step[14 - 1, 5 + 1] / 2 - w_step[14 + 1, 5 - 1] / 2 - w_step[14 + 1, 5 + 1] / 2 + w_step[14, 5 - 1] + w_step[14, 5 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 5 - 2] * Dyy[14 - 2, 5 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 5 - 2] * (w_step[14 - 2, 5] - 4 * w_step[14 - 1, 5] - 4 * w_step[14 + 1, 5] + w_step[14 + 2, 5])) * dx ** 4 - Dxx[14 - 2, 5 - 2] * dy ** 4 * (w_step[14, 5 - 2] - 4 * w_step[14, 5 - 1] - 4 * w_step[14, 5 + 1] + w_step[14, 5 + 2])) / (6 * Dxx[14 - 2, 5 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 5 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 5 - 2] * Dyy[14 - 2, 5 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 6] = (4 * dx ** 2 * (w_step[14 - 1, 6] + w_step[14 + 1, 6] - w_step[14 - 1, 6 - 1] / 2 - w_step[14 - 1, 6 + 1] / 2 - w_step[14 + 1, 6 - 1] / 2 - w_step[14 + 1, 6 + 1] / 2 + w_step[14, 6 - 1] + w_step[14, 6 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 6 - 2] * Dyy[14 - 2, 6 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 6 - 2] * (w_step[14 - 2, 6] - 4 * w_step[14 - 1, 6] - 4 * w_step[14 + 1, 6] + w_step[14 + 2, 6])) * dx ** 4 - Dxx[14 - 2, 6 - 2] * dy ** 4 * (w_step[14, 6 - 2] - 4 * w_step[14, 6 - 1] - 4 * w_step[14, 6 + 1] + w_step[14, 6 + 2])) / (6 * Dxx[14 - 2, 6 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 6 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 6 - 2] * Dyy[14 - 2, 6 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 7] = (4 * dx ** 2 * (w_step[14 - 1, 7] + w_step[14 + 1, 7] - w_step[14 - 1, 7 - 1] / 2 - w_step[14 - 1, 7 + 1] / 2 - w_step[14 + 1, 7 - 1] / 2 - w_step[14 + 1, 7 + 1] / 2 + w_step[14, 7 - 1] + w_step[14, 7 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 7 - 2] * Dyy[14 - 2, 7 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 7 - 2] * (w_step[14 - 2, 7] - 4 * w_step[14 - 1, 7] - 4 * w_step[14 + 1, 7] + w_step[14 + 2, 7])) * dx ** 4 - Dxx[14 - 2, 7 - 2] * dy ** 4 * (w_step[14, 7 - 2] - 4 * w_step[14, 7 - 1] - 4 * w_step[14, 7 + 1] + w_step[14, 7 + 2])) / (6 * Dxx[14 - 2, 7 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 7 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 7 - 2] * Dyy[14 - 2, 7 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 8] = (4 * dx ** 2 * (w_step[14 - 1, 8] + w_step[14 + 1, 8] - w_step[14 - 1, 8 - 1] / 2 - w_step[14 - 1, 8 + 1] / 2 - w_step[14 + 1, 8 - 1] / 2 - w_step[14 + 1, 8 + 1] / 2 + w_step[14, 8 - 1] + w_step[14, 8 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 8 - 2] * Dyy[14 - 2, 8 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 8 - 2] * (w_step[14 - 2, 8] - 4 * w_step[14 - 1, 8] - 4 * w_step[14 + 1, 8] + w_step[14 + 2, 8])) * dx ** 4 - Dxx[14 - 2, 8 - 2] * dy ** 4 * (w_step[14, 8 - 2] - 4 * w_step[14, 8 - 1] - 4 * w_step[14, 8 + 1] + w_step[14, 8 + 2])) / (6 * Dxx[14 - 2, 8 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 8 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 8 - 2] * Dyy[14 - 2, 8 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 9] = (4 * dx ** 2 * (w_step[14 - 1, 9] + w_step[14 + 1, 9] - w_step[14 - 1, 9 - 1] / 2 - w_step[14 - 1, 9 + 1] / 2 - w_step[14 + 1, 9 - 1] / 2 - w_step[14 + 1, 9 + 1] / 2 + w_step[14, 9 - 1] + w_step[14, 9 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 9 - 2] * Dyy[14 - 2, 9 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 9 - 2] * (w_step[14 - 2, 9] - 4 * w_step[14 - 1, 9] - 4 * w_step[14 + 1, 9] + w_step[14 + 2, 9])) * dx ** 4 - Dxx[14 - 2, 9 - 2] * dy ** 4 * (w_step[14, 9 - 2] - 4 * w_step[14, 9 - 1] - 4 * w_step[14, 9 + 1] + w_step[14, 9 + 2])) / (6 * Dxx[14 - 2, 9 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 9 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 9 - 2] * Dyy[14 - 2, 9 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 10] = (4 * dx ** 2 * (w_step[14 - 1, 10] + w_step[14 + 1, 10] - w_step[14 - 1, 10 - 1] / 2 - w_step[14 - 1, 10 + 1] / 2 - w_step[14 + 1, 10 - 1] / 2 - w_step[14 + 1, 10 + 1] / 2 + w_step[14, 10 - 1] + w_step[14, 10 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 10 - 2] * Dyy[14 - 2, 10 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 10 - 2] * (w_step[14 - 2, 10] - 4 * w_step[14 - 1, 10] - 4 * w_step[14 + 1, 10] + w_step[14 + 2, 10])) * dx ** 4 - Dxx[14 - 2, 10 - 2] * dy ** 4 * (w_step[14, 10 - 2] - 4 * w_step[14, 10 - 1] - 4 * w_step[14, 10 + 1] + w_step[14, 10 + 2])) / (6 * Dxx[14 - 2, 10 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 10 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 10 - 2] * Dyy[14 - 2, 10 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 11] = (4 * dx ** 2 * (w_step[14 - 1, 11] + w_step[14 + 1, 11] - w_step[14 - 1, 11 - 1] / 2 - w_step[14 - 1, 11 + 1] / 2 - w_step[14 + 1, 11 - 1] / 2 - w_step[14 + 1, 11 + 1] / 2 + w_step[14, 11 - 1] + w_step[14, 11 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 11 - 2] * Dyy[14 - 2, 11 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 11 - 2] * (w_step[14 - 2, 11] - 4 * w_step[14 - 1, 11] - 4 * w_step[14 + 1, 11] + w_step[14 + 2, 11])) * dx ** 4 - Dxx[14 - 2, 11 - 2] * dy ** 4 * (w_step[14, 11 - 2] - 4 * w_step[14, 11 - 1] - 4 * w_step[14, 11 + 1] + w_step[14, 11 + 2])) / (6 * Dxx[14 - 2, 11 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 11 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 11 - 2] * Dyy[14 - 2, 11 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 12] = (4 * dx ** 2 * (w_step[14 - 1, 12] + w_step[14 + 1, 12] - w_step[14 - 1, 12 - 1] / 2 - w_step[14 - 1, 12 + 1] / 2 - w_step[14 + 1, 12 - 1] / 2 - w_step[14 + 1, 12 + 1] / 2 + w_step[14, 12 - 1] + w_step[14, 12 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 12 - 2] * Dyy[14 - 2, 12 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 12 - 2] * (w_step[14 - 2, 12] - 4 * w_step[14 - 1, 12] - 4 * w_step[14 + 1, 12] + w_step[14 + 2, 12])) * dx ** 4 - Dxx[14 - 2, 12 - 2] * dy ** 4 * (w_step[14, 12 - 2] - 4 * w_step[14, 12 - 1] - 4 * w_step[14, 12 + 1] + w_step[14, 12 + 2])) / (6 * Dxx[14 - 2, 12 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 12 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 12 - 2] * Dyy[14 - 2, 12 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 13] = (4 * dx ** 2 * (w_step[14 - 1, 13] + w_step[14 + 1, 13] - w_step[14 - 1, 13 - 1] / 2 - w_step[14 - 1, 13 + 1] / 2 - w_step[14 + 1, 13 - 1] / 2 - w_step[14 + 1, 13 + 1] / 2 + w_step[14, 13 - 1] + w_step[14, 13 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 13 - 2] * Dyy[14 - 2, 13 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 13 - 2] * (w_step[14 - 2, 13] - 4 * w_step[14 - 1, 13] - 4 * w_step[14 + 1, 13] + w_step[14 + 2, 13])) * dx ** 4 - Dxx[14 - 2, 13 - 2] * dy ** 4 * (w_step[14, 13 - 2] - 4 * w_step[14, 13 - 1] - 4 * w_step[14, 13 + 1] + w_step[14, 13 + 2])) / (6 * Dxx[14 - 2, 13 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 13 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 13 - 2] * Dyy[14 - 2, 13 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, 14] = (4 * dx ** 2 * (w_step[14 - 1, 14] + w_step[14 + 1, 14] - w_step[14 - 1, 14 - 1] / 2 - w_step[14 - 1, 14 + 1] / 2 - w_step[14 + 1, 14 - 1] / 2 - w_step[14 + 1, 14 + 1] / 2 + w_step[14, 14 - 1] + w_step[14, 14 + 1]) * dy ** 2 * np.sqrt(Dxx[14 - 2, 14 - 2] * Dyy[14 - 2, 14 - 2]) + (dq * dy ** 4 - Dyy[14 - 2, 14 - 2] * (w_step[14 - 2, 14] - 4 * w_step[14 - 1, 14] - 4 * w_step[14 + 1, 14] + w_step[14 + 2, 14])) * dx ** 4 - Dxx[14 - 2, 14 - 2] * dy ** 4 * (w_step[14, 14 - 2] - 4 * w_step[14, 14 - 1] - 4 * w_step[14, 14 + 1] + w_step[14, 14 + 2])) / (6 * Dxx[14 - 2, 14 - 2] * dy ** 4 + 6 * Dyy[14 - 2, 14 - 2] * dx ** 4 + 8 * np.sqrt(Dxx[14 - 2, 14 - 2] * Dyy[14 - 2, 14 - 2]) * dx ** 2 * dy ** 2)
        #w_step[14, nx + 1] = 2 * w_step[14, nx + 1 - 1] - w_step[14, nx + 1 - 2] - nu * dx ** 2 / dy ** 2 * (w_step[14 + 1, nx + 1 - 1] - 2 * w_step[14, nx + 1 - 1] + w_step[14 - 1, nx + 1 - 1]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[14, nx + 1 - 2] - w_step[14, nx + 1 - 1] + nu / 2 * dx ** 2 / dy ** 2 * (w_step[14 + 1, nx + 1 - 1] - 2 * w_step[14, nx + 1 - 1] + w_step[14 - 1, nx + 1 - 1]))
        #w_step[14, nx + 2] = 2 * w_step[14, nx + 2 - 1] - 2 * w_step[14, nx + 2 - 3] + w_step[14, nx + 2 - 4]

        w_step[ny+1, 1] = 2 * w_step[ny, 1] - w_step[ny-1, 1] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 1] - w_step[ny, 1])
        w_step[ny+1, 2] = 2 * w_step[ny, 2] - w_step[ny-1, 2] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 2] - w_step[ny, 2])
        w_step[ny+1, 3] = 2 * w_step[ny, 3] - w_step[ny-1, 3] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 3] - w_step[ny, 3])
        w_step[ny+1, 4] = 2 * w_step[ny, 4] - w_step[ny-1, 4] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 4] - w_step[ny, 4])
        w_step[ny+1, 5] = 2 * w_step[ny, 5] - w_step[ny-1, 5] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 5] - w_step[ny, 5])
        w_step[ny+1, 6] = 2 * w_step[ny, 6] - w_step[ny-1, 6] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 6] - w_step[ny, 6])
        w_step[ny+1, 7] = 2 * w_step[ny, 7] - w_step[ny-1, 7] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 7] - w_step[ny, 7])
        w_step[ny+1, 8] = 2 * w_step[ny, 8] - w_step[ny-1, 8] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 8] - w_step[ny, 8])
        w_step[ny+1, 9] = 2 * w_step[ny, 9] - w_step[ny-1, 9] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 9] - w_step[ny, 9])
        w_step[ny+1, 10] = 2 * w_step[ny, 10] - w_step[ny-1, 10] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 10] - w_step[ny, 10])
        w_step[ny + 1, 11] = 2 * w_step[ny, 11] - w_step[ny - 1, 11] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 11] - w_step[ny, 11])
        #w_step[ny + 1, 12] = 2 * w_step[ny, 12] - w_step[ny - 1, 12] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 12] - w_step[ny, 12])
        #w_step[ny + 1, 13] = 2 * w_step[ny, 13] - w_step[ny - 1, 13] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 13] - w_step[ny, 13])
        #w_step[ny + 1, 14] = 2 * w_step[ny, 14] - w_step[ny - 1, 14] + max(curvyy_factor[idx_mid_yplane]) * (w_step[ny - 1, 14] - w_step[ny, 14])
        w_step[ny+1, nx+1] = 2 * w_step[ny, nx] - w_step[ny-1, nx-1] - nu*dx**2/dy**2*(w_step[ny+1, nx] - 2*w_step[ny, nx] + w_step[ny-1, nx]) + max(curvxx_factor[idx_mid_xplane]) * (w_step[ny - 1, nx - 1] - w_step[ny, nx] + nu/2*dx**2/dy**2*(w_step[ny+1, nx] - 2*w_step[ny, nx] + w_step[ny-1, nx]))

        w_step[ny+2, 2] = 2 * w_step[ny+1, 2] - 2 * w_step[ny-1, 2] + w_step[ny-2, 2]
        w_step[ny+2, 3] = 2 * w_step[ny+1, 3] - 2 * w_step[ny-1, 3] + w_step[ny-2, 3]
        w_step[ny+2, 4] = 2 * w_step[ny+1, 4] - 2 * w_step[ny-1, 4] + w_step[ny-2, 4]
        w_step[ny+2, 5] = 2 * w_step[ny+1, 5] - 2 * w_step[ny-1, 5] + w_step[ny-2, 5]
        w_step[ny+2, 6] = 2 * w_step[ny+1, 6] - 2 * w_step[ny-1, 6] + w_step[ny-2, 6]
        w_step[ny+2, 7] = 2 * w_step[ny+1, 7] - 2 * w_step[ny-1, 7] + w_step[ny-2, 7]
        w_step[ny+2, 8] = 2 * w_step[ny+1, 8] - 2 * w_step[ny-1, 8] + w_step[ny-2, 8]
        w_step[ny+2, 9] = 2 * w_step[ny+1, 9] - 2 * w_step[ny-1, 9] + w_step[ny-2, 9]
        w_step[ny+2, 10] = 2 * w_step[ny+1, 10] - 2 * w_step[ny-1, 10] + w_step[ny-2, 10]
        w_step[ny + 2, 11] = 2 * w_step[ny + 1, 11] - 2 * w_step[ny - 1, 11] + w_step[ny - 2, 11]
        #w_step[ny + 2, 12] = 2 * w_step[ny + 1, 12] - 2 * w_step[ny - 1, 12] + w_step[ny - 2, 12]
        #w_step[ny + 2, 13] = 2 * w_step[ny + 1, 13] - 2 * w_step[ny - 1, 13] + w_step[ny - 2, 13]
        #w_step[ny + 2, 14] = 2 * w_step[ny + 1, 14] - 2 * w_step[ny - 1, 14] + w_step[ny - 2, 14]

        increase.append(w_step[ny, nx])
        if k>1000 and abs(increase[k]/increase[k-1]) < 1+tol:
            break
    print(k)
    u_slab.append(w_step[ny, nx])
    u_beam.append(w_step[ny, 2])

    #for j in [0, ny-2]:
    #    for i in [0, nx-2]:
    #        mxx[j, i] = -np.min(Dxx) * (w_step[j + 2, i + 3] - 2 * w_step[j + 2, i + 2] + w_step[j + 2, i + 1]) / (dx ** 2) - nu * np.sqrt(np.min(Dxx) * np.min(Dyy)) * (w_step[j + 3, i + 2] - 2 * w_step[j + 2, i + 2] + w_step[j + 1, i + 2]) / (dy ** 2)
    #        myy[j, i] = -np.min(Dyy) * (w_step[j + 3, i + 2] - 2 * w_step[j + 2, i + 2] + w_step[j + 1, i + 2]) / (dy ** 2) - nu * np.sqrt(np.min(Dxx) * np.min(Dyy)) * (w_step[j + 2, i + 3] - 2 * w_step[j + 2, i + 2] + w_step[j + 2, i + 1]) / (dx ** 2)

    for j in np.arange(0,ny-1):
        for i in np.arange(0,nx-1):
            mxy[j, i] = -2 * (w_step[j + 3, i + 3] + w_step[j + 1, i + 1] - w_step[j + 3, i + 1] - w_step[j + 1, i + 3]) / (4 * dx * dy) * np.sqrt(Dxx_corner * Dyy_corner) / 2
    mxy[0, 0] = 2*mxy[0, 0]

    #Mybeammax = EIin_beam/EIin_yy * myy[-1, 0] / 1000
    #ratio_slab_yy = myy[-1, -1] / myy[-1, 0]
    #print(Mybeammax, ratio_slab_yy)
    Mybeammax = 0.02114278964289895*dq
    ratio_slab_yy = 0.6453152030632676
    Mybeamfunction_step = Mybeammax * 4 * y * ((2 * W) - y) / (2 * W) ** 2

    Mxx_x0_y0 = 0
    Mxx_xL_y0 = 5.333975332959467*dq
    Mxx_x0_yW = 0
    Mxx_xL_yW = 4.755623281052069*dq
    #Mxx_x0_y0 = mxx[0, 0]
    #Mxx_xL_y0 = mxx[0, -1]
    #Mxx_x0_yW = mxx[-1, 0]
    #Mxx_xL_yW = mxx[-1, -1]
    #print(Mxx_x0_y0, Mxx_xL_y0, Mxx_x0_yW, Mxx_xL_yW)
    Mxxfunctionx_step = Mxx_xL_y0 * 4 * X * ((2 * L) - X) / (2 * L) ** 2
    Mxxfunctiony_step = (Mxx_x0_yW + (Mxx_xL_yW - Mxx_xL_y0 - Mxx_x0_yW) * 4 * X * ((2 * L) - X) / (2 * L) ** 2) * 4 * Y * ((2 * W) - Y) / (2 * W) ** 2
    Mxxfunctionxy_step = Mxxfunctionx_step + Mxxfunctiony_step

    w[0] = w_step
    Mxxfunctionxy[0] = Mxxfunctionxy_step
    Mybeamfunction[0] = Mybeamfunction_step
    if l > 0:
        w[l] = w[l - 1]
        w[l] += w_step
        Mxxfunctionxy[l] = Mxxfunctionxy[l - 1]
        Mxxfunctionxy[l] += Mxxfunctionxy_step
        Mybeamfunction[l] += Mybeamfunction[l - 1]
        Mybeamfunction[l] += Mybeamfunction_step

    Mxx_xL_y0_plot.append(Mxxfunctionxy[l][0, -1])
    Mxx_xL_yW_plot.append(Mxxfunctionxy[l][-1, -1])
    m1RA = abs(Mxxfunctionxy - mxy)
    kappaxx = np.clip(np.interp(m1RA, momxx, curvxx), curvxx_yield_neg, curvxx_yield_pos)
    kappaxx_xL_y0_plot.append(kappaxx[l][0, -1])
    kappaxx_xL_yW_plot.append(kappaxx[l][-1, -1])

    kappa_beamyy = np.clip(np.interp(Mybeamfunction, mom_beamyy, curv_beamyy), curv_beamyy_yield_neg, curv_beamyy_yield_pos)
    Myy_x0_y0 = 0
    Myy_xL_y0 = 0
    Myy_x0_yW = np.interp(kappa_beamyy[l][-1], curvyy, momyy)
    Myy_xL_yW = ratio_slab_yy * Myy_x0_yW
    Myyfunctionx_step = Myy_xL_y0 * 4 * Y * ((2 * W) - Y) / (2 * W) ** 2
    Myyfunctiony_step = (Myy_x0_yW + (Myy_xL_yW - Myy_xL_y0 - Myy_x0_yW) * 4 * X * ((2 * L) - X) / (2 * L) ** 2) * 4 * Y * ((2 * W) - Y) / (2 * W) ** 2
    Myyfunctionxy_step = Myyfunctionx_step + Myyfunctiony_step
    m2RA = abs(Myyfunctionxy_step - mxy)
    kappayy = np.clip(np.interp(m2RA, momyy, curvyy), curvyy_yield_neg, curvyy_yield_pos)

    Dxx = np.clip((m1RA[l]+0.0000001) / (kappaxx[l]+0.000000000000000000001), momxx_yield_pos / curvxx_yield_pos, momxx_crack_pos / curvxx_crack_pos)
    Dyy = np.clip((m2RA+0.0000001) / (kappayy+0.000000000000000000001), momyy_yield_pos / curvyy_yield_pos, momyy_crack_pos / curvyy_crack_pos)
    Dxx_corner = Dxx[0, 0]
    Dyy_corner = Dyy[0, 0]
    Dyy_beam = np.clip((Mybeamfunction[l] + 0.0000001) / (kappa_beamyy[l] + 0.000000000000000000001), mom_beamyy_yield_pos / curv_beamyy_yield_pos, mom_beamyy_crack_pos / curv_beamyy_crack_pos)
    Dyy[0::,0] = 1000*Dyy_beam

    idx_mid_xplane = []
    idx_mid_yplane = []

    for j in np.arange(0, ny-1):
        idx_mid_xplane.append(find_nearest(momxx, Mxxfunctionxy[l][:, -1][j]))
    for i in np.arange(0, nx-1):
        idx_mid_yplane.append(find_nearest(momyy, Myyfunctionxy[l][-1][i]))

    print('-------------------------------------------------------------------')
    print('progress:', str(round((l + 1) / len(qindex) * 100, 2)) + '%')
    print('l =', l)
    print('curv factor xx =', curvxx_factor[idx_mid_xplane])
    print('curv factor yy =', curvyy_factor[idx_mid_yplane])
    print("displacement x=L/2, y=W/2:", w_step[ny, nx])
    print("displacement x=L/2, y=0:", w_step[2, nx])
    print("displacement x=0, y=W/2:", w_step[ny, 2])

    #Dynamic part
    w_norm_x = (1 / (w[l][ny, nx] - w[l][ny, 2])) * (w[l][ny, 2:nx + 1] - w[l][ny, 2])
    w_norm_x2 = w_norm_x**2
    w_norm_y = (1 / (w[l][ny, nx] - w[l][2, nx])) * (w[l][2:ny + 1, nx] - w[l][2, nx])
    w_norm_y2 = w_norm_y**2
    w_norm_beam = (1 / w[l][ny, 2]) * w[l][2:ny + 1, 2]
    w_norm_beam2 = w_norm_beam**2
    w_norm = (1 / w[l][ny, nx]) * w[l][2:ny + 1, 2:nx + 1]
    w_norm2 = w_norm**2
    w_edge_norm = (1 / w[l][ny, 2]) * w[l][2:ny + 1, 2]
    w_edge_norm2 = w_edge_norm ** 2

    kM_xx.append(simps(w_norm_x2, x) / L)
    kM_yy.append(simps(w_norm_y2, y) / W)
    kM_xy.append(simps(w_norm_x, x) * simps(w_norm_y, y) / (L*W))
    kM_beam.append(simps(w_norm_beam2, y) / W)
    kL.append(simps(simps(w_norm, x), y) / (W * L))
    kL_beam.append(simps(w_edge_norm, y) / W)


u_slab = np.cumsum(u_slab)
u_beam = np.cumsum(u_beam)
F = np.arange(dq,dq*(len(qindex)+1),dq)*4*L*W

print([0] + list(u_slab))
print([0] + list(F))
print([0] + list(u_beam))
print([0] + list(F/2))
print([kM_xx[0]] + list(kM_xx))
print([kM_yy[0]] + list(kM_yy))
print([kM_xy[0]] + list(kM_xy))
print([kL[0]] + list(kL))
print([kL_beam[0]] + list(kL_beam))
print([kM_beam[0]] + list(kM_beam))
end = time.time()
print('Computation time =', end - start, 'seconds')

fig, ax = plt.subplots(3,3,subplot_kw={"projection": "3d"})
jet = plt.get_cmap('jet')  #_r

surf = ax[0,0].plot_surface(X, Y, w[-1][2:ny + 1, 2:nx + 1], cmap = jet)
ax[0,0].set_xlabel('x')
ax[0,0].set_ylabel('y')
ax[0,0].set_zlabel('w(x,y)')

surf = ax[0,1].plot_surface(X, Y, m1RA[-1], cmap = jet)
ax[0,1].set_xlabel('x')
ax[0,1].set_ylabel('y')
ax[0,1].set_zlabel('M1RA')

surf = ax[0,2].plot_surface(X, Y, m2RA, cmap = jet)
ax[0,2].set_xlabel('x')
ax[0,2].set_ylabel('y')
ax[0,2].set_zlabel('M2RA')

surf = ax[1,0].plot_surface(X, Y, mxy, cmap = jet)
ax[1,0].set_xlabel('x')
ax[1,0].set_ylabel('y')
ax[1,0].set_zlabel('mxy')

surf = ax[1,1].plot_surface(X, Y, Dxx, cmap = jet)
ax[1,1].set_xlabel('x')
ax[1,1].set_ylabel('y')
ax[1,1].set_zlabel('Dxx')

surf = ax[1,2].plot_surface(X, Y, Dyy, cmap = jet)
ax[1,2].set_xlabel('x')
ax[1,2].set_ylabel('y')
ax[1,2].set_zlabel('Dyy')

surf = ax[2,0].plot_surface(X, Y, Mxxfunctionxy[-1], cmap = jet)
ax[2,0].set_xlabel('x')
ax[2,0].set_ylabel('y')
ax[2,0].set_zlabel('mxx')

surf = ax[2,1].plot_surface(X, Y, Myyfunctionxy_step, cmap = jet)
ax[2,1].set_xlabel('x')
ax[2,1].set_ylabel('y')
ax[2,1].set_zlabel('myy')

fig2, axs2 = plt.subplots(3, 3)
axs2[0,0].plot(u_slab, np.arange(dq, dq * (len(qindex) + 1), dq))
axs2[0,0].set_title('F-U')
axs2[0,0].set_xlabel('w [m]')
axs2[0,0].set_ylabel('q [kN/m]')

axs2[0,1].plot(Mxx_xL_y0_plot, np.arange(dq,dq*(len(qindex)+1),dq))
axs2[0,1].set_title('M (x=L, y=0)')
axs2[0,1].set_xlabel('Mxx [kNm/m]')
axs2[0,1].set_ylabel('q [kN/m]')

axs2[0,2].plot(Mxx_xL_yW_plot, np.arange(dq,dq*(len(qindex)+1),dq))
axs2[0,2].set_title('M (x=L, y=W)')
axs2[0,2].set_xlabel('Mxx [kNm/m]')
axs2[0,2].set_ylabel('q [kN/m]')

axs2[1,1].plot(kappaxx_xL_y0_plot, Mxx_xL_y0_plot)
axs2[1,1].set_title('M-kappa (x=L, y=0)')
axs2[1,1].set_xlabel('Mxx [kNm/m]')
axs2[1,1].set_ylabel('kappaxx [kN/m]')

axs2[1,2].plot(kappaxx_xL_yW_plot, Mxx_xL_yW_plot)
axs2[1,2].set_title('M-kappa (x=L, y=W)')
axs2[1,2].set_xlabel('Mxx [kNm/m]')
axs2[1,2].set_ylabel('kappaxx [kN/m]')

axs2[2,0].plot(y, Mybeamfunction[-1])
axs2[2,0].set_title('Beam bending moment')
axs2[2,0].set_xlabel('y [m]')
axs2[2,0].set_ylabel('M [kNm]')

axs2[2,1].plot(y, kappa_beamyy[-1])
axs2[2,1].set_title('Beam curvature')
axs2[2,1].set_xlabel('y [m]')
axs2[2,1].set_ylabel('curv [1/m]')

plt.show()
